@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef __kate_configdialog_h__
@@ -31,6 +31,10 @@
 
 #include <kdialogbase.h>
 
+class QCheckBox;
+class QSpinBox;
+class QButtonGroup;
+
 struct PluginPageListItem
 {
   Kate::Plugin *plugin;
@@ -60,15 +64,14 @@ class KateConfigDialog : public KDialogBase
     Kate::View* v;
     bool dataChanged;
 
-    class QCheckBox* cb_reopenProjects;
-    class QCheckBox* cb_reopenFiles;
-    class QCheckBox* cb_restoreVC;
-    class QCheckBox *cb_singleInstance;
-    class QCheckBox *cb_fullPath;
-    class QCheckBox *cb_syncKonsole;
-    class QCheckBox *cb_modNotifications;
-    class QCheckBox *cb_saveMetaInfos;
-    class QSpinBox *sb_daysMetaInfos;
+    QCheckBox *cb_fullPath;
+    QCheckBox *cb_syncKonsole;
+    QCheckBox *cb_modNotifications;
+    QCheckBox *cb_saveMetaInfos;
+    QSpinBox *sb_daysMetaInfos;
+    QCheckBox* cb_restoreVC;
+    QButtonGroup *sessions_start;
+    QButtonGroup *sessions_exit;
     Kate::ConfigPage *fileSelConfigPage;
     Kate::ConfigPage *filelistConfigPage;
     Kate::ConfigPage *configExternalToolsPage;
