@@ -40,6 +40,7 @@
 #include <kmessagebox.h>
 #include <kencodingfiledialog.h>
 #include <kio/job.h>
+#include <kwin.h>
 
 #include <qdatetime.h>
 #include <qtextcodec.h>
@@ -478,13 +479,14 @@ void KateDocManager::restoreDocumentList (KConfig* config)
     return;
   }
 
-  QProgressDialog *pd=new QProgressDialog(
+  QProgressDialog *pd = new QProgressDialog(
         i18n("Reopening files from the last session..."),
         QString::null,
         count,
         0,
         "openprog");
-
+  
+  KWin::setOnDesktop(pd->winId(), KWin::currentDesktop());
   pd->setCaption (KateApp::self()->makeStdCaption(i18n("Starting Up")));
 
   bool first = true;
