@@ -131,7 +131,9 @@ KateFileSelector::KateFileSelector( KateMainWindow *mainWindow,
 
   dir = new KDirOperator(KURL(), this, "operator");
   dir->setView(KFile::/* Simple */Detail);
-  dir->view()->setSelectionMode(KFile::Multi);
+  dir->view()->setSelectionMode(KFile::Extended);
+  connect ( dir, SIGNAL( viewChanged(KFileView *) ),
+                   this, SLOT( selectorViewChanged(KFileView *) ) );
   setStretchFactor(dir, 2);
 
   KActionCollection *coll = dir->actionCollection();
@@ -219,7 +221,7 @@ void KateFileSelector::readConfig(KConfig *config, const QString & name)
   dir->setViewConfig( config, name + ":view" );
   dir->readConfig(config, name + ":dir");
   dir->setView( KFile::Default );
-  dir->view()->setSelectionMode(KFile::Multi);
+  dir->view()->setSelectionMode(KFile::Extended);
   config->setGroup( name );
 
   // set up the toolbar
@@ -300,7 +302,7 @@ void KateFileSelector::writeConfig(KConfig *config, const QString & name)
 void KateFileSelector::setView(KFile::FileView view)
 {
   dir->setView(view);
-  dir->view()->setSelectionMode(KFile::Multi);
+  dir->view()->setSelectionMode(KFile::Extended);
 }
 
 //END Public Methods
@@ -445,6 +447,11 @@ void KateFileSelector::kateViewChanged()
   acSyncDir->setEnabled( ! mainwin->activeDocumentUrl().directory().isEmpty() );
 }
 
+void KateFileSelector::selectorViewChanged( KFileView * newView )
+{
+  newView->setSelectionMode(KFile::Extended);
+}
+
 //END Private Slots
 
 //BEGIN Protected
