@@ -69,6 +69,9 @@ class KWrite : public KParts::MainWindow
     void editToolbars();
     void changeEditor();
 
+  private slots:
+    void slotNewToolbarConfig();
+
   public slots:
     void printNow();
     void printDlg();
@@ -132,3 +135,4 @@ class KWriteEditorChooser: public KDialogBase
 };
 
 #endif
+// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
