@@ -39,7 +39,7 @@ public:
    BGDialog(QWidget* parent, KConfig* _config, bool _multidesktop = true);
    ~BGDialog();
 
-   void load();
+   void load( bool useDefaults );
    void save();
    void defaults();
 
