@@ -635,8 +635,6 @@ void KBackgroundSettings::setReverseBlending(bool value)
 
 void KBackgroundSettings::setWallpaper(QString wallpaper)
 {
-    if (m_Wallpaper == wallpaper)
-        return;
     dirty = hashdirty = true;
     m_Wallpaper = wallpaper;
 }
@@ -812,7 +810,7 @@ void KBackgroundSettings::readSettings(bool reparse)
         _defMinOptimizationDepth );
     m_bShm = m_pConfig->readBoolEntry( "UseSHM", _defShm );
 
-    dirty = false; hashdirty = true;
+    dirty = reparse; hashdirty = true;
 }
 
 
@@ -969,7 +967,7 @@ void KBackgroundSettings::changeWallpaper(bool init)
 }
 
 
-QString KBackgroundSettings::currentWallpaper()
+QString KBackgroundSettings::currentWallpaper() const
 {
     if ( m_WallpaperMode == NoWallpaper )
 	return QString::null;
