@@ -16,7 +16,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #include <qcheckbox.h>
@@ -147,6 +147,11 @@ KBellConfig::KBellConfig(QWidget *parent, const char *name):
 }
 
 void KBellConfig::load()
+{
+   load( false );
+}
+
+void KBellConfig::load( bool useDefaults )
 {
   XKeyboardState kbd;
   XGetKeyboardControl(kapp->getDisplay(), &kbd);
@@ -156,9 +161,11 @@ void KBellConfig::load()
   m_duration->setValue(kbd.bell_duration);
 
   KConfig cfg("kdeglobals", false, false);
+  cfg.setReadDefaults(  useDefaults );
   cfg.setGroup("General");
   m_useBell->setChecked(cfg.readBoolEntry("UseSystemBell", false));
   useBell(m_useBell->isChecked());
+  emit changed( useDefaults );
 }
 
 void KBellConfig::save()
@@ -236,11 +243,7 @@ void KBellConfig::ringBell()
 
 void KBellConfig::defaults()
 {
-  m_volume->setValue(100);
-  m_pitch->setValue(800);
-  m_duration->setValue(100);
-  m_useBell->setChecked( false );
-  useBell( false );
+   load( true );
 }
 
 void KBellConfig::useBell( bool on )
