@@ -860,9 +860,14 @@ void KCryptoConfig::configChanged()
     emit changed(true);
 }
 
-
 void KCryptoConfig::load()
 {
+   load( false );
+}
+
+void KCryptoConfig::load( bool useDefaults )
+{
+  config->setReadDefaults( useDefaults );
 #ifdef HAVE_SSL
   otherCertDelList.clear();
   yourCertDelList.clear();
@@ -1019,7 +1024,7 @@ void KCryptoConfig::load()
   slotYourCertSelect();
 #endif
 
-  emit changed(false);
+  emit changed( useDefaults );
 }
 
 void KCryptoConfig::save()
@@ -1219,46 +1224,7 @@ void KCryptoConfig::save()
 
 void KCryptoConfig::defaults()
 {
-  mUseTLS->setChecked(true);
-  mUseSSLv2->setChecked(true);
-  mUseSSLv3->setChecked(true);
-  mWarnOnEnter->setChecked(false);
-  mWarnOnLeave->setChecked(true);
-  mWarnOnUnencrypted->setChecked(false);
-#if 0  // NOT IMPLEMENTED IN KDE 2.0
-  mWarnOnMixed->setChecked(true);
-  mWarnSelfSigned->setChecked(true);
-  mWarnExpired->setChecked(true);
-  mWarnRevoked->setChecked(true);
-#endif
-
-#ifdef HAVE_SSL
-    // We don't want to make
-    // ciphers < 56 bit a default selection.  This is very unsafe and
-    // I have already witnessed OpenSSL negotiate a 0 bit connection
-    // on me after tracing the https ioslave on a suspicion.
-
-  CipherItem *item;
-  for ( item = static_cast<CipherItem *>(SSLv2Box->firstChild()); item;
-	item = static_cast<CipherItem *>(item->nextSibling()) ) {
-    item->setOn( item->bits() >= 56 );
-  }
-
-  for ( item = static_cast<CipherItem *>(SSLv3Box->firstChild()); item;
-	item = static_cast<CipherItem *>(item->nextSibling()) ) {
-    item->setOn( item->bits() >= 56 );
-  }
-  mUseEGD->setChecked(false);
-  mUseEFile->setChecked(false);
-  mEGDLabel->setEnabled(false);
-  mEGDPath->setEnabled(false);
-  mEGDPath->setURL(QString::null);
-  oPath->setURL(QString::null);
-
-  defCertBG->setButton(defCertBG->id(defDont));
-#endif
-
-  emit changed(true);
+   load( true );
 }
 
 void KCryptoConfig::genCAList() {
