@@ -34,7 +34,7 @@ class FilterOptions : public KCModule
 public:
     FilterOptions(QWidget *parent = 0, const char *name = 0);
 
-    void load();
+    void load( bool useDefaults );
     void save();
     void defaults();
 
