@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #include <unistd.h>
@@ -34,7 +34,7 @@
  * IMPORTANT: If you change anything here, please run the regression test
  * kdelibs/kio/tests/kurifiltertest
  */
- 
+
 typedef KGenericFactory<KAutoWebSearch> KAutoWebSearchFactory;
 K_EXPORT_COMPONENT_FACTORY (libkuriikwsfilter, KAutoWebSearchFactory("kcmkurifilt"))
 
@@ -50,14 +50,16 @@ KAutoWebSearch::~KAutoWebSearch()
 
 void KAutoWebSearch::configure()
 {
-  kdDebug() << "KAutoWebSearch::configure: Config reload requested..." << endl;
+  if ( KURISearchFilterEngine::self()->verbose() )
+    kdDebug() << "KAutoWebSearch::configure: Config reload requested..." << endl;
+
   KURISearchFilterEngine::self()->loadConfig();
 }
 
 bool KAutoWebSearch::filterURI( KURIFilterData &data ) const
 {
   if (KURISearchFilterEngine::self()->verbose())
-    kdDebug() << "KAutoWebSearch::filterURI: " <<  data.uri().url() << endl;
+    kdDebug() << "KAutoWebSearch::filterURI: '" <<  data.uri().url() << "'" << endl;
 
   KURL u = data.uri();
   if ( u.pass().isEmpty() )
