@@ -1,6 +1,7 @@
 /*  This file is part of the KDE project
     Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
     Copyright (C) 2000 Yves Arrouye <yves@realnames.com>
+    Copyright (C) 2002, 2003 Dawit Alemayehu <adawit@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -29,10 +30,16 @@
 #include "kuriikwsfiltereng.h"
 #include "kurisearchfilter.h"
 
-#define searcher KURISearchFilterEngine::self()
+/**
+ * IMPORTANT: If you change anything here, please run the regression test
+ * kdelibs/kio/tests/kurifiltertest
+ */
+
+typedef KGenericFactory<KURISearchFilter> KURISearchFilterFactory;
+K_EXPORT_COMPONENT_FACTORY(libkurisearchfilter, KURISearchFilterFactory("kcmkurifilt"))
 
 KURISearchFilter::KURISearchFilter(QObject *parent, const char *name,
-	                           const QStringList & /*args*/)
+                                   const QStringList &)
                  :KURIFilterPlugin(parent, name ? name : "kurisearchfilter", 1.0),
                   DCOPObject("KURISearchFilterIface")
 {
@@ -44,36 +51,40 @@ KURISearchFilter::~KURISearchFilter()
 
 void KURISearchFilter::configure()
 {
-    kdDebug() << "(" << getpid() << ") " << "Search Engine Keywords: Sending a config reload request..." << endl;
-    searcher->loadConfig();
+  if ( KURISearchFilterEngine::self()->verbose() )
+    kdDebug() << "KURISearchFilter::configure: Config reload request..." << endl;
+
+  KURISearchFilterEngine::self()->loadConfig();
 }
 
 bool KURISearchFilter::filterURI( KURIFilterData &data ) const
 {
-    if ( searcher->verbose() )
-        kdDebug() << "KURISearchFilter: filtering " << data.uri().url() << endl;
+  if ( KURISearchFilterEngine::self()->verbose() )
+    kdDebug() << "KURISearchFilter::filterURI: '" << data.typedString() << "'" << endl;
 
-    QString result = searcher->searchQuery( data.uri() );
-    if ( !result.isEmpty() )
-    {
-        setFilteredURI( data, result );
-        setURIType( data, KURIFilterData::NET_PROTOCOL );
-        return true;
-    }
-    return false;
+  QString result = KURISearchFilterEngine::self()->webShortcutQuery( data.typedString() );
+
+  if ( !result.isEmpty() )
+  {
+    if ( KURISearchFilterEngine::self()->verbose() )
+      kdDebug() << "Filtered URL: " << result << endl;
+
+    setFilteredURI( data, KURL( result ) );
+    setURIType( data, KURIFilterData::NET_PROTOCOL );
+    return true;
+  }
+
+  return false;
 }
 
-KCModule *KURISearchFilter::configModule(QWidget *parent, const char *name) const
+KCModule *KURISearchFilter::configModule(QWidget *parent, const char *) const
 {
-    return new InternetKeywordsOptions( KURISeachFilterFactory::instance(), parent, name);
+  return new FilterOptions( KURISearchFilterFactory::instance(), parent, "kcmkurifilt");
 }
 
 QString KURISearchFilter::configName() const
 {
-    return i18n("&Keywords");
+  return i18n("Search F&ilters");
 }
 
-K_EXPORT_COMPONENT_FACTORY( libkurisearchfilter, 
-	                    KURISeachFilterFactory( "kuriikwsfilter" ) )
-
 #include "kurisearchfilter.moc"
