@@ -2,13 +2,10 @@
 
 extern "C"
 {
-	  KCModule *create_filetypes(QWidget *parent, const char *)
+	  KDE_EXPORT KCModule *create_filetypes(QWidget *parent, const char *)
           {
         return new FileTypesView(parent, "filetypes");
 	  }
 
-	    void init_filetypes()
-		      {
-			        }
 }
 
