@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  *
  */
@@ -458,7 +458,7 @@ void KMemoryWidget::update_Values()
 #include "memory_sgi.cpp"
 #elif defined(__svr4__) && defined(sun)
 #include "memory_solaris.cpp"
-#elif defined(__FreeBSD__)
+#elif defined(__FreeBSD__) || defined(__DragonFly__)
 #include "memory_fbsd.cpp"
 #elif defined(__hpux)
 #include "memory_hpux.cpp"
