@@ -22,9 +22,7 @@ extern "C" {
 }
 #include <mach/vm_statistics.h>
 
-/* $Id: memory_tru64.cpp,v 1.2 2001/05/27 16:19:53 deller Exp $ */
-
-#define pagetob(size) (1024L * ((long) (size) << (long) pageshift))
+#define pagetob(size) (MEMORY(1024L) * ((long) (size) << (long) pageshift))
 #define LOG1024       10
 
 extern "C" void vm_statistics(task_t, vm_statistics_data_t*);
@@ -76,7 +74,9 @@ void KMemoryWidget::update()
   Memory_Info[FREE_MEM]     = pagetob(vmstats.free_count);
   Memory_Info[SHARED_MEM]   = NO_MEMORY_INFO; 		    /* FIXME ?? */
   Memory_Info[BUFFER_MEM]   = NO_MEMORY_INFO; 		    /* FIXME ?? */
+#ifdef __GNUC__
 #warning "FIXME: Memory_Info[CACHED_MEM]"
+#endif
   Memory_Info[CACHED_MEM]   = NO_MEMORY_INFO; /* cached memory in ram */
   Memory_Info[SWAP_MEM]     = pagetob(swap_pages);
   Memory_Info[FREESWAP_MEM] = pagetob(swap_free);
