@@ -1,6 +1,4 @@
 /*
- * $Id: themepage.h,v 1.3 2003/10/09 22:13:46 fredrik Exp $
- *
  * Copyright (C) 2003 Fredrik Hglund <fredrik@kde.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -14,8 +12,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __THEMEPAGE_H
@@ -35,6 +33,7 @@ class ThemePage : public QWidget
 		// Called by the KCM
 		void save();
 		void load();
+		void load( bool useDefaults );
 		void defaults();
 
 	signals:
