@@ -16,7 +16,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 #include "joywidget.h"
 #include "joydevice.h"
@@ -36,8 +36,8 @@
 
 #include <klocale.h>
 #include <kdialog.h>
-#include <kdebug.h>
 #include <kmessagebox.h>
+#include <kiconloader.h>
 
 //--------------------------------------------------------------
 static QString PRESSED = I18N_NOOP("PRESSED");
@@ -49,8 +49,17 @@ JoyWidget::JoyWidget(QWidget *parent, const char *name)
   QVBox *mainVbox = new QVBox(parent);
   mainVbox->setSpacing(KDialog::spacingHint());
 
-  message = new QLabel(mainVbox);
-  message->hide();
+  // create area to show an icon + message if no joystick was detected
+  {
+    messageBox = new QHBox(mainVbox);
+    messageBox->setSpacing(KDialog::spacingHint());
+    QLabel *icon = new QLabel(messageBox);
+    icon->setPixmap(KGlobal::iconLoader()->loadIcon("messagebox_warning", KIcon::NoGroup,
+                                                    KIcon::SizeMedium, KIcon::DefaultState, 0, true));
+    icon->setFixedSize(icon->sizeHint());
+    message = new QLabel(messageBox);
+    messageBox->hide();
+  }
 
   QHBox *devHbox = new QHBox(mainVbox);
   new QLabel(i18n("Device:"), devHbox);
@@ -176,12 +185,11 @@ void JoyWidget::init()
   /* KDE 4: Remove this check(and i18n) when all KCM wrappers properly test modules */
   if ( device->count() == 0 )
   {
-    message->show();
+    messageBox->show();
     message->setText(QString("<qt><b>%1</b></qt>").arg(
-      i18n("No joystick device automatically found on this computer.\n"
-           "Checks were done in /dev/js[0-4] and /dev/input/js[0-4]\n"
-           "If you know that there is one attached, please enter the correct device file.")
-      .replace("\n", "<br>")));  // hack because we're in string freeze
+      i18n("No joystick device automatically found on this computer.<br>"
+           "Checks were done in /dev/js[0-4] and /dev/input/js[0-4]<br>"
+           "If you know that there is one attached, please enter the correct device file.")));
   }
 }
 
