@@ -13,7 +13,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -90,10 +90,10 @@ RootInfoWidget::RootInfoWidget(QWidget *parent, const char *name = 0)
                       "allow modifications in this module."));
 
 	QWhatsThis::add(this, i18n("This module requires special permissions, probably "
-                              "for system-wide modifications. Therefore it is "
+                              "for system-wide modifications; therefore, it is "
                               "required that you provide the root password to be "
-                              "able to change the modules properties. As long as "
-                              "you don't provide the password, the module will be "
+                              "able to change the module's properties.  If you "
+                              "do not provide the password, the module will be "
                               "disabled."));
 }
 
@@ -205,7 +205,7 @@ ProxyWidget::ProxyWidget(KCModule *client, QString title, const char *name,
 
   _sep = new KSeparator(KSeparator::HLine, this);
 
-  _help =    new KPushButton( KStdGuiItem::help(), this );
+  _handbook= new KPushButton( KGuiItem(KStdGuiItem::help().text(),"contents"), this );
   _default = new KPushButton( KStdGuiItem::defaults(), this );
   _apply =   new KPushButton( KStdGuiItem::apply(), this );
   _reset =   new KPushButton( KGuiItem( i18n( "&Reset" ), "undo" ), this );
@@ -215,7 +215,7 @@ ProxyWidget::ProxyWidget(KCModule *client, QString title, const char *name,
 
   // only enable the requested buttons
   int b = _client->buttons();
-  setVisible(_help, false & (b & KCModule::Help));
+  setVisible(_handbook, (b & KCModule::Help));
   setVisible(_default, mayModify && (b & KCModule::Default));
   setVisible(_apply, mayModify && (b & KCModule::Apply));
   setVisible(_reset, mayModify && (b & KCModule::Apply));
@@ -225,7 +225,7 @@ ProxyWidget::ProxyWidget(KCModule *client, QString title, const char *name,
   _apply->setEnabled( false );
   _reset->setEnabled( false );
 
-  connect(_help, SIGNAL(clicked()), SLOT(helpClicked()));
+  connect(_handbook, SIGNAL(clicked()), SLOT(handbookClicked()));
   connect(_default, SIGNAL(clicked()), SLOT(defaultClicked()));
   connect(_apply, SIGNAL(clicked()), SLOT(applyClicked()));
   connect(_reset, SIGNAL(clicked()), SLOT(resetClicked()));
@@ -237,7 +237,7 @@ ProxyWidget::ProxyWidget(KCModule *client, QString title, const char *name,
   top->addWidget(_sep);
 
   QHBoxLayout *buttons = new QHBoxLayout(top, 4);
-  buttons->addWidget(_help);
+  buttons->addWidget(_handbook);
   buttons->addWidget(_default);
   if (run_as_root) 
   {
@@ -267,10 +267,18 @@ QString ProxyWidget::quickHelp() const
     return "";
 }
 
+void ProxyWidget::handbookClicked()
+{
+  if (getuid()!=0)
+	  emit handbookRequest();
+  else
+     kapp->dcopClient()->send("kcontrol", "moduleIface", "invokeHandbook()", QByteArray());
+}
+
 void ProxyWidget::helpClicked()
 {
   if (getuid()!=0)
-	  emit helpRequest();
+         emit helpRequest();
   else
      kapp->dcopClient()->send("kcontrol", "moduleIface", "invokeHelp()", QByteArray());
 }
