@@ -14,7 +14,7 @@
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  
 */                                                                            
 
@@ -56,6 +56,7 @@ public:
   SearchWidget(QWidget *parent, const char *name=0);
 
   void populateKeywordList(ConfigModuleList *list);
+  void searchTextChanged(const QString &);
 
 signals:
   void moduleSelected(ConfigModule *);
@@ -65,14 +66,12 @@ protected:
   void populateResultListBox(const QString& keyword);
 
 protected slots:
-  void slotSearchTextChanged(const QString &);
   void slotKeywordSelected(const QString &);
   void slotModuleSelected(QListBoxItem *item);
   void slotModuleClicked(QListBoxItem *item);
 
 private:
   KListBox  *_keyList, *_resultList;
-  KLineEdit *_input; 
   QPtrList<KeywordListEntry> _keywords;
 };
 
