@@ -14,10 +14,11 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-  MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA  02110-1301, USA.
 */
 
+#include <kapplication.h>
 #include <kstandarddirs.h>
 #include <kconfig.h>
 #include <kbugreport.h>
@@ -27,8 +28,13 @@
 #include <kaction.h>
 #include <kwin.h>
 #include <kiconloader.h>
+#include <klineedit.h>
 
+#include <qlabel.h>
+#include <qlayout.h>
+#include <qpushbutton.h>
 #include <qtabwidget.h>
+#include <qtooltip.h>
 #include <qwhatsthis.h>
 
 #include "indexwidget.h"
@@ -74,39 +80,69 @@ TopLevel::TopLevel(const char* name)
   _modules = new ConfigModuleList();
   _modules->readDesktopEntries();
 
-  for ( ConfigModule* m = _modules->first(); m; m = _modules->next() )
+  for ( ConfigModule* m = _modules->first(); m; m = _modules->next() ) {
+      connect( m, SIGNAL( handbookRequest() ), this, SLOT( slotHandbookRequest() ) );
       connect( m, SIGNAL( helpRequest() ), this, SLOT( slotHelpRequest() ) );
+  }
 
   // create the layout box
   _splitter = new QSplitter( QSplitter::Horizontal, this );
 
-  // create the left hand side (the tab view)
-  _tab = new QTabWidget( _splitter );
+  QFrame* leftFrame = new QFrame ( _splitter );
+  QBoxLayout *leftFrameLayout = new QVBoxLayout( leftFrame );
 
-  QWhatsThis::add( _tab, i18n("Choose between Index, Search and Quick Help") );
+  QFrame* mSearchFrame = new QFrame( leftFrame );
+  leftFrameLayout->addWidget( mSearchFrame );
+
+  QBoxLayout *searchLayout = new QHBoxLayout( mSearchFrame );
+  searchLayout->setSpacing( KDialog::spacingHint() );
+  searchLayout->setMargin( 6 );
+
+  QPushButton *clearButton = new QPushButton( mSearchFrame );
+  clearButton->setIconSet( KApplication::reverseLayout() ?
+    SmallIconSet( "clear_left" ) : SmallIconSet("locationbar_erase") );
+  searchLayout->addWidget( clearButton );
+  QToolTip::add( clearButton, i18n("Clear search") );
+
+  QLabel *label = new QLabel(i18n("Search:"), mSearchFrame );
+  searchLayout->addWidget( label );
+  
+  KLineEdit *searchEdit = new KLineEdit( mSearchFrame );
+  clearButton->setFixedHeight( searchEdit->height() );
+  connect( clearButton, SIGNAL( clicked() ), searchEdit, SLOT( clear() ) );
+  label->setBuddy( searchEdit );
+  searchLayout->addWidget( searchEdit );
+  connect( searchEdit, SIGNAL( textChanged( const QString & ) ),
+           SLOT( slotSearchChanged(const QString &) ) );
+
+  // create the left hand side under search
+  _stack = new QWidgetStack( leftFrame );
+  leftFrameLayout->addWidget( _stack );
 
   // index tab
-  _indextab = new IndexWidget(_modules, _tab);
-  connect(_indextab, SIGNAL(moduleActivated(ConfigModule*)),
+  _index = new IndexWidget(_modules, this);
+  connect(_index, SIGNAL(moduleActivated(ConfigModule*)),
                   this, SLOT(activateModule(ConfigModule*)));
-  _tab->addTab(_indextab, SmallIconSet("kcontrol"), i18n("&Index"));
+  _stack->addWidget( _index );
 
-  connect(_indextab, SIGNAL(categorySelected(QListViewItem*)),
+  connect(_index, SIGNAL(categorySelected(QListViewItem*)),
                   this, SLOT(categorySelected(QListViewItem*)));
 
   // search tab
-  _searchtab = new SearchWidget(_tab);
-  _searchtab->populateKeywordList(_modules);
-  connect(_searchtab, SIGNAL(moduleSelected(ConfigModule *)),
+  _search = new SearchWidget(this);
+  _search->populateKeywordList(_modules);
+  connect(_search, SIGNAL(moduleSelected(ConfigModule *)),
                   this, SLOT(activateModule(ConfigModule *)));
 
-  _tab->addTab(_searchtab, SmallIconSet("find"), i18n("Sear&ch"));
+  _stack->addWidget( _search );
 
-  // help tab
-  _helptab = new HelpWidget(_tab);
-  _tab->addTab(_helptab, SmallIconSet("help"), i18n("Hel&p"));
+  // set up the right hand side (the docking area)
+  _dock = new DockContainer( _splitter );
 
-  _tab->setSizePolicy( QSizePolicy( QSizePolicy::Maximum, QSizePolicy::Preferred ) );
+  // help widget
+  _help = new HelpWidget(_dock);
+
+  _stack->setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding ) );
 
  // Restore sizes
   config->setGroup("General");
@@ -114,11 +150,8 @@ TopLevel::TopLevel(const char* name)
   if (!sizes.isEmpty())
      _splitter->setSizes(sizes);
 
-  // set up the right hand side (the docking area)
-  _dock = new DockContainer( _splitter );
-
   // That one does the trick ...
-  _splitter->setResizeMode( _tab, QSplitter::KeepSize );
+  _splitter->setResizeMode( leftFrame, QSplitter::KeepSize );
 
   connect(_dock, SIGNAL(newModule(const QString&, const QString&, const QString&)),
                   this, SLOT(newModule(const QString&, const QString&, const QString&)));
@@ -144,7 +177,7 @@ TopLevel::TopLevel(const char* name)
   // insert the about widget
   if (KCGlobal::isInfoCenter())
   {
-      AboutWidget *aw = new AboutWidget( this, 0, _indextab->firstTreeViewItem());
+      AboutWidget *aw = new AboutWidget( this, 0, _index->firstTreeViewItem());
       connect( aw, SIGNAL( moduleSelected( ConfigModule * ) ),
                SLOT( activateModule( ConfigModule * ) ) );
       _dock->setBaseWidget( aw );
@@ -253,7 +286,7 @@ actionCollection());
 void TopLevel::activateIconView()
 {
   KCGlobal::setViewMode(Icon);
-  _indextab->activateView(Icon);
+  _index->activateView(Icon);
 
   icon_small->setEnabled(true);
   icon_medium->setEnabled(true);
@@ -280,7 +313,7 @@ void TopLevel::activateIconView()
 void TopLevel::activateTreeView()
 {
   KCGlobal::setViewMode(Tree);
-  _indextab->activateView(Tree);
+  _index->activateView(Tree);
 
   icon_small->setEnabled(false);
   icon_medium->setEnabled(false);
@@ -291,32 +324,32 @@ void TopLevel::activateTreeView()
 void TopLevel::activateSmallIcons()
 {
   KCGlobal::setIconSize(KIcon::SizeSmall);
-  _indextab->reload();
+  _index->reload();
 }
 
 void TopLevel::activateMediumIcons()
 {
   KCGlobal::setIconSize(KIcon::SizeMedium);
-  _indextab->reload();
+  _index->reload();
 }
 
 void TopLevel::activateLargeIcons()
 {
   KCGlobal::setIconSize(KIcon::SizeLarge);
-  _indextab->reload();
+  _index->reload();
 }
 
 void TopLevel::activateHugeIcons()
 {
   KCGlobal::setIconSize(KIcon::SizeHuge);
-  _indextab->reload();
+  _index->reload();
 }
 
 void TopLevel::newModule(const QString &name, const QString& docPath, const QString &quickhelp)
 {
     setCaption(name, false);
 
-  _helptab->setText( docPath, quickhelp );
+  _help->setText( docPath, quickhelp );
 
   if (!report_bug) return;
 
@@ -363,9 +396,10 @@ void TopLevel::categorySelected(QListViewItem *category)
   // insert the about widget
   QListViewItem *firstItem = category->firstChild();
   QString caption = static_cast<ModuleTreeItem*>(category)->caption();
+  QString icon = static_cast<ModuleTreeItem*>(category)->icon();
   if( _dock->baseWidget()->isA( "AboutWidget" ) )
   {
-    static_cast<AboutWidget *>( _dock->baseWidget() )->setCategory( firstItem, caption);
+    static_cast<AboutWidget *>( _dock->baseWidget() )->setCategory( firstItem, icon, caption);
   }
   else
   {
@@ -383,18 +417,18 @@ void TopLevel::activateModule(ConfigModule *mod)
      return;
 
   // tell the index to display the module
-  _indextab->makeVisible(mod);
+  _index->makeVisible(mod);
 
   // tell the index to mark this module as loaded
-  _indextab->makeSelected(mod);
+  _index->makeSelected(mod);
 
   // dock it
   if (!_dock->dockModule(mod))
   {
      if ( _dock->module() )
      {
-       _indextab->makeVisible(_active);
-       _indextab->makeSelected(_active);
+       _index->makeVisible(_active);
+       _index->makeSelected(_active);
      }
      return;
   }
@@ -422,10 +456,25 @@ void TopLevel::deleteDummyAbout()
   dummyAbout = 0;
 }
 
+void TopLevel::slotSearchChanged(const QString& search)
+{
+    if (search.isEmpty())
+       _stack->raiseWidget(_index);
+    else
+    {
+       _stack->raiseWidget(_search);
+       _search->searchTextChanged(search);
+    }
+}
 
 void TopLevel::slotHelpRequest()
 {
-    _tab->showPage( _helptab );
+    _help->display(_help->text(), QCursor::pos ( ), _dock);
+}
+
+void TopLevel::slotHandbookRequest()
+{
+    _help->handbookRequest();
 }
 
 void TopLevel::reportBug()
