@@ -4,7 +4,7 @@
 // Author        : Craig Drummond
 // Project       : K Font Installer
 // Creation Date : 26/04/2003
-// Version       : $Revision: 468965 $ $Date: 2005-10-09 23:28:29 +0200 (So, 09 Okt 2005) $
+// Version       : $Revision: 535294 $ $Date: 2006-04-29 09:35:51 +0200 (Sa, 29 Apr 2006) $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -631,7 +631,7 @@ void CKCmFontInst::addFonts(const KURL::List &src, const KURL &dest)
         {
             KURL::List associatedUrls;
 
-            Misc::getAssociatedUrls(*it, associatedUrls);
+            Misc::getAssociatedUrls(*it, associatedUrls, false, this);
             copy+=associatedUrls;
         }
 
