@@ -4,7 +4,7 @@
 // Author        : Craig Drummond
 // Project       : K Font Installer
 // Creation Date : 05/03/2003
-// Version       : $Revision: 531358 $ $Date: 2006-04-19 07:07:36 +0200 (Mi, 19 Apr 2006) $
+// Version       : $Revision: 820166 $ $Date: 2008-06-13 14:14:08 +0200 (Fr, 13. Jun 2008) $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -163,13 +163,6 @@ static QString modifyName(const QString &fname)
     return rv;
 }
 
-static QString getFcString(FcPattern *pat, const char *val)
-{
-    FcChar8 *fcStr;
-
-    return FcResultMatch==FcPatternGetString(pat, val, 0, &fcStr) ? (char *)fcStr : NULL;
-}
-
 static int getSize(const QCString &file)
 {
     KDE_struct_stat buff;
@@ -233,7 +226,7 @@ static int getSize(QValueList<FcPattern *> &patterns)
     int                               size=0;
 
     for(it=patterns.begin(); it!=end; ++it)
-        size+=getFontSize(getFcString(*it, FC_FILE));
+        size+=getFontSize(CFcEngine::getFcString(*it, FC_FILE));
 
     return size;
 }
@@ -330,7 +323,7 @@ static bool createFontUDSEntry(KIO::UDSEntry &entry, const QString &name, QValue
     {
         KURL::List urls;
 
-        Misc::getAssociatedUrls(KURL(getFcString(patterns.first(), FC_FILE)), urls);
+        Misc::getAssociatedUrls(KURL(CFcEngine::getFcString(patterns.first(), FC_FILE)), urls);
 
         if(0==urls.count())
             multiple=false;
@@ -355,7 +348,7 @@ static bool createFontUDSEntry(KIO::UDSEntry &entry, const QString &name, QValue
 
     for(it=sortedPatterns.begin(); it!=end; ++it)
     {
-        QString         path(getFcString(*it, FC_FILE));
+        QString         path(CFcEngine::getFcString(*it, FC_FILE));
         QCString        cPath(QFile::encodeName(path));
         KDE_struct_stat buff;
 
@@ -1634,7 +1627,7 @@ void CKioFonts::del(const KURL &url, bool)
  
             for(it=entries->begin(); it!=end; ++it)
             {
-                QString file(getFcString(*it, FC_FILE));
+                QString file(CFcEngine::getFcString(*it, FC_FILE));
 
                 modifiedDirs.add(Misc::getDir(file));
                 cmd+=" ";
@@ -1669,7 +1662,7 @@ void CKioFonts::del(const KURL &url, bool)
         {
             for(it=entries->begin(); it!=end; ++it)
             {
-                QString file(getFcString(*it, FC_FILE));
+                QString file(CFcEngine::getFcString(*it, FC_FILE));
 
                 if (0!=unlink(QFile::encodeName(file).data()))
                     error(EACCES==errno || EPERM==errno
@@ -2042,7 +2035,7 @@ bool CKioFonts::updateFontList()
             for (int i = 0; i < itsFontList->nfont; i++)
             {
                 EFolder folder=FOLDER_SYS;
-                QString file(Misc::fileSyntax(getFcString(itsFontList->fonts[i], FC_FILE)));
+                QString file(Misc::fileSyntax(CFcEngine::getFcString(itsFontList->fonts[i], FC_FILE)));
 
                 if(!file.isEmpty())
                 {
@@ -2059,7 +2052,7 @@ bool CKioFonts::updateFontList()
                                                           end=patterns.end();
 
                         for(it=patterns.begin(); use && it!=end; ++it)
-                            if(file==(Misc::fileSyntax(getFcString(*it, FC_FILE))))
+                            if(file==(Misc::fileSyntax(CFcEngine::getFcString(*it, FC_FILE))))
                                 use=false;
                     }
                     if(use)
@@ -2121,8 +2114,8 @@ FcPattern * CKioFonts::getEntry(EFolder folder, const QString &file, bool full)
                                           patEnd=it.data().end();
 
         for(patIt=it.data().begin(); patIt!=patEnd; ++patIt)
-            if( (full && getFcString(*patIt, FC_FILE)==file) ||
-                (!full && Misc::getFile(getFcString(*patIt, FC_FILE))==file))
+            if( (full && CFcEngine::getFcString(*patIt, FC_FILE)==file) ||
+                (!full && Misc::getFile(CFcEngine::getFcString(*patIt, FC_FILE))==file))
                 return *patIt;
     }
 
@@ -2167,7 +2160,7 @@ bool CKioFonts::getSourceFiles(const KURL &src, QStringList &files)
                                               end=entries->end();
 
             for(it=entries->begin(); it!=end; ++it)
-                files.append(getFcString(*it, FC_FILE));
+                files.append(CFcEngine::getFcString(*it, FC_FILE));
         }
 
         if(files.count())
@@ -2348,7 +2341,7 @@ bool CKioFonts::confirmMultiple(const KURL &url, QValueList<FcPattern *> *patter
                                           end=patterns->end();
 
         for(it=patterns->begin(); it!=end; ++it)
-            files.append(getFcString(*it, FC_FILE));
+            files.append(CFcEngine::getFcString(*it, FC_FILE));
     }
 
     return confirmMultiple(url, files, folder, op);
