@@ -4,7 +4,7 @@
 // Author        : Craig Drummond
 // Project       : K Font Installer
 // Creation Date : 02/08/2003
-// Version       : $Revision: 363303 $ $Date: 2004-11-16 03:08:35 +0100 (Di, 16 Nov 2004) $
+// Version       : $Revision: 465343 $ $Date: 2005-09-29 15:24:25 +0200 (Do, 29 Sep 2005) $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -20,7 +20,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 ////////////////////////////////////////////////////////////////////////////////
 // (C) Craig Drummond, 2003, 2004
@@ -38,7 +38,7 @@
 
 extern "C"
 {
-    ThumbCreator *new_creator()
+    KDE_EXPORT ThumbCreator *new_creator()
     {
         return new KFI::CFontThumbnail;
     }
