@@ -4,7 +4,7 @@
 // Author        : Craig Drummond
 // Project       : K Font Installer
 // Creation Date : 03/08/2002
-// Version       : $Revision: 422926 $ $Date: 2005-06-06 23:37:08 +0200 (Mo, 06 Jun 2005) $
+// Version       : $Revision: 465343 $ $Date: 2005-09-29 15:24:25 +0200 (Do, 29 Sep 2005) $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -20,7 +20,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 ////////////////////////////////////////////////////////////////////////////////
 // (C) Craig Drummond, 2002, 2003, 2004
@@ -30,14 +30,20 @@
 #include "FontPreview.h"
 #include "Misc.h"
 #include "KfiConstants.h"
+#include "KfiPrint.h"
 #include <klocale.h>
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qframe.h>
 #include <qfile.h>
 #include <qlabel.h>
+#include <qpainter.h>
+#include <qpaintdevicemetrics.h>
 #include <qvalidator.h>
 #include <qregexp.h>
+#include <qsettings.h>
+#include <qstringlist.h>
+#include <qtimer.h>
 #include <kio/netaccess.h>
 #include <kinstance.h>
 #include <kmessagebox.h>
@@ -46,7 +52,7 @@
 #include <kaction.h>
 #include <kinputdialog.h>
 #include <kdialog.h>
-#include <string.h>
+#include <kprinter.h>
 #include <fontconfig/fontconfig.h>
 
 static KURL getDest(const KURL &url, bool system)
@@ -104,6 +110,8 @@ CFontViewPart::CFontViewPart(QWidget *parent, const char *name)
     itsChangeTextAction=new KAction(i18n("Change Text..."), "text", KShortcut(),
                                     this, SLOT(changeText()), actionCollection(), "changeText");
     itsChangeTextAction->setEnabled(false);
+    itsPrintAction=KStdAction::print(this, SLOT(print()), actionCollection(), "print");
+    itsPrintAction->setEnabled(false);
 
     setXMLFile("kfontviewpart.rc");
     setWidget(itsFrame);
@@ -132,12 +140,45 @@ bool CFontViewPart::openURL(const KURL &url)
 }
 
 bool CFontViewPart::openFile()
+{
+    // NOTE: Cant do the real open here, as dont seem to be able to use KIO::NetAccess functions during initial start-up.
+    // Bug report 111535 indicates that calling "konqueror <font>" crashes.
+    QTimer::singleShot(0, this, SLOT(timeout()));
+    return true;
+}
+
+void CFontViewPart::timeout()
 {
     bool showFs=false,
          isFonts=KFI_KIO_FONTS_PROTOCOL==m_url.protocol();
 
+    itsShowInstallButton=false;
+
     if(isFonts)
         FcInitReinitialize();
+    else
+    {
+        KURL destUrl;
+
+        //
+        // Not from fonts:/, so try to see if font is already installed...
+        if(Misc::root())
+        {
+            destUrl=QString("fonts:/")+itsPreview->engine().getName(m_url);
+            itsShowInstallButton=!KIO::NetAccess::exists(destUrl, true, itsFrame->parentWidget());
+        }
+        else
+        {
+            destUrl=QString("fonts:/")+i18n(KFI_KIO_FONTS_SYS)+QChar('/')+itsPreview->engine().getName(m_url);
+            if(KIO::NetAccess::exists(destUrl, true, itsFrame->parentWidget()))
+                itsShowInstallButton=false;
+            else
+            {
+                destUrl=QString("fonts:/")+i18n(KFI_KIO_FONTS_USER)+QChar('/')+itsPreview->engine().getName(m_url);
+                itsShowInstallButton=!KIO::NetAccess::exists(destUrl, true, itsFrame->parentWidget());
+            }
+        }
+    }
 
     itsPreview->showFont(isFonts ? m_url : m_file);
 
@@ -147,37 +188,9 @@ bool CFontViewPart::openFile()
         itsFaceSelector->setRange(1, itsPreview->engine().getNumIndexes(), 1, false);
     }
 
-    itsShowInstallButton=false;
     itsFaceLabel->setShown(showFs);
     itsFaceSelector->setShown(showFs);
     itsToolsFrame->hide();
-
-    if(KFI_KIO_FONTS_PROTOCOL!=m_url.protocol())
-    {
-        KURL          destUrl;
-        KIO::UDSEntry uds;
-
-        //
-        // Not from fonts:/, so try to see if font is already installed...
-        if(Misc::root())
-        {
-            destUrl=QString("fonts:/")+itsPreview->engine().getName(m_url);
-            itsShowInstallButton=KIO::NetAccess::stat(destUrl, uds, itsFrame->parentWidget()) ? false : true;
-        }
-        else
-        {
-            destUrl=QString("fonts:/")+i18n(KFI_KIO_FONTS_SYS)+QChar('/')+itsPreview->engine().getName(m_url);
-            if(KIO::NetAccess::stat(destUrl, uds, itsFrame->parentWidget()))
-                itsShowInstallButton=false;
-            else
-            {
-                destUrl=QString("fonts:/")+i18n(KFI_KIO_FONTS_USER)+QChar('/')+itsPreview->engine().getName(m_url);
-                itsShowInstallButton=KIO::NetAccess::stat(destUrl, uds, itsFrame->parentWidget()) ? false : true;
-            }
-        }
-    }
-
-    return true;
 }
 
 void CFontViewPart::previewStatus(bool st)
@@ -185,6 +198,7 @@ void CFontViewPart::previewStatus(bool st)
     itsInstallButton->setShown(st && itsShowInstallButton);
     itsToolsFrame->setShown(itsInstallButton->isShown()||itsFaceSelector->isShown());
     itsChangeTextAction->setEnabled(st);
+    itsPrintAction->setEnabled(st && KFI_KIO_FONTS_PROTOCOL==m_url.protocol());
 }
 
 void CFontViewPart::install()
@@ -254,6 +268,15 @@ void CFontViewPart::changeText()
     }
 }
 
+void CFontViewPart::print()
+{
+    QStringList items;
+
+    items.append(itsPreview->engine().getName(m_url));
+
+    Print::printItems(items, 0, itsFrame->parentWidget(), itsPreview->engine());
+}
+
 }
 
 #include "FontViewPart.moc"
