@@ -117,63 +117,78 @@ KDesktopConfig::KDesktopConfig(QWidget *parent, const char * /*name*/)
   layout->addWidget(_wheelOption);
   layout->addStretch(1);
 
-  // Begin check for immutable
-  int kwin_screen_number = DefaultScreen(qt_xdisplay());
-
-  KConfig config( "kwinrc" );
-
-  QCString groupname;
-  if (kwin_screen_number == 0)
-     groupname = "Desktops";
-  else
-     groupname.sprintf("Desktops-screen-%d", kwin_screen_number);
-
-  if (config.groupIsImmutable(QString::fromUtf8(groupname)))
-  {
-     name_group->setEnabled(false);
-     number_group->setEnabled(false);
-  }
-  else
-  {
-     KConfigGroupSaver cfgSaver(&config, groupname);
-     if (config.entryIsImmutable("Number"))
-     {
-        number_group->setEnabled(false);
-     }
-  }
-  // End check for immutable
-
   load();
 }
 
 void KDesktopConfig::load()
+{
+	load( false );
+}
+	
+void KDesktopConfig::load( bool useDefaults )
 {
   // get number of desktops
   NETRootInfo info( qt_xdisplay(), NET::NumberOfDesktops | NET::DesktopNames );
   int n = info.numberOfDesktops();
 
-  _numInput->setValue(n);
+  int konq_screen_number = 0;
+  if (qt_xdisplay())
+     konq_screen_number = DefaultScreen(qt_xdisplay());
 
+  QCString groupname;
+  if (konq_screen_number == 0)
+     groupname = "Desktops";
+  else
+     groupname.sprintf("Desktops-screen-%d", konq_screen_number);
+
+  KConfig * kwinconfig = new KConfig("kwinrc");
+
+  kwinconfig->setReadDefaults( useDefaults );
+
+  kwinconfig->setGroup("Desktops");
   for(int i = 1; i <= maxDesktops; i++)
   {
+    QString key_name(QString("Name_") + QString::number(i));
     QString name = QString::fromUtf8(info.desktopName(i));
+    if (name.isEmpty()) // Get name from configuration if none is set in the WM.
+    {
+        name = kwinconfig->readEntry(key_name, i18n("Desktop %1").arg(i));
+    }
     _nameInput[i-1]->setText(name);
+
+    // Is this entry immutable or not in the range of configured desktops?
+    _labelImmutable[i - 1] = kwinconfig->entryIsImmutable(key_name);
+    _nameInput[i-1]->setEnabled(i <= n && !_labelImmutable[i - 1]);
   }
 
-  for(int i = 1; i <= maxDesktops; i++)
-    _nameInput[i-1]->setEnabled(i <= n);
-  emit changed(false);
+  _numInput->setEnabled(!kwinconfig->entryIsImmutable("Number"));
+
+  delete kwinconfig;
+  kwinconfig = 0;
+
+  QString configfile;
+  if (konq_screen_number == 0)
+      configfile = "kdesktoprc";
+  else
+      configfile.sprintf("kdesktop-screen-%drc", konq_screen_number);
+
+  KConfig *config = new KConfig(configfile, false, false);
+
+  config->setReadDefaults( useDefaults );
 
-  KConfig *config = new KConfig("kdesktoprc", false, false);
   config->setGroup("Mouse Buttons");
   _wheelOption->setChecked(config->readBoolEntry("WheelSwitchesWorkspace",false));
 
   _wheelOptionImmutable = config->entryIsImmutable("WheelSwitchesWorkspace");
 
   if (_wheelOptionImmutable || n<2)
-     _wheelOption->setEnabled(false);
+     _wheelOption->setEnabled( false );
 
   delete config;
+  config = 0;
+
+  _numInput->setValue(n);
+  emit changed( useDefaults );
 }
 
 void KDesktopConfig::save()
@@ -191,16 +206,6 @@ void KDesktopConfig::save()
 
   XSync(qt_xdisplay(), FALSE);
 
-  KConfig *config = new KConfig("kdesktoprc");
-  config->setGroup("Mouse Buttons");
-  config->writeEntry("WheelSwitchesWorkspace", _wheelOption->isChecked());
-  delete config;
-
-  // Tell kdesktop about the new config file
-  if ( !kapp->dcopClient()->isAttached() )
-     kapp->dcopClient()->attach();
-  QByteArray data;
-
   int konq_screen_number = 0;
   if (qt_xdisplay())
      konq_screen_number = DefaultScreen(qt_xdisplay());
@@ -210,6 +215,17 @@ void KDesktopConfig::save()
       appname = "kdesktop";
   else
       appname.sprintf("kdesktop-screen-%d", konq_screen_number);
+
+  KConfig *config = new KConfig(appname + "rc");
+  config->setGroup("Mouse Buttons");
+  config->writeEntry("WheelSwitchesWorkspace", _wheelOption->isChecked());
+  delete config;
+
+  // Tell kdesktop about the new config file
+  if ( !kapp->dcopClient()->isAttached() )
+     kapp->dcopClient()->attach();
+  QByteArray data;
+
   kapp->dcopClient()->send( appname, "KDesktopIface", "configure()", data );
 
   emit changed(false);
@@ -217,32 +233,14 @@ void KDesktopConfig::save()
 
 void KDesktopConfig::defaults()
 {
-  int n = 4;
-  _numInput->setValue(n);
-
-  for(int i = 0; i < maxDesktops; i++)
-    _nameInput[i]->setText(i18n("Desktop %1").arg(i+1));
-
-  for(int i = 0; i < maxDesktops; i++)
-    _nameInput[i]->setEnabled(i < n);
-
-  _wheelOption->setChecked(false);
-  if (!_wheelOptionImmutable)
-    _wheelOption->setEnabled(true);
-
-  emit changed(false);
+	load( true );
 }
 
 void KDesktopConfig::slotValueChanged(int n)
 {
   for(int i = 0; i < maxDesktops; i++)
-  {
-    _nameInput[i]->setEnabled(i < n);
-    if(i<n && _nameInput[i]->text().isEmpty())
-      _nameInput[i]->setText(i18n("Desktop %1").arg(i+1));
-  }
+  { _nameInput[i]->setEnabled(i < n && !_labelImmutable[i]); }
   if (!_wheelOptionImmutable)
-    _wheelOption->setEnabled(n>1);
+  { _wheelOption->setEnabled(n>1); }
   emit changed(true);
 }
-
