@@ -277,6 +277,10 @@ void KMiscHTMLOptions::load( bool useDefaults )
     m_pOnlyMarkedBookmarksCheckBox->setChecked( config.readBoolEntry("FilteredToolbar", false) );
 
 	 emit changed( useDefaults );
+
+#undef READ_ENTRY
+#undef READ_BOOL
+#undef SET_GROUP
 }
 
 void KMiscHTMLOptions::defaults()
