@@ -2,13 +2,12 @@
 #ifndef __KHTTPOPTDLG_H
 #define __KHTTPOPTDLG_H
 
-
-#include <qwidget.h>
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
 #include <qstring.h>
 
+#include <kcmodule.h>
 #include <kconfig.h>
 
 
@@ -16,19 +15,17 @@
 *  Dialog for configuring HTTP Options like charset and language negotiation
 *  and assuming that file got from HTTP is HTML if no Content-Type is given
 */
-class KHTTPOptions : public QWidget
+class KHTTPOptions : public KCModule
 {
 Q_OBJECT
   public:
     KHTTPOptions(KConfig *config, QString group, QWidget *parent = 0L, const char *name = 0L);
 
     virtual void load();
+    virtual void load( bool useDefaults );
     virtual void save();
     virtual void defaults();
 
-signals:
-    void changed( bool state );
-
   private:
 
     KConfig *m_pConfig;
@@ -45,8 +42,7 @@ signals:
     QString defaultCharsets;
 
 private slots:
-
-  void changed();
+    void slotChanged();
 
 };
 
