@@ -113,7 +113,11 @@ void kthememanager::init()
 void kthememanager::updateButton()
 {
     QListViewItem * cur = dlg->lvThemes->currentItem();
-    dlg->btnRemove->setEnabled( cur != 0 );
+    bool enable = (cur != 0);
+    if (enable) {
+        enable = QFile(KGlobal::dirs()->saveLocation( "themes",  cur->text( 0 ) + "/"+ cur->text( 0 )+ ".xml" ,false)).exists() ;
+    }
+    dlg->btnRemove->setEnabled(enable);
 }
 
 void kthememanager::load()
