@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   */
 
@@ -49,10 +49,10 @@ public:
   virtual ~KLocaleApplication();
 
   virtual void load();
+  virtual void load(bool useDefault);
   virtual void save();
   virtual void defaults();
   virtual QString quickHelp() const;
-  virtual const KAboutData * aboutData() const;
 
 signals:
   void languageChanged();
@@ -80,7 +80,6 @@ private:
 
   KConfig * m_globalConfig;
   KConfig * m_nullConfig;
-  KAboutData * m_aboutData;
 };
 
 typedef KGenericFactory<KLocaleApplication, QWidget > KLocaleFactory;
