@@ -13,7 +13,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "randr.h"
@@ -152,30 +152,31 @@ bool RandRScreen::confirm()
 
 	// FIXME remember to put the dialog on the right screen
 
-	KTimerDialog *acceptDialog = new KTimerDialog(
-											15000,
-											KTimerDialog::CountDown,
-											KApplication::kApplication()->mainWidget(),
+	KTimerDialog acceptDialog ( 15000, KTimerDialog::CountDown, 
+                KApplication::kApplication()->mainWidget(),
 											"mainKTimerDialog",
 											true,
 											i18n("Confirm Display Setting Change"),
 											KTimerDialog::Ok|KTimerDialog::Cancel,
 											KTimerDialog::Cancel);
 
-	acceptDialog->setButtonOK(KGuiItem(i18n("&Accept Configuration"), "button_ok"));
-	acceptDialog->setButtonCancel(KGuiItem(i18n("&Return to Previous Configuration"), "button_cancel"));
+	acceptDialog.setButtonOK(KGuiItem(i18n("&Accept Configuration"), "button_ok"));
+	acceptDialog.setButtonCancel(KGuiItem(i18n("&Return to Previous Configuration"), "button_cancel"));
 
-	KActiveLabel *label = new KActiveLabel(i18n("Your screen orientation, size and refresh rate have been changed to the requested settings. Please indicate whether you wish to keep this configuration. In 15 seconds the display will revert to your previous settings."), acceptDialog, "userSpecifiedLabel");
+	KActiveLabel *label = new KActiveLabel(i18n("Your screen orientation, size and refresh rate "
+                    "have been changed to the requested settings. Please indicate whether you wish to "
+                    "keep this configuration. In 15 seconds the display will revert to your previous "
+                    "settings."), &acceptDialog, "userSpecifiedLabel");
 
-	acceptDialog->setMainWidget(label);
+	acceptDialog.setMainWidget(label);
 
-	KDialog::centerOnScreen(acceptDialog, m_screen);
+	KDialog::centerOnScreen(&acceptDialog, m_screen);
 
-	m_shownDialog = acceptDialog;
+	m_shownDialog = &acceptDialog;
 	connect( m_shownDialog, SIGNAL( destroyed()), this, SLOT( shownDialogDestroyed()));
 	connect( kapp->desktop(), SIGNAL( resized(int)), this, SLOT( desktopResized()));
 
-    return acceptDialog->exec();
+        return acceptDialog.exec();
 }
 
 void RandRScreen::shownDialogDestroyed()
@@ -546,8 +547,8 @@ void RandRScreen::save(KConfig& config) const
 	config.writeEntry("height", currentPixelHeight());
 	config.writeEntry("refresh", refreshRateIndexToHz(currentSize(), currentRefreshRate()));
 	config.writeEntry("rotation", rotationIndexToDegree(currentRotation()));
-	config.writeEntry("reflectX", (bool)(currentRotation() & ReflectMask == ReflectX));
-	config.writeEntry("reflectY", (bool)(currentRotation() & ReflectMask == ReflectY));
+	config.writeEntry("reflectX", (bool)(currentRotation() & ReflectMask) == ReflectX);
+	config.writeEntry("reflectY", (bool)(currentRotation() & ReflectMask) == ReflectY);
 }
 
 RandRDisplay::RandRDisplay()
