@@ -50,6 +50,7 @@ public:
   SmartcardBase *base;
 
   void load();
+  void load( bool useDefaults);
   void save();
   void defaults();
 
@@ -77,8 +78,7 @@ private:
   bool _ok;
   KCardDB * _cardDB;
   KPopupMenu * _popUpKardChooser;
-
-  void loadSmartCardSupportTab();
+  
   void getSupportingModule( KListViewItem * ant,
                             QString & cardATR) const ;
 
