@@ -57,8 +57,14 @@ SMServerConfig::SMServerConfig( QWidget *parent, const char* name, const QString
 }
 
 void SMServerConfig::load()
+{
+	load( false );
+}
+
+void SMServerConfig::load(bool useDefaults )
 {
   KConfig *c = new KConfig("ksmserverrc", false, false);
+  c->setReadDefaults( useDefaults );
   c->setGroup("General");
   dialog->confirmLogoutCheck->setChecked(c->readBoolEntry("confirmLogout", true));
   bool en = c->readBoolEntry("offerShutdown", true);
@@ -88,7 +94,7 @@ void SMServerConfig::load()
 
   delete c;
 
-  emit changed(false);
+  emit changed(useDefaults);
 }
 
 void SMServerConfig::save()
@@ -121,13 +127,7 @@ void SMServerConfig::save()
 
 void SMServerConfig::defaults()
 {
-  dialog->previousSessionRadio->setChecked(true);
-  dialog->confirmLogoutCheck->setChecked(true);
-  dialog->offerShutdownCheck->setChecked(true);
-  dialog->sdGroup->setEnabled(true);
-  dialog->logoutRadio->setChecked(true);
-  dialog->excludeLineedit->setText("");
-
+	load( true );
 }
 
 #include "kcmsmserver.moc"
