@@ -30,6 +30,8 @@
 #include <kdialog.h>
 #include <kgenericfactory.h>
 #include <kwin.h>
+#include <kcolorbutton.h>
+#include <qlabel.h>
 
 #define protected public
 #include "kcmtaskbarui.h"
@@ -152,7 +154,9 @@ TaskbarConfig::TaskbarConfig(QWidget *parent, const char* name, const QStringLis
 
     connect(m_widget->kcfg_GroupTasks, SIGNAL(activated(int)),
             this, SLOT(slotUpdateComboBox()));
+    connect(m_widget->kcfg_UseCustomColors, SIGNAL(stateChanged(int)), this, SLOT(slotUpdateCustomColors()));
 
+    slotUpdateCustomColors();
     updateAppearanceCombo();
 
     if (KWin::numberOfDesktops() < 2)
@@ -183,6 +187,18 @@ TaskbarConfig::TaskbarConfig(QWidget *parent, const char* name, const QStringLis
     QTimer::singleShot(0, this, SLOT(notChanged()));
 }
 
+void TaskbarConfig::slotUpdateCustomColors()
+{
+    m_widget->kcfg_ActiveTaskTextColor->setEnabled(m_widget->kcfg_UseCustomColors->isChecked());
+    m_widget->activeTaskTextColorLabel->setEnabled(m_widget->kcfg_UseCustomColors->isChecked());
+    
+    m_widget->kcfg_InactiveTaskTextColor->setEnabled(m_widget->kcfg_UseCustomColors->isChecked());
+    m_widget->inactiveTaskTextColorLabel->setEnabled(m_widget->kcfg_UseCustomColors->isChecked());
+    
+    m_widget->kcfg_TaskBackgroundColor->setEnabled(m_widget->kcfg_UseCustomColors->isChecked());
+    m_widget->taskBackgroundColorLabel->setEnabled(m_widget->kcfg_UseCustomColors->isChecked());
+}
+
 void TaskbarConfig::slotUpdateComboBox()
 {
     int pos = TaskBarSettings::ActivateRaiseOrMinimize;
