@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: passwd.cpp 355587 2004-10-18 12:08:14Z mlaurent $
+ * $Id: passwd.cpp 822499 2008-06-20 12:47:26Z lunakl $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -158,6 +158,13 @@ int PasswdProcess::ConversePasswd(const char *oldpass, const char *newpass,
 
 	case 2: 
 	    m_Error = "";
+	    if( line.contains("again"))
+	    {
+		m_Error = line;
+		kill(m_Pid, SIGKILL);
+		waitForChild();
+		return PasswordIncorrect;
+	    }
 	    // Wait for second prompt.
 	    errline = line;  // use first line for error message
 	    while (!isPrompt(line, "new"))
