@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: passwddlg.cpp 293432 2004-03-03 21:33:17Z mhunter $
+ * $Id: passwddlg.cpp 432857 2005-07-08 19:31:49Z binner $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -103,7 +103,7 @@ bool KDEpasswd2Dialog::checkPassword(const char *password)
 
     if (strlen(password) > 8)
     {
-	switch(KMessageBox::questionYesNoCancel(this,
+	switch(KMessageBox::warningYesNoCancel(this,
 		m_User.isEmpty() ?
 		i18n("Your password is longer than 8 characters. On some "
 			"systems, this can cause problems. You can truncate "
@@ -112,9 +112,9 @@ bool KDEpasswd2Dialog::checkPassword(const char *password)
 			"systems, this can cause problems. You can truncate "
 			"the password to 8 characters, or leave it as it is.")
 			,
-		i18n("Password too long"),
+		i18n("Password Too Long"),
 		i18n("Truncate"),
-		i18n("Use as is"),
+		i18n("Use as Is"),
 		"truncatePassword"))
 	{
 	case KMessageBox::Yes :
