@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -23,7 +23,8 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <kpushbutton.h>
-#include <klistbox.h>
+#include <klistview.h>
+#include <qheader.h>
 #include <klocale.h>
 #include <kabc/stdaddressbook.h>
 #include <kmessagebox.h>
@@ -36,28 +37,22 @@
 FaxAB::FaxAB(QWidget *parent, const char *name)
 : KDialog(parent, name, true)
 {
-	m_name = new KListBox(this);
-	m_fax = new KListBox(this);
-	QLabel	*m_namelabel = new QLabel(i18n("Entries:"), this);
-	QLabel	*m_faxlabel = new QLabel(i18n("Fax number:"), this);
+	m_list = new KListView( this );
+	m_list->addColumn( i18n( "Name" ) );
+	m_list->addColumn( i18n( "Fax Number" ) );
+	m_list->header()->setStretchEnabled( true, 0 );
+	QLabel	*m_listlabel = new QLabel(i18n("Entries:"), this);
 	m_ok = new KPushButton(KStdGuiItem::ok(), this);
 	QPushButton	*m_cancel = new KPushButton(KStdGuiItem::cancel(), this);
 	QPushButton	*m_ab = new KPushButton(KGuiItem(i18n("&Edit Addressbook"), "contents"), this);
 	connect(m_ok, SIGNAL(clicked()), SLOT(accept()));
 	connect(m_cancel, SIGNAL(clicked()), SLOT(reject()));
-	connect(m_name, SIGNAL(highlighted(const QString&)), SLOT(slotSelected(const QString&)));
 	connect(m_ab, SIGNAL(clicked()), SLOT(slotEditAb()));
 	m_ok->setDefault(true);
 
 	QVBoxLayout	*l0 = new QVBoxLayout(this, 10, 10);
-	QGridLayout	*l1 = new QGridLayout(0, 2, 3, 0, 0);
-	l0->addLayout(l1, 1);
-	l1->setRowStretch(1, 1);
-	l1->addColSpacing(1, 10);
-	l1->addWidget(m_namelabel, 0, 0);
-	l1->addWidget(m_faxlabel, 0, 2);
-	l1->addWidget(m_name, 1, 0);
-	l1->addWidget(m_fax, 1, 2);
+	l0->addWidget( m_listlabel );
+	l0->addWidget( m_list );
 	QHBoxLayout	*l2 = new QHBoxLayout(0, 0, 10);
 	l0->addLayout(l2, 0);
 	l2->addWidget(m_ab, 0);
@@ -84,44 +79,53 @@ FaxAB::~FaxAB()
 void FaxAB::initialize()
 {
 	m_entries.clear();
-	m_name->clear();
-	m_fax->clear();
+	m_list->clear();
 
 	KABC::AddressBook	*bk = KABC::StdAddressBook::self();
 	for (KABC::AddressBook::Iterator it=bk->begin(); it!=bk->end(); ++it)
 	{
 		KABC::PhoneNumber::List	numbers = (*it).phoneNumbers();
-		QStringList	filteredNumbers;
+		KABC::PhoneNumber::List faxNumbers;
 		for (QValueList<KABC::PhoneNumber>::Iterator nit=numbers.begin(); nit!=numbers.end(); ++nit)
 		{
 			if (((*nit).type() & KABC::PhoneNumber::Fax) && !(*nit).number().isEmpty())
-				filteredNumbers << (*nit).number();
+				faxNumbers << ( *nit );
 		}
-		if (filteredNumbers.count() > 0)
+		if (faxNumbers.count() > 0)
 		{
-			filteredNumbers.prepend((*it).organization());
-			if ( !( *it ).formattedName().isEmpty() )
-				m_entries[(*it).formattedName()] = filteredNumbers;
-			else
+			for ( KABC::PhoneNumber::List::ConstIterator nit = faxNumbers.begin(); nit != faxNumbers.end(); ++nit )
 			{
-				QString key = ( *it ).familyName();
-				if ( !( *it ).givenName().isEmpty() )
+				FaxABEntry entry;
+				entry.m_number = ( *nit );
+				entry.m_enterprise = ( *it ).organization();
+				if ( !( *it ).formattedName().isEmpty() )
+					entry.m_name = ( *it ).formattedName();
+				else
 				{
-					if ( !key.isEmpty() )
-						key.append( " " );
-					key.append( ( *it ).givenName() );
+					QString key = ( *it ).familyName();
+					if ( !( *it ).givenName().isEmpty() )
+					{
+						if ( !key.isEmpty() )
+							key.append( " " );
+						key.append( ( *it ).givenName() );
+					}
+					entry.m_name = key;
 				}
-				m_entries[ key ] = filteredNumbers;
+				entry.m_name += ( " (" + ( *nit ).typeLabel() + ")" );
+				m_entries[ entry.m_name ] = entry;
 			}
 		}
 	}
 
 	if (m_entries.count() > 0)
 	{
-		for (QMap<QString,QStringList>::ConstIterator it=m_entries.begin(); it!=m_entries.end(); ++it)
-			m_name->insertItem(SmallIcon("abentry"), it.key());
-		m_name->sort();
-		m_name->setCurrentItem(0);
+		for (QMap<QString,FaxABEntry>::ConstIterator it=m_entries.begin(); it!=m_entries.end(); ++it)
+		{
+			QCheckListItem *item = new QCheckListItem( m_list, it.key(), QCheckListItem::CheckBox );
+			item->setText( 1, ( *it ).m_number.number() );
+			item->setText( 2, ( *it ).m_enterprise );
+		}
+		m_list->sort();
 		m_ok->setEnabled(true);
 	}
 	else
@@ -138,22 +142,7 @@ void FaxAB::slotAbChanged(AddressBook*)
 	initialize();
 }
 
-void FaxAB::slotSelected(const QString& text)
-{
-	if (m_entries.contains(text))
-	{
-		QStringList	l = m_entries[text];
-		m_fax->clear();
-		QStringList::ConstIterator	it = l.begin();
-		++it;	// skip organization name
-		for (; it!=l.end(); ++it)
-			m_fax->insertItem(SmallIcon("kdeprintfax"), *it);
-		m_fax->sort();
-		m_fax->setCurrentItem(0);
-	}
-}
-
-bool FaxAB::getEntry(QString& number, QString& name, QString& enterprise, QWidget *parent)
+bool FaxAB::getEntry(QStringList& number, QStringList& name, QStringList& enterprise, QWidget *parent)
 {
 	FaxAB	kab(parent);
 	if (!kab.isValid())
@@ -163,12 +152,22 @@ bool FaxAB::getEntry(QString& number, QString& name, QString& enterprise, QWidge
 	}
 	if (kab.exec())
 	{
+		QListViewItemIterator it( kab.m_list, QListViewItemIterator::Checked );
+		while ( it.current() )
+		{
+			number << it.current()->text( 1 );
+			name << it.current()->text( 0 );
+			enterprise << it.current()->text( 2 );
+			++it;
+		}
+		/*
 		number = kab.m_fax->currentText();
 		name = kab.m_name->currentText();
 		if (kab.m_entries.contains(name))
 		{
 			enterprise = kab.m_entries[name][0];
 		}
+		*/
 		return true;
 	}
 
@@ -188,7 +187,7 @@ bool FaxAB::getEntryByNumber(const QString& number, QString& name, QString& ente
 			{
 				QString strippedNumber;
 				for (uint i = 0; i < (*nit).number().length(); ++i)
-					if ((*nit).number()[i].isDigit())
+					if ((*nit).number()[i].isDigit() || ( *nit ).number()[ i ] == '+')
 						strippedNumber.append((*nit).number()[i]);
 
 				if ( strippedNumber == number)
