@@ -744,7 +744,9 @@ void KDesktop::desktopIconsAreaChanged(const QRect &area, int screen)
     else if (screen == -1)
        screen = kapp->desktop()->primaryScreen();
 
-    if ( (screen == kdesktop_screen_number) && m_pIconView )
+    // This is pretty broken, mixes Xinerama and non-Xinerama multihead
+    // and generally doesn't seem to be required anyway => ignore screen.
+    if ( /*(screen == kdesktop_screen_number) &&*/ m_pIconView )
         m_pIconView->updateWorkArea(area);
 }
 
