@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef __desktop_h__
@@ -48,6 +48,9 @@ public:
    bool eventFilter( QObject *, QEvent * e );
 signals:
    void wheelRolled( int delta );
+   void colorDropEvent( QDropEvent* e );
+   void imageDropEvent( QDropEvent* e );
+   void newWallpaper( const KURL& url );
 };
 
 /**
@@ -63,7 +66,7 @@ public:
 
   enum WheelDirection { Forward = 0, Reverse };
 
-  KDesktop(bool x_root_hack, bool auto_start, bool wait_for_kded );
+  KDesktop(bool x_root_hack, bool wait_for_kded );
   ~KDesktop();
 
   // Implementation of the DCOP interface
@@ -76,12 +79,16 @@ public:
 
   virtual void configure();
   virtual void popupExecuteCommand();
+  virtual void popupExecuteCommand(const QString& content);
   virtual void refresh();
   virtual void logout();
   virtual void clearCommandHistory();
+  virtual void runAutoStart();
 
   virtual void switchDesktops( int delta );
 
+  virtual void desktopIconsAreaChanged(const QRect &area, int screen);
+
   void logout( KApplication::ShutdownConfirm confirm, KApplication::ShutdownType sdtype );
 
   KWinModule* kwinModule() const { return m_pKwinmodule; }
@@ -96,9 +103,6 @@ public:
   KDIconView *iconView() const { return m_pIconView; }
 
 private slots:
-
-  void workAreaChanged();
-
   /** Background is ready. */
   void backgroundInitDone();
 
@@ -119,6 +123,8 @@ private slots:
 
   void slotShowWindowList();
 
+  void slotSwitchUser();
+
   void slotLogout();
   void slotLogoutNoCnf();
   void slotHaltNoCnf();
@@ -139,11 +145,12 @@ private slots:
   void handleColorDropEvent( QDropEvent * );
   void slotNewWallpaper(const KURL &url);
 
-  void updateWorkArea();
-
   /** Connected to KDIconView and KRootWidget  */
   void slotSwitchDesktops(int delta);
 
+  // when there seems to be no kicker, we have to get desktopIconsArea from kwinModule
+  void slotNoKicker();
+
 protected:
   void initConfig();
   void initRoot();
@@ -159,7 +166,7 @@ protected:
 
 private slots:
   void desktopResized();
-  
+
 private:
 
   KGlobalAccel *keys;
@@ -171,8 +178,6 @@ private:
   KDIconView *m_pIconView;
   KRootWidget *m_pRootWidget;
 
-  QTimer *updateWorkAreaTimer;
-
   Minicli *m_miniCli;
 
   StartupId* startup_id;
@@ -181,23 +186,22 @@ private:
   /** Set to true until start() has been called */
   bool m_bInit;
 
-  /** Execute files from autoexec folder? */
-  bool m_bAutoStart;
-
   /** Wait for kded to finish building database? */
   bool m_bWaitForKded;
-  
+
   /** Desktop enabled / disabled **/
   bool m_bDesktopEnabled;
 
   /** Whether or not to switch desktops when mouse wheel is rolled */
   bool m_bWheelSwitchesWorkspace;
 
+  QTimer *m_waitForKicker;
+
   /** Default mouse wheel direction (Fwd means mwheel up switches to
       lower desktop)
   */
   static const WheelDirection m_eDefaultWheelDirection = Forward;
-  
+
   /** Mouse wheel/desktop switching direction */
   static WheelDirection m_eWheelDirection;
 
