@@ -417,7 +417,7 @@ void LockProcess::createSaverWindow()
 {
     Visual* visual = CopyFromParent;
     XSetWindowAttributes attrs;
-    int flags = 0;
+    int flags = CWOverrideRedirect;
 #ifdef HAVE_GLXCHOOSEVISUAL
     if( mOpenGLVisual )
     {
@@ -461,6 +461,9 @@ void LockProcess::createSaverWindow()
         }
     }
 #endif
+
+    attrs.override_redirect = 1;
+    hide();
     Window w = XCreateWindow( x11Display(), RootWindow( x11Display(), x11Screen()),
         x(), y(), width(), height(), 0, x11Depth(), InputOutput, visual, flags, &attrs );
     create( w );
@@ -485,7 +488,6 @@ void LockProcess::createSaverWindow()
 
     setCursor( blankCursor );
     setGeometry(0, 0, mRootWidth, mRootHeight);
-    hide();
 
     kdDebug(1204) << "Saver window Id: " << winId() << endl;
 }
