@@ -27,6 +27,7 @@
 #include <kcrash.h>
 #include <kdebug.h>
 #include <kglobalsettings.h>
+#include <kglobal.h>
 #include <kconfig.h>
 #include <kmanagerselection.h>
 
@@ -57,6 +58,7 @@ static KCmdLineOptions options[] =
 // -----------------------------------------------------------------------------
 
 int kdesktop_screen_number = 0;
+QCString kdesktop_name, kicker_name, kwin_name;
 
 static void crashHandler(int sigId)
 {
@@ -136,13 +138,19 @@ extern "C" KDE_EXPORT int kdemain( int argc, char **argv )
 	}
     }
 
-    QCString appname;
-    if (kdesktop_screen_number == 0)
-	appname = "kdesktop";
-    else
-	appname.sprintf("kdesktop-screen-%d", kdesktop_screen_number);
+    KGlobal::locale()->setMainCatalogue("kdesktop");
 
-    KAboutData aboutData( appname.data(), I18N_NOOP("KDesktop"),
+    if (kdesktop_screen_number == 0) {
+        kdesktop_name = "kdesktop";
+        kicker_name = "kicker";
+        kwin_name = "kwin";
+    } else {
+        kdesktop_name.sprintf("kdesktop-screen-%d", kdesktop_screen_number);
+        kicker_name.sprintf("kicker-screen-%d", kdesktop_screen_number);
+        kwin_name.sprintf("kwin-screen-%d", kdesktop_screen_number);
+    }
+
+    KAboutData aboutData( kdesktop_name, I18N_NOOP("KDesktop"),
 			  version, description, KAboutData::License_GPL,
 			  "(c) 1998-2000, The KDesktop Authors");
     aboutData.addAuthor("David Faure", 0, "faure@kde.org");
@@ -171,7 +179,7 @@ extern "C" KDE_EXPORT int kdemain( int argc, char **argv )
     KUniqueApplication app;
     app.disableSessionManagement(); // Do SM, but don't restart.
 
-    KDesktopSettings::instance(appname + "rc");
+    KDesktopSettings::instance(kdesktop_name + "rc");
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
     bool x_root_hack = args->isSet("x-root");
@@ -205,4 +213,3 @@ extern "C" KDE_EXPORT int kdemain( int argc, char **argv )
 
     return app.exec();
 }
-
