@@ -24,8 +24,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef MINICLI_H
@@ -35,6 +35,7 @@
 #include <qstringlist.h>
 
 #include <kdialog.h>
+#include <kservice.h>
 
 class QTimer;
 class QWidget;
@@ -55,6 +56,7 @@ public:
   void clearHistory();
   
   virtual void show();
+  virtual QSize sizeHint() const;
 
 protected slots:
   virtual void accept();
@@ -82,8 +84,9 @@ private:
   int runCommand();
   void parseLine( bool final );
   QString terminalCommand (const QString&, const QString&);
-  void setMaxCommandBoxWidth();
   QString calculate(const QString &exp);
+  void notifyServiceStarted(KService::Ptr service);
+
 
   int m_iPriority;
   int m_iScheduler;
