@@ -1,6 +1,4 @@
 /* vi: ts=8 sts=4 sw=4
- *
- * $Id: sudlg.h,v 1.3 2000/03/09 20:19:09 jansen Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -17,7 +15,7 @@ class KDEsuDialog
     Q_OBJECT
 
 public:
-    KDEsuDialog(QCString user, QCString auth_user, bool enableKeep);
+    KDEsuDialog(QCString user, QCString auth_user, bool enableKeep, const QString& icon , bool withIgnoreButton=false);
     ~KDEsuDialog();
 
     enum ResultCodes { AsUser = 10 };
