@@ -65,9 +65,6 @@ extern int loginrestrictions( const char *Name, const int Mode, const char *Tty,
 extern int loginfailed( const char *User, const char *Host, const char *Tty );
 extern int loginsuccess( const char *User, const char *Host, const char *Tty, char **Msg );
 #else /* USE_PAM || _AIX */
-# ifdef USESHADOW
-#  include <shadow.h>
-# endif
 # ifdef KERBEROS
 #  include <sys/param.h>
 #  include <krb.h>
@@ -81,6 +78,10 @@ extern int loginsuccess( const char *User, const char *Host, const char *Tty, ch
 /* for expiration */
 # include <time.h>
 #endif /* USE_PAM || _AIX */
+#ifdef HAVE_SHADOW
+# include <shadow.h>
+#endif
+#include <signal.h>
 
 /*
  * Session data, mostly what struct verify_info was for
@@ -368,6 +369,9 @@ static int
 AccNoPass( const char *un )
 {
 	struct passwd *pw = 0;
+# ifdef HAVE_SHADOW /* (sic!) - not USESHADOW */
+	struct spwd *spw;
+# endif
 #else
 AccNoPass( const char *un, struct passwd *pw )
 {
@@ -391,6 +395,13 @@ AccNoPass( const char *un, struct passwd *pw )
 #if defined(USE_PAM) || defined(_AIX)
 			if (!(pw = getpwnam( un )))
 				return 0;
+			if (pw->pw_passwd[0] == '!' || pw->pw_passwd[0] == '*')
+				continue;
+# ifdef HAVE_SHADOW /* (sic!) - not USESHADOW */
+			if ((spw = getspnam( un )) &&
+			    (spw->sp_pwdp[0] == '!' || spw->sp_pwdp[0] == '*'))
+					continue;
+# endif
 #endif
 			if (pw->pw_uid)
 				return 1;
@@ -586,25 +597,31 @@ Verify( GConvFunc gconv, int rootok )
 
 	if (!(p = getpwnam( curuser ))) {
 		Debug( "getpwnam() failed.\n" );
+		gconv( GCONV_PASS, 0 );
 		V_RET_AUTH;
 	}
-# ifdef __linux__ /* only Linux? */
 	if (p->pw_passwd[0] == '!' || p->pw_passwd[0] == '*') {
 		Debug( "account is locked\n" );
+		gconv( GCONV_PASS, 0 );
 		V_RET_AUTH;
 	}
-# endif
 
 # ifdef USESHADOW
-	if ((sp = getspnam( curuser )))
+	if ((sp = getspnam( curuser ))) {
 		p->pw_passwd = sp->sp_pwdp;
-	else
+		if (p->pw_passwd[0] == '!' || p->pw_passwd[0] == '*') {
+			Debug( "account is locked\n" );
+			gconv( GCONV_PASS, 0 );
+			V_RET_AUTH;
+		}
+	} else
 		Debug( "getspnam() failed: %m. Are you root?\n" );
 # endif
 
 	if (!*p->pw_passwd) {
 		if (!td->allowNullPasswd) {
 			Debug( "denying user with empty password\n" );
+			gconv( GCONV_PASS, 0 );
 			V_RET_AUTH;
 		}
 		goto nplogin;
@@ -958,13 +975,16 @@ static const char *envvars[] = {
 
 
 #if defined(USE_PAM) && defined(HAVE_INITGROUPS)
-int num_saved_gids;
-gid_t saved_gids[NGROUPS];
+static int num_saved_gids;
+static gid_t *saved_gids;
 
 static int
 saveGids( void )
 {
-	if ((num_saved_gids = getgroups( as(saved_gids), saved_gids )) < 0) {
+	num_saved_gids = getgroups( 0, 0 );
+	if (!(saved_gids = Malloc( sizeof(gid_t) * num_saved_gids )))
+		return 0;
+	if (getgroups( num_saved_gids, saved_gids ) < 0) {
 		LogError( "saving groups failed: %m\n" );
 		return 0;
 	}
@@ -1348,6 +1368,7 @@ StartClient()
 		GSet( &mstrtalk );
 
 		setsid();
+		Signal( SIGINT, SIG_DFL );
 
 	/* Memory leaks are ok here as we exec() soon. */
 
@@ -1604,6 +1625,8 @@ SessionExit( int status )
 	int pretc;
 #endif
 
+	Signal( SIGTERM, SIG_IGN );
+
 	if (removeAuth) {
 		if (source( systemEnviron, td->reset, td_setup ))
 			LogError( "Cannot execute reset script %\"s\n", td->reset );
