@@ -824,6 +824,7 @@ processCtrl( const char *string, int len, int fd, struct display *d )
 						goto bust;
 					}
 					if (ar[6]) {
+						free( args );
 					  exce:
 						fLog( d, fd, "bad", "excess argument(s)" );
 						goto bust;
@@ -842,7 +843,7 @@ processCtrl( const char *string, int len, int fd, struct display *d )
 					break;
 				case remoteLogin:
 					if (di->serverPid != -1 && nuke)
-						TerminateProcess( di->serverPid, d->termSignal );
+						TerminateProcess( di->serverPid, di->termSignal );
 					break;
 				case reserve:
 					di->status = notRunning;
