@@ -1,4 +1,3 @@
-/* $TOG: reset.c /main/12 1998/02/09 13:56:00 kaleb $ */
 /*
 
 Copyright 1988, 1998  The Open Group
@@ -15,40 +14,40 @@ in all copies or substantial portions of the Software.
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR
+IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-Except as contained in this notice, the name of The Open Group shall
+Except as contained in this notice, the name of a copyright holder shall
 not be used in advertising or otherwise to promote the sale, use or
 other dealings in this Software without prior written authorization
-from The Open Group.
+from the copyright holder.
 
 */
-/* $XFree86: xc/programs/xdm/reset.c,v 1.2 1998/10/10 15:25:37 dawes Exp $ */
 
 /*
  * xdm - display manager daemon
- * Author:  Keith Packard, MIT X Consortium
+ * Author: Keith Packard, MIT X Consortium
  *
  * pseudoReset -- pretend to reset the server by killing all clients
  * with windows.  It will reset the server most of the time, unless
  * a client remains connected with no windows.
  */
 
-#define NEED_SIGNAL
 #include "dm.h"
 #include "dm_error.h"
 
 #include <X11/Xlib.h>
 
+#include <signal.h>
+
 /*ARGSUSED*/
 static int
-ignoreErrors (Display *dspl ATTR_UNUSED, XErrorEvent *event ATTR_UNUSED)
+ignoreErrors( Display *dspl ATTR_UNUSED, XErrorEvent *event ATTR_UNUSED )
 {
-	Debug ("ignoring error\n");
-	return 0;
+		Debug( "ignoring error\n" );
+		return 0;
 }
 
 /*
@@ -58,55 +57,55 @@ ignoreErrors (Display *dspl ATTR_UNUSED, XErrorEvent *event ATTR_UNUSED)
  */
 
 static void
-killWindows (Window window)
+killWindows( Window window )
 {
-	Window	root, parent, *children;
-	unsigned int child, nchildren = 0;
-	
-	while (XQueryTree (dpy, window, &root, &parent, &children, &nchildren)
-	       && nchildren > 0)
-	{
-		for (child = 0; child < nchildren; child++) {
-			Debug ("XKillClient %p\n", children[child]);
-			XKillClient (dpy, children[child]);
+		Window root, parent, *children;
+		unsigned int child, nchildren = 0;
+
+		while (XQueryTree( dpy, window, &root, &parent, &children, &nchildren )
+		       && nchildren > 0)
+		{
+				for (child = 0; child < nchildren; child++) {
+						Debug( "XKillClient %p\n", children[child] );
+						XKillClient( dpy, children[child] );
+				}
+				XFree( (char *)children );
 		}
-		XFree ((char *)children);
-	}
 }
 
-static Jmp_buf	resetJmp;
+static Jmp_buf resetJmp;
 
 /* ARGSUSED */
-static SIGVAL
-abortReset (int n ATTR_UNUSED)
+static void
+abortReset( int n ATTR_UNUSED )
 {
-	Longjmp (resetJmp, 1);
+		Longjmp( resetJmp, 1 );
 }
 
 /*
  * this display connection better not have any windows...
  */
- 
-void
-pseudoReset ()
-{
-	int	screen;
 
-	if (Setjmp (resetJmp)) {
-		LogError ("pseudoReset timeout\n");
-	} else {
-		(void) Signal (SIGALRM, abortReset);
-		(void) alarm (30);
-		XSetErrorHandler (ignoreErrors);
-		for (screen = 0; screen < ScreenCount (dpy); screen++) {
-			Debug ("pseudoReset screen %d\n", screen);
-			killWindows (RootWindow (dpy, screen));
+void
+pseudoReset()
+{
+		int screen;
+
+		if (Setjmp( resetJmp )) {
+				LogError( "pseudoReset timeout\n" );
+		} else {
+				(void)Signal( SIGALRM, abortReset );
+				(void)alarm( 30 );
+				XSetErrorHandler( ignoreErrors );
+				for (screen = 0; screen < ScreenCount (dpy); screen++) {
+						Debug( "pseudoReset screen %d\n", screen );
+						killWindows( RootWindow( dpy, screen ) );
+				}
+				Debug( "before XSync\n" );
+				XSync( dpy, False );
+				(void)alarm( 0 );
 		}
-		Debug ("before XSync\n");
-		XSync (dpy, False);
-		(void) alarm (0);
-	}
-	Signal (SIGALRM, SIG_DFL);
-	XSetErrorHandler ((XErrorHandler)0 );
-	Debug ("pseudoReset done\n");
+		Signal( SIGALRM, SIG_DFL );
+		XSetErrorHandler( (XErrorHandler)0 );
+		Debug( "pseudoReset done\n" );
 }
