@@ -4,10 +4,13 @@
  *
  ***********************************************************************/
 
+#include <qtimer.h>
+
 #include <kglobal.h>
 #include <klocale.h>
 #include <kdatepicker.h>
 #include <kdatetbl.h>
+#include <kdebug.h>
 
 #include "kdatecombo.h"
 
@@ -24,15 +27,17 @@ KDateCombo::KDateCombo(const QDate & date, QWidget *parent, const char *name) :
   initObject(date, parent, name);
 }
 
-void KDateCombo::initObject(const QDate & date, QWidget *parent, const char *name)
+void KDateCombo::initObject(const QDate & date, QWidget *, const char *)
 {
   clearValidator();
   popupFrame = new KPopupFrame(this, "popupFrame");
+  popupFrame->installEventFilter(this);
   datePicker = new KDatePicker(popupFrame, date, "datePicker");
   datePicker->setMinimumSize(datePicker->sizeHint());
+  datePicker->installEventFilter(this);
   popupFrame->setMainWidget(datePicker);
   setDate(date);
-  //connect(datePicker, SIGNAL(dateEntered(QDate)), this, SLOT(dateEnteredEvent(QDate)));
+
   connect(datePicker, SIGNAL(dateSelected(QDate)), this, SLOT(dateEnteredEvent(QDate)));
 }
 
@@ -71,6 +76,8 @@ bool KDateCombo::setDate(const QDate & newDate)
 
 void KDateCombo::dateEnteredEvent(QDate newDate)
 {
+  if (!newDate.isValid())
+     newDate = datePicker->date();
   popupFrame->hide();
   setDate(newDate);
 }
@@ -78,6 +85,7 @@ void KDateCombo::dateEnteredEvent(QDate newDate)
 void KDateCombo::mousePressEvent (QMouseEvent * e)
 {
   if (e->button() & QMouseEvent::LeftButton)
+  {
     if  (rect().contains( e->pos()))
     {
       QDate tempDate;
@@ -86,5 +94,38 @@ void KDateCombo::mousePressEvent (QMouseEvent * e)
       popupFrame->popup(mapToGlobal(QPoint(0, height())));
       //datePicker->setFocus();
     }
+  }
 }
 
+bool KDateCombo::eventFilter (QObject*, QEvent* e)
+{
+  if ( e->type() == QEvent::MouseButtonPress )
+  {
+      QMouseEvent *me = (QMouseEvent *)e;
+      QPoint p = mapFromGlobal( me->globalPos() );
+      if (rect().contains( p ) )
+      {
+        QTimer::singleShot(10, this, SLOT(dateEnteredEvent()));
+        return true;
+      }
+  }
+  else if ( e->type() == QEvent::KeyRelease )
+  {
+      QKeyEvent *k = (QKeyEvent *)e;
+      //Press return == pick selected date and close the combo
+      if((k->key()==Qt::Key_Return)||(k->key()==Qt::Key_Enter))
+      {
+        dateEnteredEvent(datePicker->date());
+        return true;
+      }
+      else if (k->key()==Qt::Key_Escape)
+      {
+        popupFrame->hide();
+        return true;
+      }
+      else
+        return false;
+  }
+
+  return false;
+}
