@@ -39,10 +39,11 @@ private:
    QDate & string2Date(const QString &, QDate * );
 
 protected:
-   virtual void mousePressEvent (QMouseEvent * e);
-
+  bool eventFilter (QObject*, QEvent*);
+  virtual void mousePressEvent (QMouseEvent * e);
+   
 protected slots:
-   void dateEnteredEvent(QDate);
+   void dateEnteredEvent(QDate d=QDate());
 };
 
 #endif
