@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef APPLICATION_H
 #define APPLICATION_H
@@ -24,12 +24,17 @@
 
 namespace KHC {
 
+class MainWindow;
+
 class Application : public KUniqueApplication
 {
   public:
     Application();
 
     virtual int newInstance();
+    
+  private:
+    MainWindow *mMainWindow;
 };
 
 }
