@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #include "glossary.h"
 #include "view.h"
@@ -174,7 +174,7 @@ void Glossary::meinprocExited( KProcess *meinproc )
 
 	KMainWindow *mainWindow = dynamic_cast<KMainWindow *>( kapp->mainWidget() );
 	Q_ASSERT( mainWindow );
-	mainWindow->statusBar()->message( i18n( "Rebuilding cache... done!" ), 2000 );
+	mainWindow->statusBar()->message( i18n( "Rebuilding cache... done." ), 2000 );
 
 	buildGlossaryTree();
 }
