@@ -471,7 +471,7 @@ void KCMHelpCenter::startIndexProcess()
     kdDebug() << "Run as root" << endl;
   }
 
-  *mProcess << "khc_indexbuilder";
+  *mProcess << locate("exe", "khc_indexbuilder");
   *mProcess << mCmdFile->name();
   *mProcess << Prefs::indexDirectory();
 
