@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef KHC_NAVIGATORITEM_H
 #define KHC_NAVIGATORITEM_H
@@ -49,6 +49,8 @@ class NavigatorItem : public QListViewItem
     TOC *toc() const { return mToc; }
 
     TOC *createTOC();
+  
+    void setOpen( bool open );
 
   private:
     void init( DocEntry * );
