@@ -57,7 +57,7 @@ void PluginTraverser::process( DocEntry *entry )
     return;
   }
 
-  if ( !entry->docExists() & !mNavigator->showMissingDocs() )
+  if ( !entry->docExists() && !mNavigator->showMissingDocs() )
     return;
 
 #if 0
