@@ -213,6 +213,8 @@ void Condition_list_widget::new_selected( int type_P )
 
 void Condition_list_widget::copy_pressed()
     {
+        if ( !selected_item )
+            return;
     conditions_listview->setSelected( create_listview_item(
         selected_item->condition()->copy( selected_item->condition()->parent()),
         selected_item->parent() ? NULL : conditions_listview,
@@ -221,13 +223,19 @@ void Condition_list_widget::copy_pressed()
     }
 
 void Condition_list_widget::delete_pressed()
+{
+    if ( selected_item )
     {
-    conditions.remove( selected_item->condition()); // we own it
-    delete selected_item; // CHECKME snad vyvola signaly pro enable()
+        conditions.remove( selected_item->condition()); // we own it
+        delete selected_item; // CHECKME snad vyvola signaly pro enable()
+        selected_item = NULL;
     }
+}
 
 void Condition_list_widget::modify_pressed()
     {
+        if ( !selected_item )
+            return;
     edit_listview_item( selected_item );
     }
 
