@@ -79,13 +79,13 @@ extern "C"
 // Settings
 
 KConfigDialogSingle::KConfigDialogSingle(Zone *zone, QWidget *parent,
-					 const char *name, Prefs * prefs,
-					 KDialogBase::DialogType dialogType,
+                                         const char *name, Prefs * prefs,
+                                         KDialogBase::DialogType dialogType,
                                          bool modal) :
     KConfigDialog(parent, name, prefs, dialogType,
-	          KDialogBase::Default | KDialogBase::Ok |
-	          KDialogBase::Apply | KDialogBase::Cancel,
-	          KDialogBase::Ok,
+                  KDialogBase::Default | KDialogBase::Ok |
+                  KDialogBase::Apply | KDialogBase::Cancel,
+                  KDialogBase::Ok,
                   modal), _prefs(prefs)
 {
     // As a temporary mesure until the kicker applet's app name is set to the
@@ -205,7 +205,7 @@ void SettingsWidgetImp::OkApply()
 
 
 ClockWidget::ClockWidget(ClockApplet *applet, Prefs* prefs)
-    : _applet(applet), _prefs(prefs)
+    : _applet(applet), _prefs(prefs), _force(false)
 {}
 
 
@@ -219,6 +219,7 @@ ClockWidget::~ClockWidget()
 PlainClock::PlainClock(ClockApplet *applet, Prefs *prefs, QWidget *parent, const char *name)
     : QLabel(parent, name), ClockWidget(applet, prefs)
 {
+    setBackgroundOrigin(AncestorOrigin);
     loadSettings();
     updateClock();
 }
@@ -241,28 +242,18 @@ void PlainClock::updateClock()
 {
     QString newStr = KGlobal::locale()->formatTime(_applet->clockGetTime(), _prefs->plainShowSeconds());
 
-    if (newStr != _timeStr) {
+    if (_force || newStr != _timeStr) {
         _timeStr = newStr;
         setText(_timeStr);
     }
 }
 
-void PlainClock::forceUpdate()
-{
-    _timeStr = QString::null;
-}
-
 void PlainClock::loadSettings()
 {
-
-    setFrameStyle(Panel | (_prefs->plainShowFrame() ? Sunken : 0));
+    setFrameStyle(_prefs->plainShowFrame() ? Panel | Sunken : NoFrame);
     setAlignment(AlignVCenter | AlignHCenter | SingleLine);
 
     setFont(_prefs->plainFont());
-    QPalette pal = palette();
-    pal.setColor( QColorGroup::Foreground, _prefs->plainForegroundColor());
-    pal.setColor( QColorGroup::Background, _prefs->plainBackgroundColor());
-    setPalette( pal );
 }
 
 bool PlainClock::showDate()
@@ -281,6 +272,8 @@ bool PlainClock::showDayOfWeek()
 DigitalClock::DigitalClock(ClockApplet *applet, Prefs *prefs, QWidget *parent, const char *name)
     : QLCDNumber(parent, name), ClockWidget(applet, prefs)
 {
+    setWFlags(WNoAutoErase);
+    setBackgroundOrigin(AncestorOrigin);
     loadSettings();
     updateClock();
 }
@@ -340,25 +333,22 @@ void DigitalClock::updateClock()
     else
         newStr.sprintf(format.latin1(), h, m);
 
-    if (newStr != _timeStr){
+    if (_force || newStr != _timeStr)
+    {
         _timeStr = newStr;
         setUpdatesEnabled( FALSE );
         display(_timeStr);
         setUpdatesEnabled( TRUE );
-        repaint( FALSE );
+        update();
     }
+    
     if (_prefs->digitalBlink())
         colon = !colon;
 }
 
-void DigitalClock::forceUpdate()
-{
-    _timeStr = QString::null;
-}
-
 void DigitalClock::loadSettings()
 {
-    setFrameStyle(Panel | (_prefs->digitalShowFrame() ? Sunken : 0));
+    setFrameStyle(_prefs->digitalShowFrame() ? Panel | Sunken : NoFrame);
     setMargin( 4 );
     setSegmentStyle(QLCDNumber::Flat);
 
@@ -385,7 +375,8 @@ void DigitalClock::paintEvent(QPaintEvent*)
     }
     else if (paletteBackgroundPixmap())
     {
-        p.drawTiledPixmap(0, 0, width(), height(), *paletteBackgroundPixmap());
+        QPoint offset = backgroundOffset();
+        p.drawTiledPixmap(0, 0, width(), height(), *paletteBackgroundPixmap(), offset.x(), offset.y());
     }
     else
     {
@@ -453,6 +444,8 @@ bool DigitalClock::showDayOfWeek()
 AnalogClock::AnalogClock(ClockApplet *applet, Prefs *prefs, QWidget *parent, const char *name)
     : QFrame(parent, name), ClockWidget(applet, prefs), _spPx(NULL)
 {
+    setWFlags(WNoAutoErase);
+    setBackgroundOrigin(AncestorOrigin);
     loadSettings();
 }
 
@@ -483,20 +476,17 @@ void AnalogClock::initBackgroundPixmap()
 
 void AnalogClock::updateClock()
 {
-    if (!_prefs->analogShowSeconds())
-         if (_time.minute() == _applet->clockGetTime().minute())
+    if (!_force)
+    {
+        if (!_prefs->analogShowSeconds() && (_time.minute() == _applet->clockGetTime().minute()))
             return;
-
+    }
+    
     _time = _applet->clockGetTime();
-    repaint( false ); //don't erase on redraw
+    update();
 }
 
-void AnalogClock::forceUpdate()
-{
-    _time = QTime(0,0);
-}
-
-void  AnalogClock::loadSettings()
+void AnalogClock::loadSettings()
 {
     if (_prefs->analogLCDStyle())
     {
@@ -508,12 +498,12 @@ void  AnalogClock::loadSettings()
         setBackgroundMode(NoBackground);
     }*/
 
-    setFrameStyle(Panel | (_prefs->analogShowFrame() ? Sunken : 0));
+    setFrameStyle(_prefs->analogShowFrame() ? Panel | Sunken : NoFrame);
     _time = _applet->clockGetTime();
     _spPx = new QPixmap(size().width() * _prefs->analogAntialias()+1,
                         size().height() * _prefs->analogAntialias()+1);
 
-    repaint();
+    update();
 }
 
 void AnalogClock::paintEvent( QPaintEvent * )
@@ -552,9 +542,13 @@ void AnalogClock::paintEvent( QPaintEvent * )
     }
     else if (paletteBackgroundPixmap())
     {
-        QImage bg = paletteBackgroundPixmap()->convertToImage();
-        bg =  bg.smoothScale(spWidth, spHeight);
-        paint.drawImage(0, 0, bg);
+        QPixmap bg(width(), height());
+        QPainter p(&bg);
+        QPoint offset = backgroundOffset();
+        p.drawTiledPixmap(0, 0, width(), height(), *paletteBackgroundPixmap(), offset.x(), offset.y());
+        p.end();
+        QImage bgImage = bg.convertToImage().scale(spWidth, spHeight);
+        paint.drawImage(0, 0, bgImage);
     }
     else
     {
@@ -566,13 +560,14 @@ void AnalogClock::paintEvent( QPaintEvent * )
 
     int d = KMIN(spWidth,spHeight) - (10 * aaFactor);
 
-    if (_prefs->analogLCDStyle()) {
-        paint.setPen( QColor(100,100,100) );
+    if (_prefs->analogLCDStyle()) 
+    {
+        paint.setPen( QPen(QColor(100,100,100), aaFactor) );
         paint.setBrush( QColor(100,100,100) );
     }
     else
     {
-        paint.setPen( _prefs->analogShadowColor() );
+        paint.setPen( QPen(_prefs->analogShadowColor(), aaFactor) );
         paint.setBrush( _prefs->analogShadowColor() );
     }
 
@@ -615,16 +610,16 @@ void AnalogClock::paintEvent( QPaintEvent * )
         // quadrante
         for ( int i=0 ; i < 12 ; i++ ) {
             paint.setWorldMatrix( matrix2 );
-            paint.drawLine( 460,0, 500,0 );	// draw hour lines
+            paint.drawLine( 460,0, 500,0 ); // draw hour lines
             // paint.drawEllipse( 450, -15, 30, 30 );
             matrix2.rotate( 30 );
         }
 
         if (_prefs->analogLCDStyle()) {
-            paint.setPen( Qt::black );
+            paint.setPen( QPen(Qt::black, aaFactor) );
             paint.setBrush( Qt::black );
         } else {
-            paint.setPen( _prefs->analogForegroundColor() );
+            paint.setPen( QPen(_prefs->analogForegroundColor(), aaFactor) );
             paint.setBrush( _prefs->analogForegroundColor() );
         }
 
@@ -680,6 +675,7 @@ bool AnalogClock::showDayOfWeek()
 FuzzyClock::FuzzyClock(ClockApplet *applet, Prefs *prefs, QWidget *parent, const char *name)
     : QFrame(parent, name), ClockWidget(applet, prefs)
 {
+    setBackgroundOrigin(AncestorOrigin);
     loadSettings();
     hourNames   << i18n("hour","one") << i18n("hour","two")
                 << i18n("hour","three") << i18n("hour","four") << i18n("hour","five")
@@ -724,7 +720,7 @@ FuzzyClock::FuzzyClock(ClockApplet *applet, Prefs *prefs, QWidget *parent, const
 
     _time = _applet->clockGetTime();
     alreadyDrawing=false;
-    repaint();
+    update();
 }
 
 void FuzzyClock::deleteMyself()
@@ -752,23 +748,20 @@ int FuzzyClock::preferedHeightForWidth(int ) const
 
 void FuzzyClock::updateClock()
 {
-  if (_time.hour() == _applet->clockGetTime().hour() &&
-      _time.minute() == _applet->clockGetTime().minute())
-     return;
+    if (!_force)
+    {
+        if (_time.hour() == _applet->clockGetTime().hour() &&
+            _time.minute() == _applet->clockGetTime().minute())
+        return;
+    }
 
-  _time = _applet->clockGetTime();
-  repaint();
-}
-
-void FuzzyClock::forceUpdate()
-{
-    _time = QTime(0,0);
+    _time = _applet->clockGetTime();
+    update();
 }
 
 void FuzzyClock::loadSettings()
 {
-    setFrameStyle(Panel | (_prefs->fuzzyShowFrame() ? Sunken : 0));
-    setBackgroundColor(_prefs->fuzzyBackgroundColor());
+    setFrameStyle(_prefs->fuzzyShowFrame() ? Panel | Sunken : 0);
 }
 
 void FuzzyClock::drawContents(QPainter *p)
@@ -874,6 +867,7 @@ ClockApplet::ClockApplet(const QString& configFile, Type t, int actions,
       m_layoutTimer(new QTimer(this)),
       m_layoutDelay(0),
       m_followBackgroundSetting(true),
+      m_dateFollowBackgroundSetting(true),
       TZoffset(0),
       _prefs(new Prefs(sharedConfig())),
       zone(new Zone(config())),
@@ -883,16 +877,16 @@ ClockApplet::ClockApplet(const QString& configFile, Type t, int actions,
     DCOPObject::setObjId("ClockApplet");
     _prefs->readConfig();
     configFileName = configFile.latin1();
-    setBackgroundOrigin( QWidget::AncestorOrigin );
+    setBackgroundOrigin(AncestorOrigin);
 
     _dayOfWeek = new QLabel(this);
     _dayOfWeek->setAlignment(AlignVCenter | AlignHCenter | WordBreak);
-    _dayOfWeek->setBackgroundOrigin( QWidget::AncestorOrigin );
+    _dayOfWeek->setBackgroundOrigin(AncestorOrigin);
     _dayOfWeek->installEventFilter(this);   // catch mouse clicks
 
     _date = new QLabel(this);
     _date->setAlignment(AlignVCenter | AlignHCenter | WordBreak);
-    _date->setBackgroundOrigin( QWidget::AncestorOrigin );
+    _date->setBackgroundOrigin(AncestorOrigin);
     _date->installEventFilter(this);   // catch mouse clicks
 
     connect(m_layoutTimer, SIGNAL(timeout()), this, SLOT(fixupLayout()));
@@ -1134,6 +1128,34 @@ void ClockApplet::preferences(bool timezone)
   dialog->show();
 }
 
+void ClockApplet::updateFollowBackground()
+{
+    QColor globalBgroundColor = KApplication::palette().active().background();
+    QColor bgColor;
+    
+    switch (_prefs->type())
+    {
+        case Prefs::EnumType::Plain:
+            bgColor = _prefs->plainBackgroundColor();
+            break;
+        case Prefs::EnumType::Analog:
+            bgColor = _prefs->analogBackgroundColor();
+            break;
+        case Prefs::EnumType::Fuzzy:
+            bgColor = _prefs->fuzzyBackgroundColor();
+            break;
+        case Prefs::EnumType::Digital:
+        default:
+            bgColor = _prefs->digitalBackgroundColor();
+            break;
+    }
+    
+    m_followBackgroundSetting = (bgColor == globalBgroundColor);
+    
+    bgColor = _prefs->dateBackgroundColor();
+    m_dateFollowBackgroundSetting = (bgColor == globalBgroundColor);
+}
+
 // DCOP interface
 void ClockApplet::reconfigure()
 {
@@ -1152,32 +1174,27 @@ void ClockApplet::reconfigure()
         delete _clock;
     }
 
-    QColor globalBgroundColor = KApplication::palette().active().background();
-    QColor bgroundColor;
     int shortInterval = 500;
     int updateInterval = 0;
+    
     switch (_prefs->type())
     {
         case Prefs::EnumType::Plain:
             _clock = new PlainClock(this, _prefs, this);
-            bgroundColor = _prefs->plainBackgroundColor();
             if (_prefs->plainShowSeconds())
                 updateInterval = shortInterval;
             break;
         case Prefs::EnumType::Analog:
             _clock = new AnalogClock(this, _prefs, this);
-            bgroundColor = _prefs->analogBackgroundColor();
             if (_prefs->analogShowSeconds())
                 updateInterval = shortInterval;
             break;
         case Prefs::EnumType::Fuzzy:
             _clock = new FuzzyClock(this, _prefs, this);
-            bgroundColor = _prefs->fuzzyBackgroundColor();
             break;
         case Prefs::EnumType::Digital:
         default:
             _clock = new DigitalClock(this, _prefs, this);
-            bgroundColor = _prefs->digitalBackgroundColor();
             if (_prefs->digitalShowSeconds() || _prefs->digitalBlink())
                 updateInterval = shortInterval;
             break;
@@ -1199,46 +1216,28 @@ void ClockApplet::reconfigure()
 
     _timer->start(updateInterval);
 
-    // See if the clock wants to show the day of week.
-    // use same font/color as for date
-    showDayOfWeek = _clock->showDayOfWeek();
-    if (showDayOfWeek)
-    {
-        _dayOfWeek->setBackgroundColor(_prefs->dateBackgroundColor());
-
-        _dayOfWeek->setFont(_prefs->dateFont());
-        QPalette pal = _dayOfWeek->palette();
-        pal.setColor(QColorGroup::Foreground, _prefs->dateForegroundColor());
-        pal.setColor(QColorGroup::Background, _prefs->dateBackgroundColor());
-        _dayOfWeek->setPalette(pal);
-    }
-
     // See if the clock wants to show the date.
     showDate = _clock->showDate();
-    _date->setBackgroundColor(_prefs->dateBackgroundColor());
-    _date->setFont(_prefs->dateFont());
-    QPalette pal = _date->palette();
-    pal.setColor(QColorGroup::Foreground, _prefs->dateForegroundColor());
-    pal.setColor(QColorGroup::Background, _prefs->dateBackgroundColor());
-    _date->setPalette(pal);
-    TZoffset = zone->calc_TZ_offset(zone->zone(), true);
-    updateDateLabel();
+    if (showDate)
+    {
+        TZoffset = zone->calc_TZ_offset(zone->zone(), true);
+        updateDateLabel();
+    }
+    
+    updateFollowBackground();
+    setBackground();
 
     // FIXME: this means you can't have a transparent clock but a non-transparent
     //        date or day =/
-    m_followBackgroundSetting = (bgroundColor == globalBgroundColor);
-    setBackground();
 
     _clock->widget()->installEventFilter(this);   // catch mouse clicks
     _clock->widget()->show();
 
     _clock->forceUpdate(); /* force repaint */
-    _clock->updateClock();
 
     if (showDayOfWeek)
     {
         _dayOfWeek->show();
-        _dayOfWeek->repaint(true);
     }
     else
     {
@@ -1248,7 +1247,6 @@ void ClockApplet::reconfigure()
     if (showDate || (zone->zoneIndex() != 0))
     {
         _date->show();
-        _date->repaint(true);
     }
     else
     {
@@ -1269,86 +1267,100 @@ void ClockApplet::setTimerTo60()
 
 void ClockApplet::setBackground()
 {
-    bool toreset = true;
-
-    // if the clock has the same background color that we do,
-    // let's propagate the background brush too
-    if (m_followBackgroundSetting)
+    QColor globalBgroundColor = KApplication::palette().active().background();
+    QColor fgColor, bgColor;
+    
+    if (!_clock)
+        return;
+    
+    switch (_prefs->type())
     {
-        _clock->widget()->setBackgroundOrigin(AncestorOrigin);
-        const QPixmap* brush = paletteBackgroundPixmap();
-
-        if (brush)
-        {
-            toreset = false;
-            _clock->widget()->setPaletteBackgroundPixmap(*brush);
-            QColor globalBgroundColor = KApplication::palette().active().background();
-
-            // See if the clock wants to show the day of week.
-            // use same font/color as for date
-            showDayOfWeek = _clock->showDayOfWeek();
-            if (showDayOfWeek)
-            {
-                _dayOfWeek->setBackgroundColor(_prefs->dateBackgroundColor());
-
-                _dayOfWeek->setFont(_prefs->dateFont());
-                QPalette pal = _dayOfWeek->palette();
-                pal.setColor(QColorGroup::Foreground, _prefs->dateForegroundColor());
-                pal.setColor(QColorGroup::Background, _prefs->dateBackgroundColor());
-                _dayOfWeek->setPalette(pal);
-
-                if (_dayOfWeek->paletteBackgroundColor() == globalBgroundColor)
-                {
-                    _dayOfWeek->setBackgroundOrigin(AncestorOrigin);
-                    _dayOfWeek->setPaletteBackgroundPixmap(*brush);
-                }
-            }
-
-            if (_date && _date->paletteBackgroundColor() == globalBgroundColor)
-            {
-                _date->setBackgroundOrigin(AncestorOrigin);
-                _date->setPaletteBackgroundPixmap(*brush);
-            }
-        }
+        case Prefs::EnumType::Plain:
+            bgColor = _prefs->plainBackgroundColor();
+            fgColor = _prefs->plainForegroundColor();
+            break;
+        case Prefs::EnumType::Analog:
+            bgColor = _prefs->analogBackgroundColor();
+            fgColor = _prefs->analogForegroundColor();
+            break;
+        case Prefs::EnumType::Fuzzy:
+            bgColor = _prefs->fuzzyBackgroundColor();
+            fgColor = _prefs->fuzzyForegroundColor();
+            break;
+        case Prefs::EnumType::Digital:
+        default:
+            bgColor = _prefs->digitalBackgroundColor();
+            fgColor = _prefs->digitalForegroundColor();
+            break;
     }
-
-    if (toreset)
+    
+    if (!m_followBackgroundSetting)
+        _clock->widget()->setPaletteBackgroundColor(bgColor);
+    else
+        _clock->widget()->unsetPalette();
+    _clock->widget()->setPaletteForegroundColor(fgColor);
+    
+    bgColor = _prefs->dateBackgroundColor();
+        
+    // See if the clock wants to show the day of week.
+    // use same font/color as for date
+    showDayOfWeek = _clock->showDayOfWeek();
+    if (showDayOfWeek)
     {
-        _clock->widget()->setPaletteBackgroundPixmap(QPixmap());
-        _date->setPaletteBackgroundPixmap(QPixmap());
-        _dayOfWeek->setPaletteBackgroundPixmap(QPixmap());
+        _dayOfWeek->setFont(_prefs->dateFont());
+        
+        if (!m_dateFollowBackgroundSetting)
+            _dayOfWeek->setBackgroundColor(bgColor);
+        else
+            _dayOfWeek->unsetPalette();
+        _dayOfWeek->setPaletteForegroundColor(_prefs->dateForegroundColor());
     }
+    
+    // See if the clock wants to show the date.
+    showDate = _clock->showDate();
+    _date->setFont(_prefs->dateFont());
+    
+    if (!m_dateFollowBackgroundSetting)
+        _date->setPaletteBackgroundColor(bgColor);
+    else
+        _date->unsetPalette();
+    _date->setPaletteForegroundColor(_prefs->dateForegroundColor());
 }
 
 void ClockApplet::globalPaletteChange()
 {
-    if (!m_followBackgroundSetting)
-    {
+    if (!m_dateFollowBackgroundSetting && !m_followBackgroundSetting)
         return;
-    }
-
-    // we need to makes sure we have the background color synced!
-    // otherwise when we switch color schemes again or restart kicker
-    // it might come back non-transparent
+    
     QColor globalBgroundColor = KApplication::palette().active().background();
-    switch (_prefs->type())
+    
+    if (m_dateFollowBackgroundSetting)
+        _prefs->setDateBackgroundColor(globalBgroundColor);
+    
+    if (m_followBackgroundSetting)
     {
-        case Prefs::EnumType::Plain:
-            _prefs->setPlainBackgroundColor(globalBgroundColor);
-            break;
-        case Prefs::EnumType::Analog:
-            _prefs->setAnalogBackgroundColor(globalBgroundColor);
-            break;
-        case Prefs::EnumType::Fuzzy:
-            _prefs->setFuzzyBackgroundColor(globalBgroundColor);
-            break;
-        case Prefs::EnumType::Digital:
-        default:
-            _prefs->setDigitalBackgroundColor(globalBgroundColor);
-            break;
-    }
+        // we need to makes sure we have the background color synced!
+        // otherwise when we switch color schemes again or restart kicker
+        // it might come back non-transparent
+        switch (_prefs->type())
+        {
+            case Prefs::EnumType::Plain:
+                _prefs->setPlainBackgroundColor(globalBgroundColor);
+                break;
+            case Prefs::EnumType::Analog:
+                _prefs->setAnalogBackgroundColor(globalBgroundColor);
+                break;
+            case Prefs::EnumType::Fuzzy:
+                _prefs->setFuzzyBackgroundColor(globalBgroundColor);
+                break;
+            case Prefs::EnumType::Digital:
+            default:
+                _prefs->setDigitalBackgroundColor(globalBgroundColor);
+                break;
+        }
+     }
+     
     _prefs->writeConfig();
-    setBackground();
 }
 
 void ClockApplet::slotUpdate()
@@ -1571,9 +1583,8 @@ void ClockApplet::showZone(int z)
 {
     zone->setZone(z);
     TZoffset = zone->calc_TZ_offset( zone->zone() );
-    _clock->updateClock();
-    _clock->forceUpdate(); /* force repaint */
     updateDateLabel();
+    _clock->forceUpdate(); /* force repaint */
 }
 
 void ClockApplet::nextZone()
@@ -1590,17 +1601,18 @@ void ClockApplet::prevZone()
 
 void ClockApplet::mousePressEvent(QMouseEvent *ev)
 {
-    switch (ev->button()) {
-	case QMouseEvent::LeftButton:
-		toggleCalendar();
-		break;
-	case QMouseEvent::RightButton:
-		openContextMenu();
-		break;
-	case QMouseEvent::MidButton:
-		nextZone();
-		QToolTip::remove(_clock->widget());
-		break;
+    switch (ev->button()) 
+    {
+        case QMouseEvent::LeftButton:
+            toggleCalendar();
+            break;
+        case QMouseEvent::RightButton:
+            openContextMenu();
+            break;
+        case QMouseEvent::MidButton:
+            nextZone();
+            QToolTip::remove(_clock->widget());
+            break;
         default:
             break;
     }
@@ -1608,10 +1620,6 @@ void ClockApplet::mousePressEvent(QMouseEvent *ev)
 
 void ClockApplet::wheelEvent(QWheelEvent* e)
 {
-    // delay the updating so it isn't so hurky-jurky
-    // when scrolling through the applet.
-    m_layoutDelay = 300;
-
     if (e->delta() < 0)
     {
         prevZone();
