@@ -37,6 +37,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kservice.h>
 #include <kurl.h>
 
+#include "simplebutton.h"
+
 class QPopupMenu;
 class KAction;
 class KToggleAction;
@@ -47,8 +49,8 @@ public:
     KURL kurl() const {return _kurl;};
     QString url() const {return _kurl.url();};
     QString menuId() const  {return _menuId;};
-    QString comment() const {return _comment;};
     QString genericName() const { return m_genericName; }
+    QString name() const { return m_name; }
     KService::Ptr service() const {return _service;};
     void run() const;
     QPixmap pixmap(mode_t _mode = 0, KIcon::Group _group = KIcon::Desktop,
@@ -57,13 +59,13 @@ public:
 private:
     KURL _kurl;
     QString _menuId;
-    QString _comment;
     QString m_genericName;
+    QString m_name;
     KService::Ptr _service;
 };
 
 
-class QuickButton: public QButton, public KickerTip::Client {
+class QuickButton: public SimpleButton, public KickerTip::Client {
     Q_OBJECT
 
 public:
@@ -90,11 +92,6 @@ signals:
     void stickyToggled(bool isSticky);
 
 protected:
-    void paintEvent(QPaintEvent *);
-    void drawButton(QPainter *p);
-    void drawButtonLabel(QPainter *p);
-    void enterEvent(QEvent *e);
-    void leaveEvent(QEvent *e);
     void mousePressEvent(QMouseEvent *e);
     void mouseMoveEvent(QMouseEvent *e);
     void resizeEvent(QResizeEvent *rsevent);
@@ -102,8 +99,7 @@ protected:
     void updateKickerTip(KickerTip::Data &data);
 
 protected slots:
-    void settingsChanged(int);
-    void iconChanged(int);
+    void slotIconChanged(int);
     void launch();
     void removeApp();
     void slotFlash();
