@@ -715,7 +715,7 @@ void QuickLauncher::refreshContents()
     }
     else
     {
-        idim=std::min(m_settings->iconDim(), d);
+        idim = std::min(m_settings->iconDim(), d - std::max((d/8)-1, 0) * 2);
     }
     m_space = std::max((idim/8)-1, 0);
     m_border = m_space;
