@@ -59,7 +59,7 @@ Lockout::Lockout( const QString& configFile, QWidget *parent, const char *name)
     KConfig *conf = config();
     conf->setGroup("lockout");
 
-    setFrameStyle(Panel | Sunken);
+    //setFrameStyle(Panel | Sunken);
     setBackgroundOrigin( AncestorOrigin );
 
     if ( orientation() == Horizontal )
@@ -71,11 +71,8 @@ Lockout::Lockout( const QString& configFile, QWidget *parent, const char *name)
     layout->setMargin( 0 );
     layout->setSpacing( 0 );
 
-    lockButton = new QToolButton( this, "lock");
-    logoutButton = new QToolButton( this, "logout");
-
-    lockButton->setBackgroundMode(X11ParentRelative);
-    logoutButton->setBackgroundMode(X11ParentRelative);
+    lockButton = new SimpleButton( this, "lock");
+    logoutButton = new SimpleButton( this, "logout");
 
     QToolTip::add( lockButton, i18n("Lock the session") );
     QToolTip::add( logoutButton, i18n("Log out") );
@@ -83,14 +80,8 @@ Lockout::Lockout( const QString& configFile, QWidget *parent, const char *name)
     lockButton->setPixmap( SmallIcon( "lock" ));
     logoutButton->setPixmap( SmallIcon( "exit" ));
 
-    lockButton->setMinimumSize( lockButton->pixmap()->size() );
-    logoutButton->setMinimumSize( logoutButton->pixmap()->size() );
-
     bTransparent = conf->readBoolEntry( "Transparent", bTransparent );
 
-    lockButton->setAutoRaise( bTransparent );
-    logoutButton->setAutoRaise( bTransparent );
-
     connect( lockButton, SIGNAL( clicked() ), SLOT( lock() ));
     connect( logoutButton, SIGNAL( clicked() ), SLOT( logout() ));
 
@@ -212,15 +203,17 @@ bool Lockout::eventFilter( QObject *o, QEvent *e )
                 popup->insertItem( SmallIcon( "lock" ), i18n("Lock Session"),
                                    this, SLOT( lock() ) );
                 popup->insertSeparator();
-                popup->insertItem( i18n( "&Transparent" ), 100 );
+                
+                i18n("&Transparent");
+                //popup->insertItem( i18n( "&Transparent" ), 100 );
                 popup->insertItem( SmallIcon( "configure" ),
                                    i18n( "&Configure Screen Saver..." ),
                                    this, SLOT( slotLockPrefs() ) );
 
-                popup->setItemChecked( 100, bTransparent );
-                popup->connectItem(100, this, SLOT( slotTransparent() ) );
-                if (conf->entryIsImmutable( "Transparent" ))
-                    popup->setItemEnabled( 100, false );
+                //popup->setItemChecked( 100, bTransparent );
+                //popup->connectItem(100, this, SLOT( slotTransparent() ) );
+                //if (conf->entryIsImmutable( "Transparent" ))
+                //    popup->setItemEnabled( 100, false );
                 popup->exec( me->globalPos() );
                 delete popup;
 
@@ -233,15 +226,15 @@ bool Lockout::eventFilter( QObject *o, QEvent *e )
                 popup->insertItem( SmallIcon( "exit" ), i18n("&Log Out..."),
                                    this, SLOT( logout() ) );
                 popup->insertSeparator();
-                popup->insertItem( i18n( "&Transparent" ), 100 );
+                //popup->insertItem( i18n( "&Transparent" ), 100 );
                 popup->insertItem( SmallIcon( "configure" ),
                                    i18n( "&Configure Session Manager..." ),
                                    this, SLOT( slotLogoutPrefs() ) );
 
-                popup->setItemChecked( 100, bTransparent );
-                popup->connectItem(100, this, SLOT( slotTransparent() ) );
-                if (conf->entryIsImmutable( "Transparent" ))
-                    popup->setItemEnabled( 100, false );
+                //popup->setItemChecked( 100, bTransparent );
+                //popup->connectItem(100, this, SLOT( slotTransparent() ) );
+                //if (conf->entryIsImmutable( "Transparent" ))
+                //    popup->setItemEnabled( 100, false );
                 popup->exec( me->globalPos() );
                 delete popup;
 
@@ -263,8 +256,6 @@ void Lockout::slotLockPrefs()
 void Lockout::slotTransparent()
 {
     bTransparent = !bTransparent;
-    lockButton->setAutoRaise( bTransparent );
-    logoutButton->setAutoRaise( bTransparent );
 
     KConfig* conf = config();
     conf->setGroup("lockout");
