@@ -2,25 +2,13 @@
 #define LOCKOUT_H
 
 #include <qevent.h>
-#include <qpushbutton.h>
 #include <qstring.h>
 #include <kpanelapplet.h>
 
+#include "simplebutton.h"
 
 class QBoxLayout;
-
-class TrayButton : public QPushButton
-{
-    Q_OBJECT
-
-public:
-    TrayButton(QWidget* parent, const char* name)
-        : QPushButton(parent, name) { }
-    virtual ~TrayButton() {}
-
-protected:
-    void drawButton(QPainter *p);
-};
+class QToolButton;
 
 class Lockout : public KPanelApplet
 {
@@ -42,21 +30,23 @@ protected:
 
     virtual bool eventFilter( QObject *, QEvent * );
 
-    virtual void preferences();
-
 private slots:
     void lock();
     void logout();
 
     void slotLockPrefs();
     void slotLogoutPrefs();
+    void slotTransparent();
+    void slotIconChanged();
 
 private:
     void propagateMouseEvent( QMouseEvent * );
     void checkLayout( int height ) const;
 
-    TrayButton *lockButton, *logoutButton;
+    SimpleButton *lockButton, *logoutButton;
     QBoxLayout *layout;
+
+    bool bTransparent;
 };
 
 #endif // LOCKOUT_H
