@@ -88,6 +88,7 @@ Applet::Applet( const QString& configFile_P, QWidget* parent_P )
         desktop_menu( false ),
         topEdgeOffset( 0 )
     {
+    setBackgroundOrigin(AncestorOrigin);
     dcopclient.registerAs( "menuapplet", false );
     // toolbarAppearanceChanged(int) is sent when changing macstyle
     connect( kapp, SIGNAL( toolbarAppearanceChanged( int )),
@@ -206,6 +207,8 @@ void Applet::activateMenu( MenuEmbed* embed_P )
     }
     emit updateLayout();
     }
+    
+    setBackground();
     }
 
 void Applet::updateMenuGeometry( MenuEmbed* embed )
@@ -273,13 +276,20 @@ void Applet::updateTopEdgeOffset()
     }
 
 void Applet::paletteChange(const QPalette & /* oldPalette */)
-    {
-    if( active_menu != NULL )
-        {
-	active_menu->hide();
-	active_menu->show();
-	}
-    }
+{
+    setBackground();
+}
+
+void Applet::moveEvent( QMoveEvent* )
+{
+    setBackground();
+}
+
+void Applet::setBackground()
+{
+    if (active_menu)
+        active_menu->setBackground();
+}
 
 void Applet::claimSelection()
     {
@@ -477,6 +487,25 @@ void MenuEmbed::setMinimumSize( int w, int h )
         }
 }
 
+void MenuEmbed::setBackground()
+{
+    const QPixmap *pbg = parentWidget()->backgroundPixmap();
+    
+    if (pbg)
+    {
+        QPixmap bg(width(), height());
+        bg.fill(parentWidget(), pos());
+        setPaletteBackgroundPixmap(bg);
+        setBackgroundOrigin(WidgetOrigin);
+    }
+    else
+        unsetPalette();
+    
+    hide();
+    show();
+    //XClearArea(x11Display(), embeddedWinId(), 0, 0, 0, 0, True);
+}
+
 } // namespace
 
 #include "menuapplet.moc"
