@@ -28,6 +28,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qintdict.h>
 
 #include <kpanelapplet.h>
+#include <kwin.h>
 
 #include "pagerbutton.h"
 #include "pagersettings.h"
@@ -38,11 +39,8 @@ class QTimer;
 
 class KProcess;
 class KWinModule;
-class KShadowEngine;
-
-namespace KWin { 
-    class WindowInfo;
-}
+class KTextShadowEngine;
+class KSelectionOwner;
 
 class PagerSettings;
 
@@ -61,7 +59,7 @@ public:
 
     KWin::WindowInfo* info( WId win );
     KWinModule* kwin() { return m_kwin; }
-    KShadowEngine* shadowEngine();
+    KTextShadowEngine* shadowEngine();
 
     void setActive( WId active ) { m_activeWindow = active; }
     WId activeWindow() { return m_activeWindow; }
@@ -78,12 +76,13 @@ public:
     Orientation orientation() const { return KPanelApplet::orientation(); }
     Direction popupDirection() { return KPanelApplet::popupDirection(); }
 
-    void emitRequestFocus(){ emit requestFocus(); }
+    void emitRequestFocus() { emit requestFocus(); }
 
     QPoint clickPos;
 
 public slots:
     void slotSetDesktop(int desktop);
+    void slotSetDesktopViewport(int desktop, const QPoint& viewport);
     void slotSetDesktopCount(int count);
     void slotButtonSelected(int desk );
     void slotActiveWindowChanged( WId win );
@@ -122,12 +121,14 @@ private:
     QButtonGroup *m_group;
 
     QGridLayout *m_layout;
+    bool m_useViewports;
     int desktopLayoutOrientation;
     int desktopLayoutX;
     int desktopLayoutY;
+    KSelectionOwner* m_desktopLayoutOwner;
 
     KWinModule *m_kwin;
-    KShadowEngine* m_shadowEngine;
+    KTextShadowEngine* m_shadowEngine;
 
     QPopupMenu *m_contextMenu;
     PagerSettings *m_settings;
