@@ -60,7 +60,7 @@ KPixmap* KMiniPagerButton::s_commonBgPixmap;
 
 KMiniPagerButton::KMiniPagerButton(int desk, bool useViewPorts, const QPoint& viewport,
         KMiniPager *parent, const char *name)
-    : QButton(parent, name, WRepaintNoErase),
+    : QButton(parent, name),
       m_pager(parent),
       m_desktop(desk),
       m_useViewports(useViewPorts),
@@ -69,10 +69,12 @@ KMiniPagerButton::KMiniPagerButton(int desk, bool useViewPorts, const QPoint& vi
       m_sharedPixmap(0),
       m_bgPixmap(0),
       m_isCommon(false),
-      m_currentWindow(0)
+      m_currentWindow(0),
+      m_inside(false)
 {
     setToggleButton(true);
     setAcceptDrops(true);
+    setWFlags(WNoAutoErase);
 
     setBackgroundOrigin(AncestorOrigin);
     installEventFilter(KickerTip::the());
@@ -323,23 +325,45 @@ void KMiniPagerButton::backgroundLoaded( bool loaded )
     }
 }
 
-void KMiniPagerButton::paintEvent(QPaintEvent *)
+void KMiniPagerButton::enterEvent(QEvent *)
+{
+    m_inside = true;
+    update();
+}
+
+void KMiniPagerButton::leaveEvent(QEvent *)
+{
+    m_inside = false;
+    update();
+}
+
+void KMiniPagerButton::drawButton(QPainter *bp)
 {
     int w = width();
     int h = height();
     bool on = isOn();
     bool down = isDown();
-    QPixmap buffer(w, h);
-    QBitmap mask(w, h, true);
-    QPainter bp(&buffer);
-    QPainter mp(&mask);
 
     QBrush background;
 
     bool liveBkgnd = m_pager->bgType() == PagerSettings::EnumBackgroundType::BgLive;
     bool transparent = m_pager->bgType() == PagerSettings::EnumBackgroundType::BgTransparent;
 
-    // background...
+    // background
+
+    if (backgroundPixmap())
+    {
+        QPoint pt = backgroundOffset();
+        bp->drawTiledPixmap(0, 0, width(), height(), *backgroundPixmap(), pt.x(), pt.y());
+    }
+    else
+    {
+        bp->fillRect(0, 0, width(), height(), paletteBackgroundColor());
+    }
+    
+
+    // desktop background
+    
     if (liveBkgnd)
     {
         if (m_bgPixmap && !m_bgPixmap->isNull())
@@ -348,11 +372,11 @@ void KMiniPagerButton::paintEvent(QPaintEvent *)
             {
                 KPixmap tmp = *m_bgPixmap;
                 KPixmapEffect::intensity(tmp, 0.33);
-                bp.drawPixmap(0, 0, tmp);
+                bp->drawPixmap(0, 0, tmp);
             }
             else
             {
-                bp.drawPixmap(0, 0, *m_bgPixmap);
+                bp->drawPixmap(0, 0, *m_bgPixmap);
             }
         }
         else
@@ -368,21 +392,19 @@ void KMiniPagerButton::paintEvent(QPaintEvent *)
             // transparent windows get an 1 pixel frame...
             if (on)
             {
-                bp.setPen(colorGroup().midlight());
+                bp->setPen(colorGroup().midlight());
             }
             else if (down)
             {
-                bp.setPen(KickerLib::blendColors(colorGroup().mid(),
+                bp->setPen(KickerLib::blendColors(colorGroup().mid(),
                                                  colorGroup().midlight()));
             }
             else
             {
-                bp.setPen(colorGroup().dark());
+                bp->setPen(colorGroup().dark());
             }
 
-            bp.drawRect(buffer.rect());
-            mp.setPen(Qt::color1);
-            mp.drawRect(buffer.rect());
+            bp->drawRect(0, 0, w, h);
         }
         else
         {
@@ -402,7 +424,7 @@ void KMiniPagerButton::paintEvent(QPaintEvent *)
                 background = colorGroup().brush(QColorGroup::Mid);
             }
 
-            bp.fillRect(buffer.rect(), background);
+            bp->fillRect(0, 0, w, h, background);
         }
     }
 
@@ -429,7 +451,7 @@ void KMiniPagerButton::paintEvent(QPaintEvent *)
                 if (kwin->activeWindow() == info->win())
                 {
                     QBrush brush = colorGroup().brush(QColorGroup::Highlight);
-                    qDrawShadeRect(&bp, r, colorGroup(), false, 1, 0, &brush);
+                    qDrawShadeRect(bp, r, colorGroup(), false, 1, 0, &brush);
                 }
                 else
                 {
@@ -440,13 +462,8 @@ void KMiniPagerButton::paintEvent(QPaintEvent *)
                         brush.setColor(brush.color().light(120));
                     }
 
-                    bp.fillRect(r, brush);
-                    qDrawShadeRect(&bp, r, colorGroup(), true, 1, 0);
-                }
-
-                if (transparent)
-                {
-                    mp.fillRect(r, Qt::color1);
+                    bp->fillRect(r, brush);
+                    qDrawShadeRect(bp, r, colorGroup(), true, 1, 0);
                 }
 
                 if (m_pager->windowIcons() && r.width() > 15 && r.height() > 15)
@@ -454,7 +471,7 @@ void KMiniPagerButton::paintEvent(QPaintEvent *)
                     QPixmap icon = KWin::icon(*it, 16, 16, true);
                     if (!icon.isNull())
                     {
-                        bp.drawPixmap(r.left() + ((r.width() - 16) / 2),
+                        bp->drawPixmap(r.left() + ((r.width() - 16) / 2),
                                       r.top() + ((r.height() - 16) / 2),
                                       icon);
                     }
@@ -469,43 +486,32 @@ void KMiniPagerButton::paintEvent(QPaintEvent *)
         // makes it look a bit more finished.
         if (on)
         {
-            bp.setPen(colorGroup().midlight());
+            bp->setPen(colorGroup().midlight());
         }
         else
         {
-            bp.setPen(colorGroup().mid());
+            bp->setPen(colorGroup().mid());
         }
 
-        bp.drawRect(0, 0, w, h);
-    }
-
-    mp.end();
-
-    if (transparent)
-    {
-        bp.end();
-        buffer.setMask(mask);
-        erase();
-
-        bp.begin(this);
-        bp.drawPixmap(0, 0, buffer);
+        bp->drawRect(0, 0, w, h);
     }
 
     if (m_pager->labelType() != PagerSettings::EnumLabelType::LabelNone)
     {
         QString label = (m_pager->labelType() == PagerSettings::EnumLabelType::LabelNumber) ?
                             QString::number(m_desktop) : m_desktopName;
-        bp.drawText(0, 0, w, h, AlignCenter, label);
+        
+        if (transparent || liveBkgnd)
+        {
+            bp->setPen(on ? colorGroup().midlight() : colorGroup().buttonText());
+            m_pager->shadowEngine()->drawText(*bp, QRect(0, 0, w, h), AlignCenter, label, size());
+        }
+        else
+            bp->drawText(0, 0, w, h, AlignCenter, label);
     }
-
-    if (!transparent)
-    {
-        bp.end();
-        bp.begin(this);
-        bp.drawPixmap(0, 0, buffer);
-    }
-
-    bp.end();
+    
+    if (m_inside)
+        KickerLib::drawBlendedRect(bp, QRect(1, 1, width() - 2, height() - 2), colorGroup().foreground());
 }
 
 void KMiniPagerButton::mousePressEvent(QMouseEvent * e)
