@@ -48,7 +48,6 @@ public:
     QString desktopName() { return m_desktopName; }
     void setDesktopName( QString name ) { m_desktopName = name; }
 
-//    void setOn( bool b ) { QButton::setOn( b ); }
     void rename();
     void backgroundChanged();
     void windowsChanged();
@@ -60,7 +59,9 @@ signals:
     void showMenu( const QPoint&, int );
 
 protected:
-    void paintEvent(QPaintEvent *ev);
+    void drawButton(QPainter *);
+    void enterEvent(QEvent*);
+    void leaveEvent(QEvent*);
     void resizeEvent(QResizeEvent *ev);
     void mousePressEvent(QMouseEvent *);
     void mouseReleaseEvent(QMouseEvent *);
@@ -104,6 +105,7 @@ private:
     bool m_isCommon;
 
     Task::Ptr m_currentWindow;
+    bool m_inside;
 };
 
 #endif
