@@ -24,6 +24,8 @@
 #include <kpanelapplet.h>
 #include <qstringlist.h>
 
+#include "simplebutton.h"
+
 class NaughtyProcessMonitor;
 class QPushButton;
 
@@ -67,7 +69,7 @@ class NaughtyApplet : public KPanelApplet
   private:
 
     NaughtyProcessMonitor * monitor_;
-    QPushButton * button_;
+    SimpleButton * button_;
     QStringList ignoreList_;
 };
 
