@@ -29,6 +29,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qlayout.h>
 #include <qpopupmenu.h>
 #include <qtimer.h>
+#include <qpixmap.h>
+#include <qevent.h>
+#include <qstyle.h>
+#include <qpainter.h>
 
 #include <dcopclient.h>
 #include <kapplication.h>
@@ -147,6 +151,8 @@ void SystemTrayApplet::initialize()
 
         XSendEvent (display, root, False, StructureNotifyMask, (XEvent *)&xev);
     }
+    
+    setBackground();
 }
 
 SystemTrayApplet::~SystemTrayApplet()
@@ -350,7 +356,7 @@ void SystemTrayApplet::showExpandButton(bool show)
     {
         if (!m_expandButton)
         {
-            m_expandButton = new SimpleButton(this, "expandButton");
+            m_expandButton = new SimpleArrowButton(this);
             m_expandButton->installEventFilter(this);
             refreshExpandButton();
 
@@ -435,8 +441,6 @@ void SystemTrayApplet::embedWindow( WId w, bool kde_tray )
 {
     TrayEmbed* emb = new TrayEmbed(kde_tray, this);
     emb->setAutoDelete(false);
-    emb->setBackgroundOrigin(AncestorOrigin);
-    emb->setBackgroundMode(X11ParentRelative);
 
     if (kde_tray)
     {
@@ -468,6 +472,7 @@ void SystemTrayApplet::embedWindow( WId w, bool kde_tray )
     else
     {
         emb->hide();
+        emb->setBackground();
         emb->show();
         m_shownWins.append(emb);
     }
@@ -510,6 +515,8 @@ void SystemTrayApplet::updateVisibleWins()
     {
         for (; emb != lastEmb; ++emb)
         {
+            (*emb)->hide();
+            (*emb)->setBackground();
             (*emb)->show();
         }
     }
@@ -541,21 +548,14 @@ void SystemTrayApplet::refreshExpandButton()
         return;
     }
 
-    Qt::Orientation o = orientation();
-    m_expandButton->setOrientation(o);
+    Qt::ArrowType a;
 
     if (orientation() == Vertical)
-    {
-        m_expandButton->setPixmap(m_showHidden ?
-            kapp->iconLoader()->loadIcon("1downarrow", KIcon::Panel, 16) :
-            kapp->iconLoader()->loadIcon("1uparrow", KIcon::Panel, 16));
-    }
+        a = m_showHidden ? Qt::DownArrow : Qt::UpArrow;
     else
-    {
-        m_expandButton->setPixmap((m_showHidden ^ kapp->reverseLayout()) ?
-            kapp->iconLoader()->loadIcon("1rightarrow", KIcon::Panel, 16) :
-            kapp->iconLoader()->loadIcon("1leftarrow", KIcon::Panel, 16));
-    }
+        a = (m_showHidden ^ kapp->reverseLayout()) ? Qt::RightArrow : Qt::LeftArrow;
+    
+    m_expandButton->setArrowType(a);
 }
 
 void SystemTrayApplet::expand()
@@ -736,32 +736,56 @@ bool SystemTrayApplet::eventFilter(QObject* watched, QEvent* e)
     return false;
 }
 
-int SystemTrayApplet::widthForHeight(int) const
+int SystemTrayApplet::widthForHeight(int h) const
 {
-    return sizeHint().width();
-}
-
-int SystemTrayApplet::heightForWidth(int) const
-{
-    return sizeHint().height();
-}
-
-void SystemTrayApplet::resizeEvent( QResizeEvent* )
-{
-    if (m_expandButton)
+    if (orientation() == Qt::Vertical)
     {
-        if (orientation() == Vertical)
-        {
-            m_expandButton->setFixedSize(width() - 4,
-                                         m_expandButton->sizeHint().height());
-        }
-        else
-        {
-            m_expandButton->setFixedSize(m_expandButton->sizeHint().width(),
-                                         height() - 4);
-        }
+        return width();
     }
 
+    int currentHeight = height();
+    int minHeight = m_iconSize + 4;
+    if (currentHeight != h && currentHeight != minHeight)
+    {
+        SystemTrayApplet* me = const_cast<SystemTrayApplet*>(this);
+        me->setMinimumSize(0, 0);
+        me->setMaximumSize(32767, 32767);
+        me->setFixedHeight(h);
+    }
+
+    return sizeHint().width(); 
+}
+
+int SystemTrayApplet::heightForWidth(int w) const
+{
+    if (orientation() == Qt::Horizontal)
+    {
+        return height();
+    }
+
+    int currentWidth = width();
+    int minSize = m_iconSize + 4;
+    if (currentWidth != w && currentWidth != minSize)
+    {
+        SystemTrayApplet* me = const_cast<SystemTrayApplet*>(this);
+        me->setMinimumSize(0, 0);
+        me->setMaximumSize(32767, 32767);
+        me->setFixedWidth(w);
+    }
+
+    return sizeHint().height(); 
+}
+
+void SystemTrayApplet::moveEvent( QMoveEvent* )
+{
+    setBackground();
+}
+
+
+void SystemTrayApplet::resizeEvent( QResizeEvent* e )
+{
+    KPanelApplet::resizeEvent(e);
+    
     layoutTray();
     // we need to give ourselves a chance to adjust our size before calling this
     QTimer::singleShot(0, this, SIGNAL(updateLayout()));
@@ -786,25 +810,47 @@ void SystemTrayApplet::layoutTray()
     delete m_layout;
     m_layout = new QGridLayout(this, 1, 1, 2, 2);
 
+    if (m_expandButton)
+    {
+        if (orientation() == Vertical)
+        {
+            m_expandButton->setFixedSize(width() - 4, m_expandButton->sizeHint().height());
+        }
+        else
+        {
+            m_expandButton->setFixedSize(m_expandButton->sizeHint().width(), height() - 4);
+        }
+    }
+
     // col = column or row, depends on orientation(),
     // the opposite direction of line
     int col = 0;
 
+    // 
+    // The margin and spacing specified in the layout implies that:
+    // [-- 2 pixels --] [-- first icon --] [-- 2 pixels --] ... [-- 2 pixels --] [-- last icon --] [-- 2 pixels --]
+    //
+    // So, if we say that iconWidth is the icon width plus the 2 pixels spacing, then the available width for the icons
+    // is the widget width minus 2 pixels margin. Forgetting these 2 pixels broke the layout algorithm in KDE <= 3.5.9.
+    //
+    // This fix makes the workaround in the heightForWidth() and widthForHeight() methods unneeded.
+    //
+
     if (orientation() == Vertical)
     {
         int iconWidth = maxIconWidth() + 2; // +2 for the margins that implied by the layout
-        heightWidth = width();
+        heightWidth = width() - 2;
         // to avoid nbrOfLines=0 we ensure heightWidth >= iconWidth!
         heightWidth = heightWidth < iconWidth ? iconWidth : heightWidth;
         nbrOfLines = heightWidth / iconWidth;
-
+        
         if (showExpandButton)
         {
             m_layout->addMultiCellWidget(m_expandButton,
-                                         col, col,
-                                         0, nbrOfLines,
+                                         0, 0,
+                                         0, nbrOfLines - 1,
                                          Qt::AlignHCenter | Qt::AlignVCenter);
-            ++col;
+            col = 1;
         }
 
         if (m_showHidden)
@@ -849,7 +895,7 @@ void SystemTrayApplet::layoutTray()
     else // horizontal
     {
         int iconHeight = maxIconHeight() + 2; // +2 for the margins that implied by the layout
-        heightWidth = height();
+        heightWidth = height() - 2;
         heightWidth = heightWidth < iconHeight ? iconHeight : heightWidth; // to avoid nbrOfLines=0
         nbrOfLines = heightWidth / iconHeight;
 
@@ -903,21 +949,54 @@ void SystemTrayApplet::layoutTray()
 
     setUpdatesEnabled(true);
     updateGeometry();
+    setBackground();
 }
 
 void SystemTrayApplet::paletteChange(const QPalette & /* oldPalette */)
 {
-    TrayEmbedList::const_iterator lastEmb = m_shownWins.end();
-    for (TrayEmbedList::const_iterator emb = m_shownWins.begin(); emb != lastEmb; ++emb)
-    {
-        (*emb)->hide();
-        (*emb)->show();
-    }
+    setBackground();
 }
 
+void SystemTrayApplet::setBackground()
+{
+    TrayEmbedList::const_iterator lastEmb;
+    
+    lastEmb = m_shownWins.end();
+    for (TrayEmbedList::const_iterator emb = m_shownWins.begin(); emb != lastEmb; ++emb)
+        (*emb)->setBackground();
+    
+    lastEmb = m_hiddenWins.end();
+    for (TrayEmbedList::const_iterator emb = m_hiddenWins.begin(); emb != lastEmb; ++emb)
+        (*emb)->setBackground();
+}
+
+
 TrayEmbed::TrayEmbed( bool kdeTray, QWidget* parent )
     : QXEmbed( parent ), kde_tray( kdeTray )
 {
-//    if( kde_tray ) // after QXEmbed reparents windows to the root window as unmapped.
-//        setMapAfterRelease( true ); // systray one will have to be made visible somehow
+    hide();
+    setBackground();
 }
+
+void TrayEmbed::setBackground()
+{
+    const QPixmap *pbg = parentWidget()->backgroundPixmap();
+    
+    if (pbg)
+    {
+        QPixmap bg(width(), height());
+        bg.fill(parentWidget(), pos());
+        setPaletteBackgroundPixmap(bg);
+        setBackgroundOrigin(WidgetOrigin);
+    }
+    else
+        unsetPalette();
+    
+    if (!isHidden())
+    {
+        hide(); 
+        show();
+    }
+    //XClearArea(x11Display(), embeddedWinId(), 0, 0, 0, 0, True);
+}
+
