@@ -42,7 +42,7 @@ k_dcop:
     int panelOrientation() { return static_cast<int>(orientation()); }
     int panelPosition() { return static_cast<int>(position()); }
     void setPanelSize(int size) { setSize(static_cast<Size>(size),true);}///slotSetSize(size); }
-    void configure() { setBackgroundTheme(); }
+    void configure();
 
 public:
     TaskBarExtension( const QString& configFile, Type t = Normal,
