@@ -100,50 +100,9 @@ void ButtonContainer::setBackground()
 {
     PanelButton* b = button();
     if (!b)
-    {
         return;
-    }
 
     b->unsetPalette();
-
-    if (!KickerSettings::transparent())
-    {
-        b->update();
-        return;
-    }
-
-    // inheritance is ButtonContainer - ScrollView - ContainerArea
-    ContainerArea* area = 0;
-    QObject* ancestor = parent();
-    while (ancestor && !area)
-    {
-        area = dynamic_cast<ContainerArea*>(ancestor);
-        ancestor = ancestor->parent();
-    }
-
-    const QPixmap* containerBG = area ? area->completeBackgroundPixmap()
-                                        : 0;
-
-    if (!containerBG || containerBG->isNull())
-    {
-        b->setPaletteBackgroundPixmap(QPixmap());
-    }
-    else
-    {
-        int srcx = x();
-        int srcy = y();
-        int buttonWidth = b->width();
-        int buttonHeight = b->height();
-
-        QPixmap buttonBackground(buttonWidth, buttonHeight);
-        copyBlt(&buttonBackground, 0, 0,
-                containerBG, srcx, srcy,
-                buttonWidth, buttonHeight);
-
-        b->setPaletteBackgroundPixmap(buttonBackground);
-    }
-
-    b->update();
 }
 
 void ButtonContainer::configure()
@@ -318,7 +277,6 @@ bool ButtonContainer::eventFilter(QObject *o, QEvent *e)
                 if (_button)
                 {
                     _button->properties();
-                    clearOpMenu();
                 }
                 break;
             default:
@@ -327,6 +285,7 @@ bool ButtonContainer::eventFilter(QObject *o, QEvent *e)
             KickerTip::enableTipping(true);
 
             Kicker::the()->setInsertionPoint(QPoint());
+            clearOpMenu();
             sentinal = false;
             return true;
         }
