@@ -33,6 +33,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qtooltip.h>
 #include <qvbox.h>
 #include <qxembed.h>
+#include <qcolor.h>
 
 #include <dcopclient.h>
 #include <kconfig.h>
@@ -67,7 +68,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ExtensionContainer::ExtensionContainer(const AppletInfo& info,
                                        const QString& extensionId,
                                        QWidget *parent)
-  : QFrame(parent, "ExtensionContainer", WStyle_Customize | WStyle_NoBorder),
+  : QFrame(parent, ("ExtensionContainer#" + extensionId).latin1(), WStyle_Customize | WStyle_NoBorder),
     m_settings(KSharedConfig::openConfig(info.configFile())),
     m_hideMode(ManualHide),
     m_unhideTriggeredAt(UnhideTrigger::None),
@@ -94,7 +95,7 @@ ExtensionContainer::ExtensionContainer(KPanelExtension* extension,
                                        const AppletInfo& info,
                                        const QString& extensionId,
                                        QWidget *parent)
-  : QFrame(parent, "ExtensionContainer", WStyle_Customize | WStyle_NoBorder),
+  : QFrame(parent, ("ExtensionContainer#" + extensionId).latin1(), WStyle_Customize | WStyle_NoBorder),
     m_settings(KSharedConfig::openConfig(info.configFile())),
     _autoHidden(false),
     _userHidden(Unhidden),
@@ -151,6 +152,9 @@ void ExtensionContainer::init()
 
     installEventFilter(this); // for mouse event handling
 
+    connect(Kicker::the(), SIGNAL(kdisplayPaletteChanged()), this, SLOT(updateHighlightColor()));
+    updateHighlightColor();
+
     // if we were hidden when kicker quit, let's start out hidden as well!
     KConfig *config = KGlobal::config();
     config->setGroup(extensionId());
@@ -493,7 +497,7 @@ void ExtensionContainer::moveMe()
         }
     }
 
-    UserRectSel::PanelStrut newStrut = UserRectSel::select(rects, rect().center());
+    UserRectSel::PanelStrut newStrut = UserRectSel::select(rects, rect().center(), m_highlightColor);
     arrange(newStrut.m_pos, newStrut.m_alignment, newStrut.m_screen);
 
     _is_lmb_down = false;
@@ -1331,6 +1335,15 @@ void ExtensionContainer::positionChange(KPanelExtension::Position p)
     update();
 }
 
+void ExtensionContainer::updateHighlightColor()
+{
+    KConfig *config = KGlobal::config();
+    config->setGroup("WM");
+    QColor color = QApplication::palette().active().highlight();
+    m_highlightColor = config->readColorEntry("activeBackground", &color);
+    update();
+}
+
 void ExtensionContainer::paintEvent(QPaintEvent *e)
 {
     QFrame::paintEvent(e);
@@ -1339,7 +1352,10 @@ void ExtensionContainer::paintEvent(QPaintEvent *e)
     {
         // draw border
         QPainter p(this);
-        p.setPen(palette().color(QPalette::Active, QColorGroup::Mid));
+        if (KickerSettings::useBackgroundTheme() && KickerSettings::colorizeBackground())
+            p.setPen(m_highlightColor);
+        else
+            p.setPen(palette().color(QPalette::Active, QColorGroup::Mid));
         p.drawRect(0, 0, width(), height());
     }
 }
@@ -1473,6 +1489,7 @@ void ExtensionContainer::arrange(KPanelExtension::Position p,
     }
 
     actuallyUpdateLayout();
+    
     if (positionChanged)
     {
         positionChange(p);
@@ -1671,7 +1688,7 @@ void ExtensionContainer::resetLayout()
 bool ExtensionContainer::needsBorder() const
 {
     return !KickerSettings::transparent();
-           // && !KickerSettings::useBackgroundTheme();
+           //&& !KickerSettings::useBackgroundTheme();
 }
 
 QSize ExtensionContainer::initialSize(KPanelExtension::Position p, QRect workArea) const
