@@ -93,16 +93,21 @@ ContainerArea::ContainerArea(KConfig* _c,
     viewport()->setBackgroundOrigin( AncestorOrigin );
 
     m_contents = new QWidget(viewport());
+    m_contents->setBackgroundOrigin(AncestorOrigin);
+    
     m_layout = new ContainerAreaLayout(m_contents);
-
+    
     // Install an event filter to propagate layout hints coming from
     // m_contents.
     m_contents->installEventFilter(this);
 
+    setBackground();
+
     connect(&_autoScrollTimer, SIGNAL(timeout()), SLOT(autoScroll()));
     connect(kapp, SIGNAL(kdisplayPaletteChanged()), SLOT(setBackground()));
     connect(Kicker::the(), SIGNAL(immutabilityChanged(bool)),
             SLOT(immutabilityChanged(bool)));
+    connect(this, SIGNAL(contentsMoving(int, int)), SLOT(setBackground()));
 }
 
 ContainerArea::~ContainerArea()
@@ -401,15 +406,15 @@ void ContainerArea::removeAllContainers()
 void ContainerArea::configure()
 {
     setBackground();
-    repaint();
-
+    
     for (BaseContainer::Iterator it = m_containers.begin();
          it != m_containers.end();
          ++it)
     {
         (*it)->configure();
     }
-    updateContainersBackground();
+    
+    resizeContents();
 }
 
 const QWidget* ContainerArea::addButton(const AppletInfo& info)
@@ -721,7 +726,7 @@ void ContainerArea::addContainer(BaseContainer* a, bool arrange, int index)
 
     if (dynamic_cast<AppletContainer*>(a))
     {
-        connect(a, SIGNAL(updateLayout()), SLOT(updateContainersBackground()));
+        connect(a, SIGNAL(updateLayout()), SLOT(resizeContents()));
     }
 
     a->configure(orientation(), popupDirection());
@@ -969,7 +974,7 @@ void ContainerArea::mouseMoveEvent(QMouseEvent *ev)
     if (orientation() == Horizontal)
     {
         int oldX = _moveAC->x() + _moveAC->moveOffset().x();
-        int x = ev->pos().x();
+        int x = ev->pos().x() + contentsX();
         if (ev->state() & ShiftButton)
         {
             m_layout->moveContainerPush(_moveAC, x - oldX);
@@ -1002,7 +1007,7 @@ void ContainerArea::mouseMoveEvent(QMouseEvent *ev)
     else
     {
         int oldY = _moveAC->y() + _moveAC->moveOffset().y();
-        int y = ev->pos().y();
+        int y = ev->pos().y() + contentsY();
         if (ev->state() & ShiftButton)
         {
             m_layout->moveContainerPush(_moveAC, y - oldY);
@@ -1013,6 +1018,9 @@ void ContainerArea::mouseMoveEvent(QMouseEvent *ev)
             // TODO: Scrolling
         }
     }
+
+    ensureVisible(ev->pos().x() + contentsX(), ev->pos().y() + contentsY());
+    updateContainersBackground();
 }
 
 int ContainerArea::position() const
@@ -1081,9 +1089,9 @@ void ContainerArea::dragEnterEvent(QDragEnterEvent *ev)
             BaseContainer* a = *it;
 
             if ((orientation() == Horizontal &&
-                 a->x() < ev->pos().x() - _dragMoveOffset.x()) ||
+                 a->x() < (ev->pos().x() + contentsX()) - _dragMoveOffset.x()) ||
                 (orientation() == Vertical &&
-                 a->y() < ev->pos().y() - _dragMoveOffset.y()))
+                 a->y() < (ev->pos().y() + contentsY()) - _dragMoveOffset.y()))
             {
                 _dragMoveAC = a;
                 break;
@@ -1093,11 +1101,11 @@ void ContainerArea::dragEnterEvent(QDragEnterEvent *ev)
 
     if (orientation() == Horizontal)
     {
-        moveDragIndicator((ev->pos() - _dragMoveOffset).x());
+        moveDragIndicator(ev->pos().x() + contentsX() - _dragMoveOffset.x());
     }
     else
     {
-        moveDragIndicator((ev->pos() - _dragMoveOffset).y());
+        moveDragIndicator(ev->pos().y() + contentsY() - _dragMoveOffset.y());
     }
 
     _dragIndicator->show();
@@ -1122,11 +1130,11 @@ void ContainerArea::dragMoveEvent(QDragMoveEvent* ev)
         // Align the container to the mouse position.
         if (orientation() == Horizontal)
         {
-            m_layout->moveContainerSwitch(_moveAC, ev->pos().x() - _moveAC->x());
+            m_layout->moveContainerSwitch(_moveAC, ev->pos().x() + contentsX() - _moveAC->x());
         }
         else
         {
-            m_layout->moveContainerSwitch(_moveAC, ev->pos().y() - _moveAC->y());
+            m_layout->moveContainerSwitch(_moveAC, ev->pos().y() + contentsY() - _moveAC->y());
         }
         return;
     }
@@ -1138,11 +1146,11 @@ void ContainerArea::dragMoveEvent(QDragMoveEvent* ev)
 
     if (orientation() == Horizontal)
     {
-        moveDragIndicator((ev->pos() - _dragMoveOffset).x());
+        moveDragIndicator(ev->pos().x() + contentsX() - _dragMoveOffset.x());
     }
     else
     {
-        moveDragIndicator((ev->pos() - _dragMoveOffset).y());
+        moveDragIndicator(ev->pos().y() + contentsY() - _dragMoveOffset.y());
     }
 }
 
@@ -1229,7 +1237,7 @@ void ContainerArea::dropEvent(QDropEvent *ev)
         _dragIndicator->hide();
         m_layout->setStretchEnabled(true);
 
-        if (info.type() & AppletInfo::BuiltinButton)
+        if (info.type() & AppletInfo::Button)
         {
             addButton(info);
         }
@@ -1271,31 +1279,35 @@ void ContainerArea::dropEvent(QDropEvent *ev)
             }
             a = new ServiceMenuButtonContainer(relPath, m_opMenu, m_contents);
         }
-	else if (url.isLocalFile()) {
-	    QFileInfo fi(url.path());
-	    if (fi.isDir()) { // directory
-		switch (PanelDirDropMenu().exec(mapToGlobal(ev->pos()))) {
-		case PanelDirDropMenu::Browser:
-		    a = new BrowserButtonContainer(url.path(), m_opMenu,
-		                   KMimeType::iconForURL(url), m_contents);
-		    break;
-		case PanelDirDropMenu::Url:
-		    a = new URLButtonContainer(url.url(), m_opMenu, m_contents);
-		    break;
-		default: ;
-		}
-	    }
-            else if ( KMimeType::findByURL(url)->name() == "application/x-desktop" ) {
-		// a local desktop file being dragged from an external program.
-		// Make a copy first.
-		KDesktopFile df(url.path());
-		KURL newUrl;
-		newUrl.setPath(KickerLib::copyDesktopFile(url));
-		if (df.readType() == "Link")
-		   a = new URLButtonContainer(newUrl.url(), m_opMenu, m_contents);
-		else
-		   a = new ServiceButtonContainer(newUrl.path(), m_opMenu, m_contents);
-	    }
+        else if (url.isLocalFile()) 
+        {
+            QFileInfo fi(url.path());
+            if (fi.isDir()) 
+            { // directory
+                switch (PanelDirDropMenu().exec(mapToGlobal(ev->pos()))) 
+                {
+                    case PanelDirDropMenu::Browser:
+                        a = new BrowserButtonContainer(url.path(), m_opMenu,
+                                    KMimeType::iconForURL(url), m_contents);
+                        break;
+                    case PanelDirDropMenu::Url:
+                        a = new URLButtonContainer(url.url(), m_opMenu, m_contents);
+                        break;
+                    default: ;
+                }
+            }
+            else if ( KMimeType::findByURL(url)->name() == "application/x-desktop" ) 
+            {
+                // a local desktop file being dragged from an external program.
+                // Make a copy first.
+                KDesktopFile df(url.path());
+                KURL newUrl;
+                newUrl.setPath(KickerLib::copyDesktopFile(url));
+                if (df.readType() == "Link")
+                    a = new URLButtonContainer(newUrl.url(), m_opMenu, m_contents);
+                else
+                    a = new ServiceButtonContainer(newUrl.path(), m_opMenu, m_contents);
+            }
             else if (fi.isExecutable())
             {
                 // non-KDE executable
@@ -1392,6 +1404,7 @@ void ContainerArea::viewportResizeEvent(QResizeEvent* ev)
 void ContainerArea::setBackground()
 {
     _bgSet = false;
+    m_cachedGeometry.clear();
 
     if (KickerSettings::transparent() &&
         (KickerSettings::menubarPanelTransparent() ||
@@ -1609,6 +1622,7 @@ void ContainerArea::updateBackground( const QPixmap& pm )
     _completeBg.resize(width(), height());
     _completeBg.fill(this, 0, 0);
 
+    m_cachedGeometry.clear();
     updateContainersBackground();
 }
 
@@ -1662,10 +1676,8 @@ void ContainerArea::setPosition(KPanelExtension::Position p)
         {
             resizeContents(width(), 0);
         }
-
-        setBackground();
     }
-
+    
     for (BaseContainer::ConstIterator it = m_containers.constBegin();
          it != m_containers.constEnd();
          ++it)
@@ -1679,6 +1691,10 @@ void ContainerArea::setPosition(KPanelExtension::Position p)
     }
 
     m_layout->setEnabled(true);
+    
+    setContentsPos(0, 0);
+    m_contents->move(0, 0);
+    setBackground();
 
     // container extension repaints for us!
     //repaint();
@@ -1737,10 +1753,33 @@ void ContainerArea::updateContainersBackground()
          it != m_containers.constEnd();
          ++it)
     {
-        (*it)->setBackground();
+    // A rather ugly hack. The code calls updateContainersBackground() all over
+    // the place even when nothing in fact has changed. Updating the background
+    // on every single unrelated change however means that e.g. the systray
+    // flickers when a new window is opened/closed (because the taskbar is relayouted,
+    // which triggers updateContainersBackground() even though the geometry
+    // of the taskbar does not change in fact. I'm apparently unable to fix this
+    // properly, so just cache the geometry and update background only when
+    // the geometry changes or when the background really changes (in which
+    // case the cached is cleared).
+        if( !m_cachedGeometry.contains( *it ))
+        {
+            m_cachedGeometry[ *it ] = QRect();
+            connect( *it, SIGNAL( destroyed()), SLOT( destroyCachedGeometry()));
+        }
+        if( m_cachedGeometry[ *it ] != (*it)->geometry())
+        {
+            (*it)->setBackground();
+            m_cachedGeometry[ *it ] = (*it)->geometry();
+        }
     }
 }
 
+void ContainerArea::destroyCachedGeometry()
+{
+    m_cachedGeometry.remove(const_cast<QWidget*>(static_cast<const QWidget*>(sender())));
+}
+
 BaseContainer::List ContainerArea::containers(const QString& type) const
 {
     if (type.isEmpty() || type == "All")
@@ -1880,6 +1919,13 @@ int ContainerArea::heightForWidth(int w) const
 }
 
 
+DragIndicator::DragIndicator(QWidget* parent, const char* name)
+    : QWidget(parent, name) 
+{
+    setBackgroundOrigin(AncestorOrigin);
+}
+
+
 void DragIndicator::paintEvent(QPaintEvent*)
 {
     QPainter painter(this);
