@@ -331,11 +331,10 @@ void PanelExtension::slotBuildOpMenu()
 
     m_opMenuBuilt = true;
     bool kickerImmutable = Kicker::the()->isImmutable();
+    bool isMenuBar = ExtensionManager::the()->isMenuBar(dynamic_cast<QWidget*>(parent()));
+
     if (!kickerImmutable)
     {
-        bool isMenuBar = ExtensionManager::the()->isMenuBar(
-                                            dynamic_cast<QWidget*>(parent()));
-
         // setup addmenu and removemenu
         if (_containerArea->canAddContainers())
         {
@@ -365,14 +364,6 @@ void PanelExtension::slotBuildOpMenu()
 
         _opMnu->insertItem(SmallIconSet("lock"), i18n("&Lock Panels"),
                 Kicker::the(), SLOT(toggleLock()));
-
-        if (!isMenuBar)
-        {
-            _opMnu->insertItem(SmallIconSet("configure"),
-                               i18n("&Configure Panel..."),
-                               this, SLOT(showConfig()));
-            _opMnu->insertSeparator();
-        }
     }
     else if (!Kicker::the()->isKioskImmutable())
     {
@@ -383,6 +374,14 @@ void PanelExtension::slotBuildOpMenu()
                            Kicker::the(), SLOT(toggleLock()));
     }
 
+    if (!isMenuBar && !Kicker::the()->isKioskImmutable())
+    {
+        _opMnu->insertItem(SmallIconSet("configure"),
+                            i18n("&Configure Panel..."),
+                            this, SLOT(showConfig()));
+        _opMnu->insertSeparator();
+    }
+    
     if (kapp->authorize("action/help"))
     {
         KHelpMenu* help = new KHelpMenu( this, KGlobal::instance()->aboutData(), false);
