@@ -32,6 +32,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qpalette.h>
 #include <qscrollview.h>
 #include <qtimer.h>
+#include <qsizepolicy.h>
 
 #include <kiconloader.h>
 #include <kdebug.h>
@@ -62,7 +63,7 @@ AppletWidget::AppletWidget(const AppletInfo& info, bool odd, QWidget *parent)
 {
     setFocusPolicy(QWidget::StrongFocus);
     setSelected(m_selected);
-
+    
     itemTitle->setText("<h3>" + info.name() + "</h3>");
     itemTitle->installEventFilter(this);
 
@@ -108,6 +109,8 @@ bool AppletWidget::eventFilter(QObject*, QEvent* e)
             }
 
             drag->dragCopy();
+            
+            return true;
         }
     }
     else if (e->type() == QEvent::MouseButtonRelease)
@@ -152,6 +155,9 @@ void AppletWidget::mousePressEvent(QMouseEvent *e)
         emit clicked(this);
         m_dragStart = e->pos();
     }
+
+    setFocus();
+    QWidget::mousePressEvent(e);
 }
 
 void AppletWidget::mouseMoveEvent(QMouseEvent *e)
@@ -172,9 +178,10 @@ void AppletWidget::mouseMoveEvent(QMouseEvent *e)
     }
 }
 
-void AppletWidget::mouseReleaseEvent(QMouseEvent *)
+void AppletWidget::mouseReleaseEvent(QMouseEvent *e)
 {
     m_dragStart = QPoint();
+    QWidget::mouseReleaseEvent(e);
 }
 
 void AppletWidget::mouseDoubleClickEvent(QMouseEvent *e)
@@ -228,10 +235,14 @@ AddAppletDialog::AddAppletDialog(ContainerArea* cArea,
       m_selectedApplet(0),
       m_containerArea(cArea),
       m_insertionPoint(Kicker::the()->insertionPoint()),
-      m_closing(false)
+      m_closing(false),
+      m_searchDelay(new QTimer(this))
 {
     m_mainWidget = new AppletView(this, "AddAppletDialog::m_mainWidget");
-    m_mainWidget->appletScrollView->setResizePolicy(QScrollView::AutoOneFit);
+    m_mainWidget->appletScrollView->setResizePolicy(QScrollView::Manual);
+    m_mainWidget->appletScrollView->setHScrollBarMode(QScrollView::AlwaysOff);
+    m_mainWidget->appletScrollView->viewport()->setPaletteBackgroundColor(KGlobalSettings::baseColor());
+
     setMainWidget(m_mainWidget);
 
     resize(configDialogSize("AddAppletDialog Settings"));
@@ -243,12 +254,14 @@ AddAppletDialog::AddAppletDialog(ContainerArea* cArea,
     m_mainWidget->appletInstall->setGuiItem(addGuiItem);
     m_mainWidget->closeButton->setGuiItem(KStdGuiItem::close());
 
-    connect(m_mainWidget->appletSearch, SIGNAL(textChanged(const QString&)), this, SLOT(search(const QString&)));
+    connect(m_mainWidget->appletSearch, SIGNAL(textChanged(const QString&)), this, SLOT(delayedSearch()));
+    connect(m_searchDelay, SIGNAL(timeout()), this, SLOT(search()));
     connect(m_mainWidget->appletFilter, SIGNAL(activated(int)), this, SLOT(filter(int)));
     connect(m_mainWidget->appletInstall, SIGNAL(clicked()), this, SLOT(addCurrentApplet()));
     connect(m_mainWidget->closeButton, SIGNAL(clicked()), this, SLOT(close()));
 
     m_selectedType = AppletInfo::Undefined;
+    m_appletBox = 0;
 
     QTimer::singleShot(0, this, SLOT(populateApplets()));
 }
@@ -266,15 +279,45 @@ void AddAppletDialog::closeEvent(QCloseEvent* e)
     KDialogBase::closeEvent(e);
 }
 
+void AddAppletDialog::resizeAppletView()
+{
+    int w, h;
+    QScrollView *v = m_mainWidget->appletScrollView;
+    
+    if (m_closing)
+        return;
+    
+    for (int i = 0; i < 3; i++)
+    {
+        m_appletBox->layout()->activate();
+        w = v->visibleWidth();
+        h = m_appletBox->layout()->minimumSize().height();
+        v->resizeContents(w, QMAX(h, v->visibleHeight()));
+        if (w == m_appletBox->width() && h == m_appletBox->height())
+        break;
+        m_appletBox->resize(w, h);
+        v->updateScrollBars();
+    }
+}
+
+bool AddAppletDialog::eventFilter(QObject *o, QEvent *e)
+{
+    if (e->type() == QEvent::Resize)
+        QTimer::singleShot(0, this, SLOT(resizeAppletView()));
+    
+    return QObject::eventFilter(o, e);
+}
+
 void AddAppletDialog::populateApplets()
 {
-    QWidget *appletBox = new QWidget(m_mainWidget->appletScrollView->viewport());
-    appletBox->setPaletteBackgroundColor(KGlobalSettings::baseColor());
-    m_mainWidget->appletScrollView->addChild(appletBox, 0, 0);
-    appletBox->show();
-    QVBoxLayout* layout = new QVBoxLayout(appletBox);
-    layout->addStretch(1);
+    m_appletBox = new QWidget(m_mainWidget->appletScrollView->viewport());
+    m_appletBox->setPaletteBackgroundColor(KGlobalSettings::baseColor());
+    m_mainWidget->appletScrollView->addChild(m_appletBox, 0, 0);
+    m_appletBox->show();
+    QVBoxLayout* layout = new QVBoxLayout(m_appletBox);
     layout->setMargin(0);
+    
+    m_mainWidget->appletScrollView->installEventFilter(this);
 
     /* Three steps
      * - First we load the applets
@@ -297,6 +340,7 @@ void AddAppletDialog::populateApplets()
     int i = 0;
     bool odd = true;
     QWidget* prevTabWidget = m_mainWidget->appletFilter;
+
     for (AppletInfo::List::iterator it = appletInfoList.begin();
          !m_closing && it != appletInfoList.end();
          ++i)
@@ -310,7 +354,7 @@ void AddAppletDialog::populateApplets()
             continue;
         }
 
-        AppletWidget *itemWidget = new AppletWidget(*it, odd, appletBox);
+        AppletWidget *itemWidget = new AppletWidget(*it, odd, m_appletBox);
 
         if (m_mainWidget->appletSearch->text().isEmpty() ||
             appletMatchesSearch(itemWidget, m_mainWidget->appletSearch->text()))
@@ -333,9 +377,6 @@ void AddAppletDialog::populateApplets()
         connect(itemWidget, SIGNAL(doubleClicked(AppletWidget*)),
                 this, SLOT(addApplet(AppletWidget*)));
 
-        // Avoid to freeze the inferface
-        qApp->processEvents();
-
         if (m_closing)
         {
             return;
@@ -343,7 +384,9 @@ void AddAppletDialog::populateApplets()
 
         ++it;
     }
-
+    
+    resizeAppletView();
+    
     m_mainWidget->closeButton->setEnabled(true);
 }
 
@@ -436,7 +479,7 @@ bool AddAppletDialog::appletMatchesSearch(const AppletWidget* w,
         w->info().isUniqueApplet() &&
         PluginManager::the()->hasInstance(w->info()))
     {
-            return false;
+        return false;
     }
 
     return (m_selectedType == AppletInfo::Undefined ||
@@ -445,12 +488,22 @@ bool AddAppletDialog::appletMatchesSearch(const AppletWidget* w,
             w->info().comment().contains(s, false));
 }
 
-void AddAppletDialog::search(const QString& s)
+void AddAppletDialog::delayedSearch()
 {
+    if (!m_searchDelay->isActive())
+    {
+        m_searchDelay->start(300, true);
+    }
+}
+
+void AddAppletDialog::search()
+{
+    QString s = m_mainWidget->appletSearch->text();
     bool odd = true;
     AppletWidget::List::const_iterator it = m_appletWidgetList.constBegin();
+    AppletWidget::List::const_iterator itEnd = m_appletWidgetList.constEnd();
 
-    for (; it != m_appletWidgetList.constEnd(); ++it)
+    for (; it != itEnd; ++it)
     {
         AppletWidget* w = *it;
         if (appletMatchesSearch(w, s))
@@ -464,6 +517,8 @@ void AddAppletDialog::search(const QString& s)
             w->hide();
         }
     }
+    
+    QTimer::singleShot(0, this, SLOT(resizeAppletView()));
 }
 
 void AddAppletDialog::filter(int i)
@@ -479,25 +534,7 @@ void AddAppletDialog::filter(int i)
         m_selectedType = AppletInfo::Button;
     }
 
-    AppletWidget::List::const_iterator it = m_appletWidgetList.constBegin();
-
-    bool odd = true;
-    QString searchString = m_mainWidget->appletSearch->text();
-    for (; it != m_appletWidgetList.constEnd(); ++it)
-    {
-        AppletWidget* w = *it;
-        if (appletMatchesSearch(w, searchString))
-        {
-            w->setOdd(odd);
-            w->show();
-            odd = !odd;
-        }
-        else
-        {
-            w->hide();
-        }
-    }
-
+    search();
 }
 
 #include "addapplet.moc"
