@@ -311,7 +311,7 @@ void PanelServiceMenu::insertMenuItem(KService::Ptr & s, int nId,
             {
                 if (comment.find(serviceName, 0, true) == -1)
                 {
-                    serviceName = QString("%1 %2").arg(serviceName, comment);
+                    serviceName = i18n("Entries in K-menu: %1 app name, %2 description", "%1 - %2").arg(serviceName, comment);
                 }
                 else
                 {
@@ -321,7 +321,7 @@ void PanelServiceMenu::insertMenuItem(KService::Ptr & s, int nId,
         }
         else if (KickerSettings::menuEntryFormat() == KickerSettings::DescriptionAndName)
         {
-            serviceName = QString("%1 (%2)").arg(comment, serviceName);
+            serviceName = i18n("Entries in K-menu: %1 description, %2 app name", "%1 (%2)").arg(comment, serviceName);
         }
         else if (KickerSettings::menuEntryFormat() == KickerSettings::DescriptionOnly)
         {
@@ -588,10 +588,12 @@ void PanelServiceMenu::slotContextMenu(int selected)
 	    break;
 
         case PutIntoRunDialog: {
+            close();
             QCString appname = "kdesktop";
             if ( kicker_screen_number )
                 appname.sprintf("kdesktop-screen-%d", kicker_screen_number);
             service = static_cast<KService *>(contextKSycocaEntry_);
+            kapp->updateRemoteUserTimestamp( appname );
             kapp->dcopClient()->send(appname, "default", "popupExecuteCommand(QString)", service->exec());
             break;
         }
