@@ -26,6 +26,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qfile.h>
 #include <qpopupmenu.h>
 #include <qregexp.h>
+#include <qpainter.h>
 
 #include <kiconeffect.h>
 #include <kiconloader.h>
@@ -452,5 +453,25 @@ QIconSet menuIconSet(const QString& icon)
     return iconset;
 }
 
+void drawBlendedRect(QPainter *p, const QRect &r, const QColor &color, int alpha)
+{
+    static QPixmap pix;
+    static QColor last_color = Qt::black;
+    static int last_alpha = 0;
+    
+    if (pix.isNull() || last_color != color || last_alpha != alpha)
+    {
+        QImage img(16, 16, 32);
+        img.setAlphaBuffer(false);
+        img.fill(((uint)(alpha & 0xFF) << 24) | (color.rgb() & 0xFFFFFF));
+        img.setAlphaBuffer(true);
+        pix.convertFromImage(img);
+        last_color = color;
+        last_alpha = alpha;
+    }
+
+    p->drawTiledPixmap(r, pix);
+}
+
 } // namespace
 
