@@ -69,6 +69,8 @@ PanelButton::PanelButton( QWidget* parent, const char* name )
       m_size((KIcon::StdSizes)-1),
       m_fontPercent(0.40)
 {
+    setBackgroundOrigin(AncestorOrigin);
+    setWFlags(WNoAutoErase);
     KGlobal::locale()->insertCatalogue("libkicker");
     calculateIconSize();
     setAcceptDrops(true);
@@ -503,6 +505,8 @@ void PanelButton::resizeEvent(QResizeEvent*)
 
 void PanelButton::drawButton(QPainter *p)
 {
+    const QPixmap& tile = (isDown() || isOn()) ? m_down : m_up;
+    
     if (m_tileColor.isValid())
     {
         p->fillRect(rect(), m_tileColor);
@@ -512,10 +516,12 @@ void PanelButton::drawButton(QPainter *p)
     {
         // Draw the background. This is always needed, even when using tiles,
         // because they don't have to cover the entire button.
-        p->drawPixmap(0, 0, *paletteBackgroundPixmap());
+        QPoint offset = backgroundOffset();
+        int ox = offset.x();
+        int oy = offset.y();
+        p->drawTiledPixmap( 0, 0, width(), height(),*paletteBackgroundPixmap(), ox, oy);
     }
 
-    const QPixmap& tile = (isDown() || isOn()) ? m_down : m_up;
     if (!tile.isNull())
     {
         // Draw the tile.
