@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include <iostream>
@@ -609,10 +609,10 @@ void TOM::removeTask()
 {
     // TODO: write this change out to the appropriate config file
     QString task = KPopupMenu::contextMenuFocus()->text(KPopupMenu::contextMenuFocusItem());
-    if (KMessageBox::warningYesNo(this,
+    if (KMessageBox::warningContinueCancel(this,
                                   i18n("<qt>Are you sure you want to remove the <strong>%1</strong> task?<p>"
                                         "<em>Tip: You can restore the task after it has been removed by selecting the &quot;Modify These Tasks&quot; entry</em></qt>").arg(task),
-                                  i18n("Remove Task?")) == KMessageBox::Yes)
+                                  i18n("Remove Task?"),KStdGuiItem::del()) == KMessageBox::Continue)
     {
         m_tasks.remove(KPopupMenu::contextMenuFocusItem());
         KPopupMenu::contextMenuFocus()->removeItem(KPopupMenu::contextMenuFocusItem());
