@@ -30,17 +30,18 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <kapplication.h>
 #include <kglobal.h>
+#include <klibloader.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kcmdlineargs.h>
 #include <kdebug.h>
+#include <kmessagebox.h>
 #include <kpanelapplet.h>
 #include <kaboutdata.h>
 #include <qfileinfo.h>
 #include <dcopclient.h>
 #include <kwin.h>
 
-#include "pluginloader.h"
 #include "appletinfo.h"
 
 #include "appletproxy.h"
@@ -48,7 +49,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <X11/Xlib.h>
 
-// FIXME: Ugly, remove when cleaning up
 KPanelApplet::Position directionToPosition( int d )
 {
     switch( d ) {
@@ -68,9 +68,9 @@ static KCmdLineOptions options[] =
   KCmdLineLastOption
 };
 
-extern "C" int kdemain( int argc, char ** argv )
+extern "C" KDE_EXPORT int kdemain( int argc, char ** argv )
 {
-    KAboutData aboutData( "appletproxy", I18N_NOOP("Panel applet proxy.")
+    KAboutData aboutData( "kicker", I18N_NOOP("Panel applet proxy.")
                           , "v0.1.0"
                           ,I18N_NOOP("Panel applet proxy.")
                           , KAboutData::License_BSD
@@ -128,11 +128,17 @@ AppletProxy::AppletProxy(QObject* parent, const char* name)
     // try to attach to DCOP server
     if (!kapp->dcopClient()->attach()) {
 	kdError() << "Failed to attach to DCOP server." << endl;
+        KMessageBox::error(0,
+                           i18n("The applet proxy could not be started due to DCOP communication problems."),
+                           i18n("Applet Loading Error"));
 	exit(0);
     }
 
     if (!kapp->dcopClient()->registerAs("applet_proxy", true)) {
 	kdError() << "Failed to register at DCOP server." << endl;
+        KMessageBox::error(0,
+                           i18n("The applet proxy could not be started due to DCOP registration problems."),
+                           i18n("Applet Loading Error"));
 	exit(0);
     }
 
@@ -163,6 +169,9 @@ void AppletProxy::loadApplet(const QString& desktopFile, const QString& configFi
     // does the config file exist?
     if (df.isNull() || !file.exists()) {
 	kdError() << "Failed to locate applet desktop file: " << desktopFile << endl;
+        KMessageBox::error(0,
+                           i18n("The applet proxy could not load the applet information from %1.").arg(desktopFile), 
+                           i18n("Applet Loading Error"));
 	exit(0);
     }
 
@@ -175,11 +184,15 @@ void AppletProxy::loadApplet(const QString& desktopFile, const QString& configFi
 	_info->setConfigFile(configFile);
 
     // load applet DSO
-    _applet = PluginLoader::pluginLoader()->loadApplet( *_info, 0 );
+    _applet = loadApplet(*_info);
 
     // sanity check
-    if (!_applet) {
+    if (!_applet)
+    {
 	kdError() << "Failed to load applet: " << _info->library() << endl;
+        KMessageBox::error(0,
+                           i18n("The applet %1 could not be loaded via the applet proxy.").arg(_info->name()), 
+                           i18n("Applet Loading Error"));
 	exit(0);
     }
 
@@ -189,6 +202,30 @@ void AppletProxy::loadApplet(const QString& desktopFile, const QString& configFi
     connect(_applet, SIGNAL(requestFocus()), SLOT(slotRequestFocus()));
 }
 
+KPanelApplet* AppletProxy::loadApplet(const AppletInfo& info)
+{
+    KLibLoader* loader = KLibLoader::self();
+    KLibrary* lib = loader->library(QFile::encodeName(info.library()));
+
+    if (!lib)
+    {
+        kdWarning() << "cannot open applet: " << info.library()
+                    << " because of " << loader->lastErrorMessage() << endl;
+        return 0;
+    }
+
+    KPanelApplet* (*init_ptr)(QWidget *, const QString&);
+    init_ptr = (KPanelApplet* (*)(QWidget *, const QString&))lib->symbol( "init" );
+
+    if (!init_ptr)
+    {
+        kdWarning() << info.library() << " is not a kicker plugin!" << endl;
+        return 0;
+    }
+
+    return init_ptr(0, info.configFile());
+}
+
 void AppletProxy::repaintApplet(QWidget* widget) 
 {
     widget->repaint();
@@ -233,7 +270,7 @@ void AppletProxy::dock(const QCString& callbackID)
 	QDataStream dataStream( data, IO_WriteOnly );
 
 	int actions = 0;
-	if(_applet) actions = _applet->actions();
+	if (_applet) actions = _applet->actions();
 	dataStream << actions;
 
 	int type = 0;
@@ -255,6 +292,9 @@ void AppletProxy::dock(const QCString& callbackID)
 			 data, replyType, replyData ) )
         {
             kdError() << "Failed to dock into the panel." << endl;
+            KMessageBox::error(0,
+                               i18n("The applet proxy could not dock into the panel due to DCOP communication problems."),
+                               i18n("Applet Loading Error"));
             exit(0);
         }
 
@@ -265,15 +305,24 @@ void AppletProxy::dock(const QCString& callbackID)
         dcop->send(appname, _callbackID, "getBackground()", data);
     }
 
-    if (win) {
-        _applet->hide();
+    if (win)
+    {
+        if (_applet)
+        {
+            _applet->hide();
+        }
         QXEmbed::initialize();
-        QXEmbed::embedClientIntoWindow( _applet, win );
+        QXEmbed::embedClientIntoWindow(_applet, win);
     }
-    else {
+    else
+    {
         kdError() << "Failed to dock into the panel." << endl;
+        KMessageBox::error(0,
+                           i18n("The applet proxy could not dock into the panel."),
+                           i18n("Applet Loading Error"));
         delete _applet;
         _applet = 0;
+
         exit(0);
     }
 
@@ -319,7 +368,7 @@ bool AppletProxy::process(const QCString &fun, const QByteArray &data,
 	    dataStream >> dir;
 
 	    if(_applet) {
-		_applet->setPosition( (KPanelApplet::Position)directionToPosition(dir) );
+		_applet->setPosition(directionToPosition(dir));
 	    }
 	    return true;
 	}
@@ -453,9 +502,15 @@ void AppletProxy::slotApplicationRemoved(const QCString& appId)
 
 void AppletProxy::showStandalone()
 {
+    if (!_applet)
+    {
+        return;
+    }
+
     _applet->resize( _applet->widthForHeight( 48 ), 48 );
     _applet->setMinimumSize( _applet->size() );
     _applet->setCaption( _info->name() );
     kapp->setMainWidget( _applet );
     _applet->show();
 }
+
