@@ -41,8 +41,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <klocale.h>
 #include <kstandarddirs.h>
 
-#include "kshadowengine.h"
-#include "kshadowsettings.h"
 #include "kickerSettings.h"
 #include "taskbarsettings.h"
 #include "taskcontainer.h"
@@ -63,13 +61,11 @@ TaskBar::TaskBar( QWidget *parent, const char *name )
       m_textShadowEngine(0),
       m_ignoreUpdates(false)
 {
-    setBackgroundOrigin( AncestorOrigin );
-
     setFrameStyle( NoFrame );
 
     arrowType = LeftArrow;
     blocklayout = true;
-
+    
     // init
     setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding ) );
 
@@ -150,8 +146,19 @@ TaskBar::~TaskBar()
     {
         delete *it;
     }
+
+    delete m_textShadowEngine;
 }
 
+KTextShadowEngine *TaskBar::textShadowEngine()
+{
+    if (!m_textShadowEngine)
+        m_textShadowEngine = new KTextShadowEngine();
+
+    return m_textShadowEngine;
+}
+
+
 QSize TaskBar::sizeHint() const
 {
     // get our minimum height based on the minimum button height or the
@@ -177,14 +184,14 @@ QSize TaskBar::sizeHint( KPanelExtension::Position p, QSize maxSize) const
 
         if (containerCount() == 0)
         {
-            actualMax = maxSize.height();
+            actualMax = minButtonHeight;
         }
 
         if (actualMax > maxSize.height())
         {
             return maxSize;
         }
-        return QSize( maxSize.width(), maxSize.height() );
+        return QSize( maxSize.width(), actualMax );
     }
     else
     {
@@ -276,6 +283,12 @@ void TaskBar::setOrientation( Orientation o )
     reLayoutEventually();
 }
 
+void TaskBar::moveEvent( QMoveEvent* e )
+{
+    Panner::moveEvent(e);
+    setViewportBackground();
+}
+
 void TaskBar::resizeEvent( QResizeEvent* e )
 {
     if (m_showOnlyCurrentScreen)
@@ -419,7 +432,8 @@ void TaskBar::remove(Task::Ptr task, TaskContainer* container)
     {
         if ((*it)->contains(task))
         {
-            (*it)->deleteLater();
+            (*it)->finish();
+            m_deletableContainers.append(*it);
             m_hiddenContainers.erase(it);
             break;
         }
@@ -455,7 +469,8 @@ void TaskBar::remove(Task::Ptr task, TaskContainer* container)
         }
 
         removeChild(container);
-        container->deleteLater();
+        container->finish();
+        m_deletableContainers.append(container);
 
         reLayoutEventually();
         emit containerCountChanged();
@@ -479,7 +494,8 @@ void TaskBar::remove(Startup::Ptr startup, TaskContainer* container)
 
             if ((*it)->isEmpty())
             {
-                (*it)->deleteLater();
+                (*it)->finish();
+                m_deletableContainers.append(*it);
                 m_hiddenContainers.erase(it);
             }
 
@@ -520,7 +536,8 @@ void TaskBar::remove(Startup::Ptr startup, TaskContainer* container)
 
     // startup containers only ever contain that one item. so
     // just delete the poor bastard.
-    container->deleteLater();
+    container->finish();
+    m_deletableContainers.append(container);
     reLayoutEventually();
     emit containerCountChanged();
 }
@@ -636,6 +653,19 @@ void TaskBar::reLayoutEventually()
 
 void TaskBar::reLayout()
 {
+    // Because QPopupMenu::exec() creates its own event loop, deferred deletes
+    // via QObject::deleteLater() may be prematurely executed when a container's
+    // popup menu is visible.
+    //
+    // To get around this, we collect the containers and delete them manually
+    // when doing a relayout. (kling)
+    if (!m_deletableContainers.isEmpty()) {
+        TaskContainer::List::iterator it = m_deletableContainers.begin();
+        for (; it != m_deletableContainers.end(); ++it)
+            delete *it;
+        m_deletableContainers.clear();
+    }
+
     // filter task container list
     TaskContainer::List list = filteredContainers();
 
@@ -682,6 +712,12 @@ void TaskBar::reLayout()
         // actual button height
         int bheight = contentsRect().height() / rows;
 
+        // avoid zero devision later
+        if (bheight < 1)
+        {
+            bheight = 1;
+        }
+
         // buttons per row
         int bpr = (int)ceil( (double)list.count() / rows);
 
@@ -728,18 +764,22 @@ void TaskBar::reLayout()
 
             int row = i % rows;
 
-            c->setArrowType(arrowType);
-            c->resize( bwidth, bheight );
-            c->show();
-
             int x = ( i / rows ) * bwidth;
             if (reverseLayout)
             {
                 x = contentsRect().width() - x - bwidth;
             }
+            int y = (row * bheight) + topPadding;
 
-            moveChild(c, x, (row * bheight) + topPadding);
-            c->update();
+            c->setArrowType(arrowType);
+            
+            if (childX(c) != x || childY(c) != y)
+                moveChild(c, x, y);
+                
+            if (c->width() != bwidth || c->height() != bheight)
+                c->resize( bwidth, bheight );
+                
+            c->setBackground();
         }
     }
     else // vertical layout
@@ -759,18 +799,59 @@ void TaskBar::reLayout()
             TaskContainer* c = *it;
 
             c->setArrowType(arrowType);
-            c->resize(contentsRect().width(), minButtonHeight);
-            c->show();
+            
+            if (c->width() != contentsRect().width() || c->height() != minButtonHeight)
+                c->resize(contentsRect().width(), minButtonHeight);
 
-            moveChild(c, 0, i * minButtonHeight);
+            if (childX(c) != 0 || childY(c) != (i * minButtonHeight))
+                moveChild(c, 0, i * minButtonHeight);
+            
+            c->setBackground();
             i++;
-            c->update();
         }
     }
-
+    
     QTimer::singleShot(100, this, SLOT(publishIconGeometry()));
 }
 
+void TaskBar::viewportResizeEvent( QResizeEvent* e )
+{
+    Panner::viewportResizeEvent(e);
+    setViewportBackground();
+}
+
+void TaskBar::setViewportBackground()
+{
+    const QPixmap *bg = parentWidget()->backgroundPixmap();
+    
+    viewport()->unsetPalette();
+    
+    if (bg)
+    {
+        QPixmap pm(parentWidget()->size());
+        pm.fill(parentWidget(), pos() + viewport()->pos());
+        viewport()->setPaletteBackgroundPixmap(pm);
+        viewport()->setBackgroundOrigin( WidgetOrigin );
+    }
+    else
+        viewport()->setPaletteBackgroundColor(paletteBackgroundColor());
+}
+
+void TaskBar::setBackground()
+{
+    setViewportBackground();
+    
+    TaskContainer::List list = filteredContainers();
+    
+    for (TaskContainer::Iterator it = list.begin();
+            it != list.end();
+            ++it)
+    {
+        TaskContainer* c = *it;
+        c->setBackground();
+    }
+}
+
 void TaskBar::setArrowType(Qt::ArrowType at)
 {
     if (arrowType == at)
@@ -920,7 +1001,8 @@ void TaskBar::reGroup()
          it != lastContainer;
          ++it)
     {
-        (*it)->deleteLater();
+        (*it)->finish();
+        m_deletableContainers.append(*it);
     }
     m_hiddenContainers.clear();
 
@@ -928,7 +1010,8 @@ void TaskBar::reGroup()
          it != containers.constEnd();
          ++it)
     {
-        (*it)->deleteLater();
+        (*it)->finish();
+        m_deletableContainers.append(*it);
     }
     containers.clear();
 
@@ -954,14 +1037,15 @@ void TaskBar::reGroup()
     reLayoutEventually();
 }
 
+
 TaskContainer::List TaskBar::filteredContainers()
 {
     // filter task container list
     TaskContainer::List list;
 
     for (TaskContainer::List::const_iterator it = containers.constBegin();
-         it != containers.constEnd();
-         ++it)
+        it != containers.constEnd();
+        ++it)
     {
         TaskContainer* c = *it;
         if ((m_showAllWindows || c->onCurrentDesktop()) &&
@@ -976,7 +1060,7 @@ TaskContainer::List TaskBar::filteredContainers()
             c->hide();
         }
     }
-
+        
     return list;
 }
 
@@ -1091,57 +1175,6 @@ int TaskBar::showScreen() const
     return m_currentScreen;
 }
 
-// taken from mtaskbar, by Sebastian Wolff
-void TaskBar::drawShadowText(QPainter  &p, QRect tr, int tf, const QString & str,
-                             int len, QRect * brect, QTextParag ** internal)
-{
-    // get the color of the shadow: white for dark text, black for bright text
-    QPen textPen = p.pen();
-    QColor shadCol = textPen.color();
-
-    if (shadCol.red() +
-        shadCol.green() +
-        shadCol.blue() <= 3*256/2-1)
-    {
-        shadCol = QColor(255,255,255);
-    }
-    else
-    {
-        shadCol = QColor(0,0,0);
-    }
-
-    // get a transparent pixmap
-    QPainter pixPainter;
-    QPixmap textPixmap(width(), height());
-
-    textPixmap.fill(QColor(0,0,0));
-    textPixmap.setMask(textPixmap.createHeuristicMask(true));
-
-    // draw text
-    pixPainter.begin(&textPixmap);
-    pixPainter.setPen(white);
-    pixPainter.setFont(p.font()); // get the font from the root painter
-    pixPainter.drawText( tr, tf, str, len, brect, internal );
-    pixPainter.end();
-
-    if (!m_textShadowEngine)
-    {
-        KShadowSettings * shadset = new KShadowSettings();
-        shadset->setOffsetX(0);
-        shadset->setOffsetY(0);
-        shadset->setThickness(1);
-        shadset->setMaxOpacity(96);
-        m_textShadowEngine = new KShadowEngine(shadset);
-    }
-
-    // draw shadow
-    QImage img = m_textShadowEngine->makeShadow(textPixmap, shadCol);
-
-    // return
-    p.drawImage(0, 0, img);
-    p.drawText(tr, tf, str, len, brect, internal);
-}
-
 QImage* TaskBar::blendGradient(const QSize& size)
 {
     if (m_blendGradient.isNull() || m_blendGradient.size() != size)
