@@ -29,6 +29,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include "taskcontainer.h"
 #include "panner.h"
+#include "kshadowengine.h"
 
 #define WINDOWLISTBUTTON_SIZE 15
 #define BUTTON_MAX_WIDTH 200
@@ -37,7 +38,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 class Startup;
 class Task;
 class KGlobalAccel;
-class KShadowEngine;
 
 class TaskBar : public Panner
 {
@@ -61,9 +61,11 @@ public:
     bool sortByDesktop() const { return m_sortByDesktop; }
     bool showAllWindows() const { return m_showAllWindows; }
 
-    void drawShadowText(QPainter &p, const QRect &tr, int tf, const QString &str, const QSize &size);
-
     QImage* blendGradient(const QSize& size);
+    
+    void setBackground();
+    
+    KTextShadowEngine *textShadowEngine();
 
 public slots:
     void configure();
@@ -96,14 +98,17 @@ protected:
     void viewportMouseReleaseEvent( QMouseEvent* );
     void viewportMouseDoubleClickEvent( QMouseEvent* );
     void viewportMouseMoveEvent( QMouseEvent* );
+    void viewportResizeEvent( QResizeEvent * );
     void wheelEvent(QWheelEvent*);
     void propagateMouseEvent( QMouseEvent* );
     void resizeEvent( QResizeEvent* );
+    void moveEvent( QMoveEvent* );
     bool idMatch( const QString& id1, const QString& id2 );
     TaskContainer::List filteredContainers();
 
 private:
     void sortContainersByDesktop(TaskContainer::List& list);
+    void setViewportBackground();
 
     bool			blocklayout;
     bool			m_showAllWindows;
@@ -123,7 +128,7 @@ private:
     bool                        isGrouping;
     void                        reGroup();
     KGlobalAccel*               keys;
-    KShadowEngine* m_textShadowEngine;
+    KTextShadowEngine* m_textShadowEngine;
     QTimer m_relayoutTimer;
     bool m_ignoreUpdates;
     QImage m_blendGradient;
