@@ -50,7 +50,7 @@ TaskBarContainer::TaskBarContainer( bool enableFrame, QWidget *parent, const cha
       windowListMenu(0)
 {
     setBackgroundOrigin( AncestorOrigin );
-
+    
     uint margin;
     if ( enableFrame )
     {
@@ -74,6 +74,8 @@ TaskBarContainer::TaskBarContainer( bool enableFrame, QWidget *parent, const cha
 
     connect( taskBar, SIGNAL( containerCountChanged() ), SIGNAL( containerCountChanged() ) );
 
+    setBackground();
+
     // read settings and setup layout
     configure();
 
@@ -283,3 +285,8 @@ QSize TaskBarContainer::sizeHint( KPanelExtension::Position p, QSize maxSize) co
     }
     return size;
 }
+
+void TaskBarContainer::setBackground()
+{
+    taskBar->setBackground();
+}
