@@ -109,8 +109,8 @@ TaskContainer::TaskContainer(Startup::Ptr startup, PixmapList& startupFrames,
 
 void TaskContainer::init()
 {
+    setWFlags(WNoAutoErase);
     setBackgroundMode(NoBackground);
-    setBackgroundOrigin(WidgetOrigin);
     animBg = QPixmap(16, 16);
 
     installEventFilter(KickerTip::the());
@@ -118,7 +118,7 @@ void TaskContainer::init()
     connect(&animationTimer, SIGNAL(timeout()), SLOT(animationTimerFired()));
     connect(&dragSwitchTimer, SIGNAL(timeout()), SLOT(showMe()));
     connect(&attentionTimer, SIGNAL(timeout()), SLOT(attentionTimerFired()));
-    connect(&m_paintEventCompressionTimer, SIGNAL(timeout()), SLOT(setPaintEventCompression()));
+    connect(&m_paintEventCompressionTimer, SIGNAL(timeout()), SLOT(updateNow()));
 }
 
 TaskContainer::~TaskContainer()
@@ -427,13 +427,18 @@ QString TaskContainer::id()
     return sid;
 }
 
-void TaskContainer::setPaintEventCompression()
+void TaskContainer::updateNow()
 {
     m_paintEventCompression = true;
     update();
 }
 
-void TaskContainer::paintEvent(QPaintEvent*)
+void TaskContainer::setBackground()
+{
+    updateNow();
+}
+
+void TaskContainer::paintEvent( QPaintEvent* )
 {
     if (!m_paintEventCompression)
     {
@@ -449,40 +454,12 @@ void TaskContainer::paintEvent(QPaintEvent*)
 
     const QPixmap* background = taskBar->backgroundPixmap();
 
-    if (TaskBarSettings::drawButtons())
+    if (background)
     {
-        // do nothing.
-    }
-    else if (background)
-    {
-        QPoint pos(geometry().topLeft());
-        pos += taskBar->geometry().topLeft();
-        int w = width();
-        int h = height();
-        int bgWidth = background->width();
-        int bgHeight = background->height();
-
-        if (bgWidth < taskBar->width() || bgHeight < taskBar->height())
-        {
-            int xOffset = pos.x() % bgWidth;
-            int yOffset = pos.y() % bgHeight;
-
-            bitBlt(pm, 0, 0, background, xOffset, yOffset);
-
-            for (int i = bgWidth - xOffset; i < w; i += bgWidth - xOffset)
-            {
-                bitBlt(pm, i, 0, background, xOffset, yOffset);
-            }
-
-            for (int i = bgHeight - yOffset; i < h; i += bgHeight - yOffset)
-            {
-                bitBlt(pm, 0, i, pm, 0, 0, w, yOffset == 0 ? bgHeight : yOffset);
-            }
-        }
-        else
-        {
-            bitBlt(pm, 0, 0, background, pos.x(), pos.y(), w, h);
-        }
+        QPoint pt = mapTo(taskBar, QPoint(0, 0)) + taskBar->backgroundOffset();
+        QPainter p(pm);
+        p.drawTiledPixmap(0, 0, width(), height(), *background, pt.x(), pt.y());
+        p.end();
     }
     else
     {
@@ -513,7 +490,7 @@ void TaskContainer::drawButton(QPainter *p)
     bool halo = TaskBarSettings::haloText();
     bool alwaysDrawButtons = TaskBarSettings::drawButtons();
     bool drawButton = alwaysDrawButtons ||
-                      (m_mouseOver && isEnabled() &&
+                      (m_mouseOver && !halo && isEnabled() &&
                        TaskBarSettings::showButtonOnHover());
     QFont font(KGlobalSettings::taskbarFont());
 
@@ -723,7 +700,7 @@ void TaskContainer::drawButton(QPainter *p)
 
             if (halo)
             {
-                taskBar->drawShadowText(tp, tr, textFlags, text, size());
+                taskBar->textShadowEngine()->drawText(tp, tr, textFlags, text, size());
             }
             else
             {
@@ -743,7 +720,7 @@ void TaskContainer::drawButton(QPainter *p)
 
             if (halo)
             {
-                taskBar->drawShadowText(*p, tr, textFlags, text, size());
+                taskBar->textShadowEngine()->drawText(*p, tr, textFlags, text, size());
             }
             else
             {
@@ -794,6 +771,10 @@ void TaskContainer::drawButton(QPainter *p)
 
         style().drawPrimitive(e, p, ar, colors, flags);
     }
+    
+    // draw mouse over frame in transparent mode
+    if (m_mouseOver && halo)
+        KickerLib::drawBlendedRect(p, QRect(0, 0, width(), height()), colorGroup().foreground());
 
     if (aboutToActivate)
     {
@@ -989,17 +970,17 @@ void TaskContainer::performAction(int action)
 
     switch( action ) {
     case TaskBarSettings::ShowTaskList:
-	// If there is only one task, the correct behavior is
-	// to activate, raise, or iconify it, not show the task menu.
-	if( m_filteredTasks.count() > 1 ) {
-            popupMenu( TaskBarSettings::ShowTaskList );
-	} else {
-            performAction( TaskBarSettings::ActivateRaiseOrMinimize );
-	}
-	break;
+    // If there is only one task, the correct behavior is
+    // to activate, raise, or iconify it, not show the task menu.
+    if( m_filteredTasks.count() > 1 ) {
+                popupMenu( TaskBarSettings::ShowTaskList );
+    } else {
+                performAction( TaskBarSettings::ActivateRaiseOrMinimize );
+    }
+    break;
     case TaskBarSettings::ShowOperationsMenu:
         popupMenu( TaskBarSettings::ShowOperationsMenu );
-	break;
+    break;
     case TaskBarSettings::ActivateRaiseOrMinimize:
     if (m_filteredTasks.isEmpty())
     {
@@ -1291,7 +1272,7 @@ void TaskContainer::setArrowType( Qt::ArrowType at )
     }
 
     arrowType = at;
-    repaint();
+    update();
 }
 
 void TaskContainer::publishIconGeometry( QPoint global )
@@ -1341,7 +1322,7 @@ void TaskContainer::enterEvent(QEvent* e)
 {
     QToolTip::remove(this);
     m_mouseOver = true;
-    update();
+    updateNow();
 
     if (tasks.isEmpty())
     {
@@ -1360,7 +1341,7 @@ void TaskContainer::enterEvent(QEvent* e)
 void TaskContainer::leaveEvent(QEvent*)
 {
     m_mouseOver = false;
-    update();
+    updateNow();
 }
 
 void TaskContainer::dragSwitch()
