@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 #ifndef KCMCGI_H
 #define KCMCGI_H
@@ -32,8 +32,6 @@ class KCMCgi : public KCModule
     KCMCgi( QWidget *parent = 0, const char *name = 0 );
     ~KCMCgi();
 
-    virtual const KAboutData * aboutData () const;
-
     void load();
     void save();
     void defaults();
@@ -52,8 +50,6 @@ class KCMCgi : public KCModule
     QPushButton *mRemoveButton;
 
     KConfig *mConfig;
-
-    KAboutData *mAboutData;
 };
 
 #endif
