@@ -76,6 +76,18 @@ void InfoProtocol::get( const KURL& url )
         return;
     }
 
+    if ( url.path().right(1) == "/" )
+    {
+        // Trailing / are not supported, so we need to remove them.
+        KURL newUrl( url );
+        QString newPath( url.path() );
+        newPath.truncate( newPath.length()-1 );
+        newUrl.setPath( newPath );
+        redirection( newUrl );
+        finished();
+        return;
+    }
+
     mimeType("text/html");
     // extract the path and node from url
     decodeURL( url );
