@@ -24,7 +24,6 @@
 #include <kconfig.h>
 #include <qstring.h>
 #include <qregexp.h>
-#include <qdatastream.h>
 
 #include <sys/stat.h>
 #include <stdlib.h>
@@ -70,7 +69,7 @@ void MacProtocol::get(const KURL& url) {
     QString path = prepareHP(url);  //mount and change to correct directory - return the filename
     QString query = url.query();
     QString mode("-");
-    QString mime = "";
+    QString mime;
     processedBytes = 0;
 
     //Find out the size and if it's a text file
@@ -92,7 +91,7 @@ void MacProtocol::get(const KURL& url) {
     if (modepos != -1) {
         mode += query.mid(modepos + 5, 1);
         if (mode != "-r" && mode != "-b" && mode != "-m" && mode != "-t" && mode != "-a") {
-            error(ERR_MALFORMED_URL, i18n("Unknown mode"));
+            error(ERR_SLAVE_DEFINED, i18n("Unknown mode"));
         }
     } else if (textpos != -1) {
         mode += "t";
@@ -112,7 +111,7 @@ void MacProtocol::get(const KURL& url) {
     myKProcess->start(KProcess::Block, KProcess::All);
 
     if (!myKProcess->normalExit() || !(myKProcess->exitStatus() == 0)) {
-        error(ERR_CANNOT_LAUNCH_PROCESS,
+        error(ERR_SLAVE_DEFINED,
               i18n("There was an error with hpcopy - please ensure it is installed"));
         return;
     }
@@ -141,7 +140,7 @@ void MacProtocol::listDir(const KURL& url) {
         myKProcess->start(KProcess::Block, KProcess::All);
 
         if ((!myKProcess->normalExit()) || (!myKProcess->exitStatus() == 0)) {
-            error(ERR_CANNOT_LAUNCH_PROCESS,
+            error(ERR_SLAVE_DEFINED,
                   i18n("There was an error with hpls - please ensure it is installed"));
         }
 
@@ -185,7 +184,7 @@ QValueList<KIO::UDSAtom> MacProtocol::doStat(const KURL& url) {
     QString filename = prepareHP(url);
 
     if (filename.isNull()) {
-        error(ERR_DOES_NOT_EXIST, i18n("No filename was found in the URL"));
+        error(ERR_SLAVE_DEFINED, i18n("No filename was found in the URL"));
     } else if (! filename.isEmpty()) {
         myKProcess = new KShellProcess();
 
@@ -198,7 +197,7 @@ QValueList<KIO::UDSAtom> MacProtocol::doStat(const KURL& url) {
         myKProcess->start(KProcess::Block, KProcess::All);
 
         if ((!myKProcess->normalExit()) || (!myKProcess->exitStatus() == 0)) {
-            error(ERR_CANNOT_LAUNCH_PROCESS,
+            error(ERR_SLAVE_DEFINED,
                   i18n("hpls did not exit normally - please ensure you have installed the hfsplus tools"));
         }
 
@@ -237,10 +236,6 @@ QString MacProtocol::prepareHP(const KURL& url) {
         path = path.mid(1); // strip leading slash
     }
 
-    if (path == NULL) {
-        path = "";
-    }
-
     //find out if a device has been specified in the query e.g. ?dev=/dev/fd0
     //or in the config file (query device entries are saved to config file)
     QString device;
@@ -289,7 +284,7 @@ QString MacProtocol::prepareHP(const KURL& url) {
 
     if ((!myKProcess->normalExit()) || (!myKProcess->exitStatus() == 0)) {
         //TODO this error interrupts the user when typing ?dev=foo on each letter of foo
-        error(ERR_CANNOT_LAUNCH_PROCESS,
+        error(ERR_SLAVE_DEFINED,
               i18n("hpmount did not exit normally - please ensure that hfsplus utils are installed,\n"
                    "that you have permission to read the partition (ls -l /dev/hdaX)\n"
                    "and that you have specified the correct partition.\n"
@@ -302,11 +297,11 @@ QString MacProtocol::prepareHP(const KURL& url) {
 
     //escape any funny characters
     //TODO are there any more characters to escape?
-    path.replace(QRegExp(" "), "\\ ");
-    path.replace(QRegExp("&"), "\\&");
-    path.replace(QRegExp("!"), "\\!");
-    path.replace(QRegExp("("), "\\(");
-    path.replace(QRegExp(")"), "\\)");
+    path.replace(" ", "\\ ");
+    path.replace("&", "\\&");
+    path.replace("!", "\\!");
+    path.replace("(", "\\(");
+    path.replace(")", "\\)");
 
     //then change to the right directory
     int s;  QString dir;
@@ -321,7 +316,7 @@ QString MacProtocol::prepareHP(const KURL& url) {
         myKProcess->start(KProcess::Block, KProcess::All);
 
         if ((!myKProcess->normalExit()) || (!myKProcess->exitStatus() == 0)) {
-            error(ERR_CANNOT_LAUNCH_PROCESS,
+            error(ERR_SLAVE_DEFINED,
                   i18n("hpcd did not exit normally - please ensure it is installed"));
             return NULL;
         }
@@ -409,7 +404,7 @@ QValueList<KIO::UDSAtom> MacProtocol::makeUDS(const QString& _line) {
             entry.append(atom);
         }
     } else {
-        error(ERR_INTERNAL, "hpls output was not matched");
+        error(ERR_INTERNAL, i18n("hpls output was not matched"));
     } //if match dirRE or fileRE
 
     return entry;
@@ -452,8 +447,7 @@ int MacProtocol::makeTime(QString mday, QString mon, QString third) {
     else if (mon == "Nov") { month = 11; }
     else if (mon == "Dec") { month = 12; }
     else {
-        error(ERR_CANNOT_LAUNCH_PROCESS,
-              "Month output from hpls -l not matched, e-mail jr@jriddell.org");
+        error(ERR_INTERNAL, i18n("Month output from hpls -l not matched"));
         month = 13;
     }
 
@@ -482,18 +476,15 @@ int MacProtocol::makeTime(QString mday, QString mon, QString third) {
 
     //check it's valid
     if ( (!QDate::isValid(year, month, day)) || (!QTime::isValid(hour, minute, 0) ) ) {
-        error(ERR_CANNOT_LAUNCH_PROCESS,
-              "Could not parse a valid date from hpls, e-mail jr@jriddell.org");
+        error(ERR_INTERNAL, i18n("Could not parse a valid date from hpls"));
     }
 
     //put it together and work it out
     QDate fileDate(year, month, day);
     QTime fileTime(hour, minute);
     QDateTime fileDateTime(fileDate, fileTime);
-    QDateTime epoc(QDate(1970, 1, 1));
 
-    int timestamp = epoc.secsTo(fileDateTime);
-    return timestamp;
+    return fileDateTime.toTime_t();
 }
 
 QString MacProtocol::getMimetype(QString type, QString app) {
@@ -531,14 +522,18 @@ QString MacProtocol::getMimetype(QString type, QString app) {
         return QString("image/gif");
     } else if (type == QString("JPEG")) {
         return QString("image/jpeg");
+    } else if (type == QString("PNGf")) {
+        return QString("image/png");
     } else if (type == QString("XBMm")) {
         return QString("image/x-xbm");
     } else if (type == QString("EPSF")) {
-        return QString("application/postscript");
+        return QString("image/x-epsf");
     } else if (type == QString("TIFF")) {
         return QString("image/tiff");
     } else if (type == QString("PICT")) {
         return QString("image/pict");
+    } else if (type == QString("TPIC")) {
+        return QString("image/x-targa");
     } else if (type == QString("ULAW")) {
         return QString("audio/basic");
     } else if (type == QString("AIFF")) {
