@@ -13,8 +13,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -25,6 +25,7 @@
 #include <qdir.h>
 #include <qfile.h>
 #include <qtextstream.h>
+#include <qdatastream.h>
 #include <qcstring.h>
 #include <qptrlist.h>
 #include <qmap.h>
@@ -40,7 +41,6 @@
 
 #include "kio_man.h"
 #include "kio_man.moc"
-#include <zlib.h>
 #include "man2html.h"
 #include <assert.h>
 #include <kfilterbase.h>
@@ -79,7 +79,7 @@ void stripExtension( QString *name )
 static
 bool parseUrl(const QString& _url, QString &title, QString &section)
 {
-    section = "";
+    section = QString::null;
 
     QString url = _url;
     if (url.at(0) == '/') {
@@ -87,7 +87,10 @@ bool parseUrl(const QString& _url, QString &title, QString &section)
             title = url;
             return true;
         } else
+        {
+            // If the directory does not exist, then it is perhaps a normal man page
             kdDebug(7107) << url << " does not exist" << endl;
+        }
     }
 
     while (url.at(0) == '/')
@@ -113,9 +116,13 @@ MANProtocol::MANProtocol(const QCString &pool_socket, const QCString &app_socket
 {
     assert(!_self);
     _self = this;
-    common_dir = KGlobal::dirs()->findResourceDir( "html", "en/common/kde-common.css" );
+    const QString common_dir = KGlobal::dirs()->findResourceDir( "html", "en/common/kde-common.css" );
+    const QString strPath=QString( "file:%1/en/common" ).arg( common_dir );
+    m_htmlPath=strPath.local8Bit(); // ### TODO encode for HTML
+    m_cssPath=strPath.local8Bit(); // ### TODO encode for CSS
     section_names << "1" << "2" << "3" << "3n" << "3p" << "4" << "5" << "6" << "7"
                   << "8" << "9" << "l" << "n";
+    m_manCSSFile = locate( "data", "kio_man/kio_man.css" );
 }
 
 MANProtocol *MANProtocol::self() { return _self; }
@@ -164,14 +171,19 @@ QMap<QString, QString> MANProtocol::buildIndexMap(const QString &section)
     QMap<QString, QString> i;
     QStringList man_dirs = manDirectories();
     // Supplementary places for whatis databases
-    man_dirs << "/var/cache/man" << "/var/catman";
+    man_dirs += m_mandbpath;
+    if (man_dirs.find("/var/cache/man")==man_dirs.end())
+        man_dirs << "/var/cache/man";
+    if (man_dirs.find("/var/catman")==man_dirs.end())
+        man_dirs << "/var/catman";
+    
     QStringList names;
     names << "whatis.db" << "whatis";
     QString mark = "\\s+\\(" + section + "[a-z]*\\)\\s+-\\s+";
 
     for ( QStringList::ConstIterator it_dir = man_dirs.begin();
           it_dir != man_dirs.end();
-          it_dir++ )
+          ++it_dir )
     {
         if ( QFile::exists( *it_dir ) ) {
     	    QStringList::ConstIterator it_name;
@@ -225,13 +237,15 @@ QStringList MANProtocol::manDirectories()
                 if ( ::stat( QFile::encodeName( dir ), &sbuf ) == 0
                     && S_ISDIR( sbuf.st_mode ) )
                 {
-                    man_dirs += dir;
+                    const QString p = QDir(dir).canonicalPath();
+                    if (!man_dirs.contains(p)) man_dirs += p;	
                 }
             }
         }
 
         // Untranslated pages in "<mandir>"
-        man_dirs += (*it_dir);
+        const QString p = QDir(*it_dir).canonicalPath();
+        if (!man_dirs.contains(p)) man_dirs += p;
     }
     return man_dirs;
 }
@@ -250,7 +264,7 @@ QStringList MANProtocol::findPages(const QString &_section,
        return list;
     }
 
-    QString star( "*" );
+    const QString star( "*" );
 
     //
     // Find man sections in this directory
@@ -302,11 +316,11 @@ QStringList MANProtocol::findPages(const QString &_section,
 
             struct dirent *ep;
 
-            QString man = QString("man");
-            QString sman = QString("sman");
+            const QString man = QString("man");
+            const QString sman = QString("sman");
 
             while ( (ep = ::readdir( dp )) != 0L ) {
-                QString file = QFile::decodeName( ep->d_name );
+                const QString file = QFile::decodeName( ep->d_name );
                 QString sect = QString::null;
 
                 if ( file.startsWith( man ) )
@@ -326,8 +340,8 @@ QStringList MANProtocol::findPages(const QString &_section,
             ::closedir( dp );
 
             if ( *it_sect != star ) { // in that case we only look around for sections
-                QString dir = man_dir + QString("/man") + (it_real) + '/';
-                QString sdir = man_dir + QString("/sman") + (it_real) + '/';
+                const QString dir = man_dir + QString("/man") + (it_real) + '/';
+                const QString sdir = man_dir + QString("/sman") + (it_real) + '/';
 
                 findManPagesInSection(dir, title, full_path, list);
                 findManPagesInSection(sdir, title, full_path, list);
@@ -335,7 +349,7 @@ QStringList MANProtocol::findPages(const QString &_section,
         }
     }
 
-//    kdDebug() << "finished " << list << " " << sect_list << endl;
+//    kdDebug(7107) << "finished " << list << " " << sect_list << endl;
 
     return list;
 }
@@ -383,13 +397,15 @@ void MANProtocol::findManPagesInSection(const QString &dir, const QString &title
 void MANProtocol::output(const char *insert)
 {
     if (insert)
-        output_string += insert;
-    if (!insert || output_string.length() > 2000) {
-        // TODO find out the language of the man page and put the right common dir in
-        output_string.replace( "KDE_COMMON_DIR", QString( "file:%1/en/common" ).arg( common_dir ).local8Bit());
-        //kdDebug(7107) << "output " << output_string << endl;
-        data(output_string);
-        output_string.truncate(0);
+    {
+        m_outputBuffer.writeBlock(insert,strlen(insert));
+    }
+    if (!insert || m_outputBuffer.at() >= 2048)
+    {
+        m_outputBuffer.close();
+        data(m_outputBuffer.buffer());
+        m_outputBuffer.setBuffer(QByteArray());
+        m_outputBuffer.open(IO_WriteOnly);
     }
 }
 
@@ -405,6 +421,18 @@ void output_real(const char *insert)
     MANProtocol::self()->output(insert);
 }
 
+static QString text2html(const QString& txt)
+{
+    QString reply = txt;
+
+    reply = reply.replace('&', "&amp;");
+    reply = reply.replace('<', "&lt;");
+    reply = reply.replace('>', "&gt;");
+    reply = reply.replace('"', "&dquot;");
+    reply = reply.replace('\'', "&quot;");
+    return reply;
+}
+
 void MANProtocol::get(const KURL& url )
 {
     kdDebug(7107) << "GET " << url.url() << endl;
@@ -430,19 +458,37 @@ void MANProtocol::get(const KURL& url )
     // tell the mimetype
     mimeType("text/html");
 
-    QStringList foundPages=findPages(section, title);
-    if (foundPages.count()==0)
+    const QStringList foundPages=findPages(section, title);
+    bool pageFound=true;
+    if (foundPages.isEmpty())
     {
-       outputError(i18n("No man page matching to %1 found. You can extend the search path by setting the environment variable MANPATH before starting KDE.").arg(title));
+       outputError(i18n("No man page matching to %1 found.<br><br>"
+           "Check that you have not mistyped the name of the page that you want.\n"
+           "Be careful that you must take care about upper case and lower case characters!<br>"
+           "If everything looks correct, then perhaps you need to set a better search path "
+           "for man pages, be it by the environment variable MANPATH or a matching file "
+           "in the directory /etc .").arg(text2html(title)));
+       pageFound=false;
     }
     else if (foundPages.count()>1)
     {
-       outputMatchingPages(foundPages);
+       pageFound=false;
+       //check for the case that there is foo.1 and foo.1.gz found:
+       // ### TODO make it more generic (other extensions)
+       if ((foundPages.count()==2) &&
+           (((foundPages[0]+".gz") == foundPages[1]) ||
+            (foundPages[0] == (foundPages[1]+".gz"))))
+          pageFound=true;
+       else
+          outputMatchingPages(foundPages);
     }
     //yes, we found exactly one man page
-    else
+
+    if (pageFound)
     {
-       QCString filename=QFile::encodeName(foundPages[0]);
+       setResourcePath(m_htmlPath,m_cssPath);
+       m_outputBuffer.open(IO_WriteOnly);
+       const QCString filename=QFile::encodeName(foundPages[0]);
        char *buf = readManPage(filename);
 
        if (!buf)
@@ -457,9 +503,12 @@ void MANProtocol::get(const KURL& url )
 
        output(0); // flush
 
+       m_outputBuffer.close();
+       data(m_outputBuffer.buffer());
+       m_outputBuffer.setBuffer(QByteArray());
        // tell we are done
        data(QByteArray());
-    };
+    }
     finished();
 }
 
@@ -481,8 +530,8 @@ char *MANProtocol::readManPage(const char *_filename)
      * convert it to roff format (used on Solaris). */
     //QString file_mimetype = KMimeType::findByPath(QString(filename), 0, false)->name();
     if (filename.contains("sman", false)) //file_mimetype == "text/html" || )
-      {
-	myStdStream = "";
+    {
+        myStdStream =QString::null;
 	KProcess proc;
 
 	/* Determine path to sgml2roff, if not already done. */
@@ -493,85 +542,101 @@ char *MANProtocol::readManPage(const char *_filename)
 			      this, SLOT(slotGetStdOutput(KProcess *, char *, int)));
 	proc.start(KProcess::Block, KProcess::All);
 
-	buf = (char*)myStdStream.latin1();
-	// Does not work (return string is empty): buf = QCString(myStdStream->local8Bit());
-      }
+        const QCString cstr=myStdStream.latin1();
+        const int len = cstr.size()-1;
+        buf = new char[len + 4];
+        qmemmove(buf + 1, cstr.data(), len);
+        buf[0]=buf[len]='\n'; // Start and end with a end of line
+        buf[len+1]=buf[len+2]='\0'; // Two additional NUL characters at end
+    }
     else
-      {
-    if (QDir::isRelativePath(filename)) {
-        kdDebug(7107) << "relative " << filename << endl;
-        filename = QDir::cleanDirPath(lastdir + "/" + filename).utf8();
-        if (!KStandardDirs::exists(filename)) { // exists perhaps with suffix
-            lastdir = filename.left(filename.findRev('/'));
-            QDir mandir(lastdir);
-            mandir.setNameFilter(filename.mid(filename.findRev('/') + 1) + ".*");
-            filename = lastdir + "/" + QFile::encodeName(mandir.entryList().first());
+    {
+        if (QDir::isRelativePath(filename)) {
+            kdDebug(7107) << "relative " << filename << endl;
+            filename = QDir::cleanDirPath(lastdir + "/" + filename).utf8();
+            if (!KStandardDirs::exists(filename)) { // exists perhaps with suffix
+                lastdir = filename.left(filename.findRev('/'));
+                QDir mandir(lastdir);
+                mandir.setNameFilter(filename.mid(filename.findRev('/') + 1) + ".*");
+                filename = lastdir + "/" + QFile::encodeName(mandir.entryList().first());
+            }
+            kdDebug(7107) << "resolved to " << filename << endl;
         }
-        kdDebug(7107) << "resolved to " << filename << endl;
+        lastdir = filename.left(filename.findRev('/'));
+    
+        QIODevice *fd= KFilterDev::deviceForFile(filename);
+    
+        if ( !fd || !fd->open(IO_ReadOnly))
+        {
+           delete fd;
+           return 0;
+        }
+        QByteArray array(fd->readAll());
+        kdDebug(7107) << "read " << array.size() << endl;
+        fd->close();
+        delete fd;
+        
+        if (array.isEmpty())
+            return 0;
+    
+        const int len = array.size();
+        buf = new char[len + 4];
+        qmemmove(buf + 1, array.data(), len);
+        buf[0]=buf[len]='\n'; // Start and end with a end of line
+        buf[len+1]=buf[len+2]='\0'; // Two NUL characters at end
     }
-    lastdir = filename.left(filename.findRev('/'));
-
-    QIODevice *fd= KFilterDev::deviceForFile(filename);
-
-    if (!fd->open(IO_ReadOnly))
-    {
-       delete fd;
-       return 0;
-    }
-    char buffer[1025];
-    int n;
-    QCString text;
-    while ( ( n = fd->readBlock(buffer, 1024) ) )
-    {
-        buffer[n] = 0;
-        text += buffer;
-    }
-    kdDebug(7107) << "read " << text.length() << endl;
-    fd->close();
-
-    delete fd;
-
-    int l = text.length();
-	buf = new char[l + 4];
-    memcpy(buf + 1, text.data(), l);
-    buf[0]=buf[l]='\n';
-    buf[l+1]=buf[l+2]='\0';
-      }
-
     return buf;
 }
 
 
 void MANProtocol::outputError(const QString& errmsg)
 {
-    QString output;
-
-    QTextStream os(&output, IO_WriteOnly);
+    QByteArray array;
+    QTextStream os(array, IO_WriteOnly);
+    os.setEncoding(QTextStream::UnicodeUTF8);
 
+    os << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Strict//EN\">" << endl;
     os << "<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">" << endl;
-    os << "<title>" << i18n("Man output") << "</title></head>" << endl;
-    os << i18n("<body bgcolor=#ffffff><h1>KDE Man Viewer Error</h1>") << errmsg << "</body>" << endl;
+    os << "<title>" << i18n("Man output") << "</title>\n" << endl;
+    if ( !m_manCSSFile.isEmpty() )
+        os << "<link href=\"file:///" << m_manCSSFile << "\" type=\"text/css\" rel=\"stylesheet\">" << endl;
+    os << "</head>" << endl;
+    os << i18n("<body><h1>KDE Man Viewer Error</h1>") << errmsg << "</body>" << endl;
     os << "</html>" << endl;
 
-    data(output.utf8());
+    data(array);
 }
 
 void MANProtocol::outputMatchingPages(const QStringList &matchingPages)
 {
-    QString output;
+    QByteArray array;
+    QTextStream os(array, IO_WriteOnly);
+    os.setEncoding(QTextStream::UnicodeUTF8);
 
-    QTextStream os(&output, IO_WriteOnly);
-
-    os << "<html>\n<head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">";
-    os << "<title>" << i18n("Man output");
-    os <<"</title></head>\n<body bgcolor=#ffffff><h1>";
-    os << i18n("There is more than one matching man page.");
-    os << "</h1>\n<ul>";
+    os << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Strict//EN\">" << endl;
+    os << "<html>\n<head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">"<<endl;
+    os << "<title>" << i18n("Man output") <<"</title>" << endl;
+    if ( !m_manCSSFile.isEmpty() )
+        os << "<link href=\"file:///" << m_manCSSFile << "\" type=\"text/css\" rel=\"stylesheet\">" << endl;
+    os << "</head>" <<endl;
+    os << "<body><h1>" << i18n("There is more than one matching man page.");
+    os << "</h1>\n<ul>\n";
+    
+    int acckey=1;
     for (QStringList::ConstIterator it = matchingPages.begin(); it != matchingPages.end(); ++it)
-       os<<"<li><a href=man:"<<QFile::encodeName(*it)<<">"<< *it <<"</a><br>\n<br>\n";
-    os<< "</ul>\n</body>\n</html>"<<endl;
+    {
+      os<<"<li><a href='man:"<<(*it)<<"' accesskey='"<< acckey <<"'>"<< *it <<"</a><br>\n<br>\n";
+      acckey++;
+    }
+    os << "</ul>\n";
+    os << "<hr>\n";
+    os << "<p>" << i18n("Note: if you read a man page in your language,"
+       " be aware it can contain some mistakes or be obsolete."
+       " In case of doubt, you should have a look at the English version.") << "</p>";
 
-    data(output.utf8());
+    os << "</body>\n</html>"<<endl;
+
+    data(array);
     finished();
 }
 
@@ -624,7 +689,7 @@ void MANProtocol::stat( const KURL& url)
 extern "C"
 {
 
-    int kdemain( int argc, char **argv ) {
+    int KDE_EXPORT kdemain( int argc, char **argv ) {
 
         KInstance instance("kio_man");
 
@@ -652,7 +717,7 @@ void MANProtocol::mimetype(const KURL & /*url*/)
     finished();
 }
 
-QString sectionName(const QString& section)
+static QString sectionName(const QString& section)
 {
     if (section == "1")
         return i18n("User Commands");
@@ -707,16 +772,21 @@ QStringList MANProtocol::buildSectionList(const QStringList& dirs) const
 
 void MANProtocol::showMainIndex()
 {
-    QString output;
-
-    QTextStream os(&output, IO_WriteOnly);
+    QByteArray array;
+    QTextStream os(array, IO_WriteOnly);
+    os.setEncoding(QTextStream::UnicodeUTF8);
 
     // print header
+    os << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Strict//EN\">" << endl;
     os << "<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">" << endl;
-    os << "<head><title>" << i18n("UNIX Manual Index") << "</title></head>" << endl;
-    os << i18n("<body bgcolor=#ffffff><h1>UNIX Manual Index</h1>") << endl;
+    os << "<title>" << i18n("UNIX Manual Index") << "</title>" << endl;
+    if (!m_manCSSFile.isEmpty())
+        os << "<link href=\"file:///" << m_manCSSFile << "\" type=\"text/css\" rel=\"stylesheet\">" << endl;
+    os << "</head>" << endl;
+    os << "<body><h1>" << i18n("UNIX Manual Index") << "</h1>" << endl;
 
-    QString sectList = getenv("MANSECT");
+    // ### TODO: why still the environment variable
+    const QString sectList = getenv("MANSECT");
     QStringList sections;
     if (sectList.isEmpty())
     	sections = buildSectionList(manDirectories());
@@ -727,17 +797,186 @@ void MANProtocol::showMainIndex()
 
     QStringList::ConstIterator it;
     for (it = sections.begin(); it != sections.end(); ++it)
-        os << "<tr><td><a href=\"man:(" << *it << ")\">" << i18n("Section ") << *it << "</a></td><td>&nbsp;</td><td> " << sectionName(*it) << "</td></tr>" << endl;
+        os << "<tr><td><a href=\"man:(" << *it << ")\" accesskey=\"" << 
+	(((*it).length()==1)?(*it):(*it).right(1))<<"\">" << i18n("Section ") 
+	<< *it << "</a></td><td>&nbsp;</td><td> " << sectionName(*it) << "</td></tr>" << endl;
 
     os << "</table>" << endl;
 
     // print footer
     os << "</body></html>" << endl;
 
-    data(output.utf8());
+    data(array);
     finished();
 }
 
+void MANProtocol::constructPath(QStringList& constr_path, QStringList constr_catmanpath)
+{
+    QMap<QString, QString> manpath_map;
+    QMap<QString, QString> mandb_map;
+
+    // Add paths from /etc/man.conf
+    //
+    // Explicit manpaths may be given by lines starting with "MANPATH" or
+    // "MANDATORY_MANPATH" (depending on system ?).
+    // Mappings from $PATH to manpath are given by lines starting with
+    // "MANPATH_MAP"
+
+    QRegExp manpath_regex( "^MANPATH\\s" );
+    QRegExp mandatory_regex( "^MANDATORY_MANPATH\\s" );
+    QRegExp manpath_map_regex( "^MANPATH_MAP\\s" );
+    QRegExp mandb_map_regex( "^MANDB_MAP\\s" );
+    //QRegExp section_regex( "^SECTION\\s" );
+    QRegExp space_regex( "\\s+" ); // for parsing manpath map
+
+    QFile mc("/etc/man.conf");             // Caldera
+    if (!mc.exists())
+        mc.setName("/etc/manpath.config"); // SuSE, Debian
+    if (!mc.exists())
+        mc.setName("/etc/man.config");  // Mandrake
+
+    if (mc.open(IO_ReadOnly))
+    {
+        QTextStream is(&mc);
+        is.setEncoding(QTextStream::Locale);
+    
+        while (!is.eof())
+        {
+            const QString line = is.readLine();
+            if ( manpath_regex.search(line, 0) == 0 )
+            {
+                const QString path = line.mid(8).stripWhiteSpace();
+                constr_path += path;
+            }
+            else if ( mandatory_regex.search(line, 0) == 0 )
+            {
+                const QString path = line.mid(18).stripWhiteSpace();
+                constr_path += path;
+            }
+            else if ( manpath_map_regex.search(line, 0) == 0 )
+            {
+                        // The entry is "MANPATH_MAP  <path>  <manpath>"
+                const QStringList mapping =
+                        QStringList::split(space_regex, line);
+    
+                if ( mapping.count() == 3 )
+                {
+                    const QString dir = QDir::cleanDirPath( mapping[1] );
+                    const QString mandir = QDir::cleanDirPath( mapping[2] );
+    
+                    manpath_map[ dir ] = mandir;
+                }
+            }
+            else if ( mandb_map_regex.search(line, 0) == 0 )
+            {
+                        // The entry is "MANDB_MAP  <manpath>  <catmanpath>"
+                const QStringList mapping =
+                        QStringList::split(space_regex, line);
+    
+                if ( mapping.count() == 3 )
+                {
+                    const QString mandir = QDir::cleanDirPath( mapping[1] );
+                    const QString catmandir = QDir::cleanDirPath( mapping[2] );
+    
+                    mandb_map[ mandir ] = catmandir;
+                }
+            }
+    /* sections are not used
+            else if ( section_regex.find(line, 0) == 0 )
+            {
+            if ( !conf_section.isEmpty() )
+            conf_section += ':';
+            conf_section += line.mid(8).stripWhiteSpace();
+        }
+    */
+        }
+        mc.close();
+    }
+
+    // Default paths
+    static const char *manpaths[] = {
+        "/usr/X11/man",
+        "/usr/X11R6/man",
+        "/usr/man",
+        "/usr/local/man",
+        "/usr/exp/man",
+        "/usr/openwin/man",
+        "/usr/dt/man",
+        "/opt/freetool/man",
+        "/opt/local/man",
+        "/usr/tex/man",
+        "/usr/www/man",
+        "/usr/lang/man",
+        "/usr/gnu/man",
+        "/usr/share/man",
+        "/usr/motif/man",
+        "/usr/titools/man",
+        "/usr/sunpc/man",
+        "/usr/ncd/man",
+        "/usr/newsprint/man",
+        NULL };
+
+
+    int i = 0;
+    while (manpaths[i]) {
+        if ( constr_path.findIndex( QString( manpaths[i] ) ) == -1 )
+            constr_path += QString( manpaths[i] );
+        i++;
+    }
+
+    // Directories in $PATH
+    // - if a manpath mapping exists, use that mapping
+    // - if a directory "<path>/man" or "<path>/../man" exists, add it
+    //   to the man path (the actual existence check is done further down)
+
+    if ( ::getenv("PATH") ) {
+        const QStringList path =
+                QStringList::split( ":",
+                                    QString::fromLocal8Bit( ::getenv("PATH") ) );
+
+        for ( QStringList::const_iterator it = path.begin();
+              it != path.end();
+              ++it )
+        {
+            const QString dir = QDir::cleanDirPath( *it );
+            QString mandir = manpath_map[ dir ];
+
+            if ( !mandir.isEmpty() ) {
+                                // a path mapping exists
+                if ( constr_path.findIndex( mandir ) == -1 )
+                    constr_path += mandir;
+            }
+            else {
+                                // no manpath mapping, use "<path>/man" and "<path>/../man"
+
+                mandir = dir + QString( "/man" );
+                if ( constr_path.findIndex( mandir ) == -1 )
+                    constr_path += mandir;
+
+                int pos = dir.findRev( '/' );
+                if ( pos > 0 ) {
+                    mandir = dir.left( pos ) + QString("/man");
+                    if ( constr_path.findIndex( mandir ) == -1 )
+                        constr_path += mandir;
+                }
+            }
+            QString catmandir = mandb_map[ mandir ];
+            if ( !mandir.isEmpty() )
+            {
+                if ( constr_catmanpath.findIndex( catmandir ) == -1 )
+                    constr_catmanpath += catmandir;
+            }
+            else
+            {
+            // What is the default mapping?
+                catmandir = mandir;
+                catmandir.replace("/usr/share/","/var/cache/");
+                if ( constr_catmanpath.findIndex( catmandir ) == -1 )
+                    constr_catmanpath += catmandir;
+            }
+        }
+    }
+}
 
 void MANProtocol::checkManPaths()
 {
@@ -748,7 +987,7 @@ void MANProtocol::checkManPaths()
 
     inited = true;
 
-    QString manpath_env = QString::fromLocal8Bit( ::getenv("MANPATH") );
+    const QString manpath_env = QString::fromLocal8Bit( ::getenv("MANPATH") );
     //QString mansect_env = QString::fromLocal8Bit( ::getenv("MANSECT") );
 
     // Decide if $MANPATH is enough on its own or if it should be merged
@@ -761,7 +1000,7 @@ void MANProtocol::checkManPaths()
     if ( manpath_env.isEmpty()
         || manpath_env[0] == ':'
         || manpath_env[manpath_env.length()-1] == ':'
-        || manpath_env.contains( QString("::") ) )
+        || manpath_env.contains( "::" ) )
     {
         construct_path = true; // need to read config file
     }
@@ -771,145 +1010,17 @@ void MANProtocol::checkManPaths()
     //   default dirs
     //   $PATH
     QStringList constr_path;
+    QStringList constr_catmanpath; // catmanpath
 
     QString conf_section;
 
-    if ( construct_path ) {
-        QMap<QString, QString> manpath_map;
-
-        // Add paths from /etc/man.conf
-        //
-        // Explicit manpaths may be given by lines starting with "MANPATH" or
-        // "MANDATORY_MANPATH" (depending on system ?).
-        // Mappings from $PATH to manpath are given by lines starting with
-        // "MANPATH_MAP"
-
-        QRegExp manpath_regex( "^MANPATH\\s" );
-        QRegExp mandatory_regex( "^MANDATORY_MANPATH\\s" );
-        QRegExp manpath_map_regex( "^MANPATH_MAP\\s" );
-        //QRegExp section_regex( "^SECTION\\s" );
-        QRegExp space_regex( "\\s+" ); // for parsing manpath map
-
-        QFile mc("/etc/man.conf");             // Caldera
-        if (!mc.exists())
-            mc.setName("/etc/manpath.config"); // SuSE, Debian
-        if (!mc.exists())
-            mc.setName("/etc/man.config");  // Mandrake
-
-        if (mc.open(IO_ReadOnly))
-        {
-            QTextStream is(&mc);
-	    is.setEncoding(QTextStream::Locale);
-
-            while (!is.eof())
-            {
-                QString line = is.readLine();
-                if ( manpath_regex.search(line, 0) == 0 )
-                {
-                    QString path = line.mid(8).stripWhiteSpace();
-                    constr_path += path;
-                }
-                else if ( mandatory_regex.search(line, 0) == 0 )
-                {
-                    QString path = line.mid(18).stripWhiteSpace();
-                    constr_path += path;
-                }
-                else if ( manpath_map_regex.search(line, 0) == 0 )
-                {
-                    // The entry is "MANPATH_MAP  <path>  <manpath>"
-                    QStringList mapping =
-                        QStringList::split(space_regex, line);
-
-                    if ( mapping.count() == 3 ) {
-                        QString dir = QDir::cleanDirPath( mapping[1] );
-                        QString mandir = QDir::cleanDirPath( mapping[2] );
-
-                        manpath_map[ dir ] = mandir;
-                    }
-                }
-/* sections are not used
-                else if ( section_regex.find(line, 0) == 0 )
-                {
-                    if ( !conf_section.isEmpty() )
-                        conf_section += ':';
-                    conf_section += line.mid(8).stripWhiteSpace();
-                }
-*/
-            }
-            mc.close();
-        }
-
-        // Default paths
-        static const char *manpaths[] = {
-                        "/usr/X11/man",
-                        "/usr/X11R6/man",
-                        "/usr/man",
-                        "/usr/local/man",
-                        "/usr/exp/man",
-                        "/usr/openwin/man",
-                        "/usr/dt/man",
-                        "/opt/freetool/man",
-                        "/opt/local/man",
-                        "/usr/tex/man",
-                        "/usr/www/man",
-                        "/usr/lang/man",
-                        "/usr/gnu/man",
-                        "/usr/share/man",
-                        "/usr/motif/man",
-                        "/usr/titools/man",
-                        "/usr/sunpc/man",
-                        "/usr/ncd/man",
-                        "/usr/newsprint/man",
-                        NULL };
-
-
-        int i = 0;
-        while (manpaths[i]) {
-            if ( constr_path.findIndex( QString( manpaths[i] ) ) == -1 )
-                 constr_path += QString( manpaths[i] );
-            i++;
-        }
-
-        // Directories in $PATH
-        // - if a manpath mapping exists, use that mapping
-        // - if a directory "<path>/man" or "<path>/../man" exists, add it
-        //   to the man path (the actual existence check is done further down)
-
-        if ( ::getenv("PATH") ) {
-            QStringList path =
-                QStringList::split( ":",
-                    QString::fromLocal8Bit( ::getenv("PATH") ) );
-
-            for ( QStringList::Iterator it = path.begin();
-                  it != path.end();
-                  it++ )
-            {
-                QString dir = QDir::cleanDirPath( *it );
-                QString mandir = manpath_map[ dir ];
-
-                if ( !mandir.isEmpty() ) {
-					// a path mapping exists
-                    if ( constr_path.findIndex( mandir ) == -1 )
-                        constr_path += mandir;
-                }
-                else {
-					// no manpath mapping, use "<path>/man" and "<path>/../man"
-
-                    mandir = dir + QString( "/man" );
-                    if ( constr_path.findIndex( mandir ) == -1 )
-                        constr_path += mandir;
-
-                    int pos = dir.findRev( '/' );
-                    if ( pos > 0 ) {
-                        mandir = dir.left( pos ) + QString("/man");
-                        if ( constr_path.findIndex( mandir ) == -1 )
-                            constr_path += mandir;
-                    }
-                }
-            }
-        }
-    } // construct_path
+    if ( construct_path )
+    {
+        constructPath(constr_path, constr_catmanpath);
+    }
 
+    m_mandbpath=constr_catmanpath;
+    
     // Merge $MANPATH with the constructed path to form the
     // actual manpath.
     //
@@ -917,11 +1028,11 @@ void MANProtocol::checkManPaths()
     // satisfied if any empty string in path_list_env (there
     // should be 1 or 0) is replaced by the constructed path.
 
-    QStringList path_list_env = QStringList::split( ':', manpath_env , true );
+    const QStringList path_list_env = QStringList::split( ':', manpath_env , true );
 
-    for ( QStringList::Iterator it = path_list_env.begin();
+    for ( QStringList::const_iterator it = path_list_env.begin();
           it != path_list_env.end();
-          it++ )
+          ++it )
     {
         struct stat sbuf;
 
@@ -1012,7 +1123,7 @@ int compare_man_index(const void *s1, const void *s2)
     // this is a bit tricky
     if ( m1->manpage_len > m2->manpage_len)
     {
-	i = qstrncmp( m1->manpage_begin,
+	i = qstrnicmp( m1->manpage_begin,
 		      m2->manpage_begin,
 		      m2->manpage_len);
 	if (!i)
@@ -1022,7 +1133,7 @@ int compare_man_index(const void *s1, const void *s2)
 
     if ( m1->manpage_len < m2->manpage_len)
     {
-	i = qstrncmp( m1->manpage_begin,
+	i = qstrnicmp( m1->manpage_begin,
 		      m2->manpage_begin,
 		      m1->manpage_len);
 	if (!i)
@@ -1030,7 +1141,7 @@ int compare_man_index(const void *s1, const void *s2)
 	return i;
     }
 
-    return qstrncmp( m1->manpage_begin,
+    return qstrnicmp( m1->manpage_begin,
 		     m2->manpage_begin,
 		     m1->manpage_len);
 }
@@ -1055,7 +1166,7 @@ private:
 	    // with the shorter length
 	    if (m1->manpage_len > m2->manpage_len)
 	    {
-		i = qstrncmp(m1->manpage_begin,
+		i = qstrnicmp(m1->manpage_begin,
 			     m2->manpage_begin,
 			     m2->manpage_len);
 		if (!i)
@@ -1066,7 +1177,7 @@ private:
 	    if (m1->manpage_len > m2->manpage_len)
 	    {
 
-		i = qstrncmp(m1->manpage_begin,
+		i = qstrnicmp(m1->manpage_begin,
 			     m2->manpage_begin,
 			     m1->manpage_len);
 		if (!i)
@@ -1074,7 +1185,7 @@ private:
 		return i;
 	    }
 
-	    return qstrncmp(m1->manpage_begin,
+	    return qstrnicmp(m1->manpage_begin,
 			    m2->manpage_begin,
 			    m1->manpage_len);
 	}
@@ -1088,14 +1199,19 @@ private:
 
 void MANProtocol::showIndex(const QString& section)
 {
-    QString output;
-
-    QTextStream os(&output, IO_WriteOnly);
+    QByteArray array;
+    QTextStream os(array, IO_WriteOnly);
+    os.setEncoding(QTextStream::UnicodeUTF8);
 
     // print header
+    os << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Strict//EN\">" << endl;
     os << "<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">" << endl;
-    os << "<head><title>" << i18n("UNIX Manual Index") << "</title></head>" << endl;
-    os << i18n("<body bgcolor=#ffffff><h1>Index for Section %1: %2</h1>").arg(section).arg(sectionName(section)) << endl;
+    os << "<title>" << i18n("UNIX Manual Index") << "</title>" << endl;
+    if ( !m_manCSSFile.isEmpty() )
+        os << "<link href=\"file:///" << m_manCSSFile << "\" type=\"text/css\" rel=\"stylesheet\">" << endl;
+    os << "</head>" << endl;
+    os << "<body><div class=\"secidxmain\">" << endl;
+    os << "<h1>" << i18n( "Index for Section %1: %2").arg(section).arg(sectionName(section)) << "</h1>" << endl;
 
     // compose list of search paths -------------------------------------------------------------
 
@@ -1155,7 +1271,7 @@ void MANProtocol::showIndex(const QString& section)
 
 #endif /* _USE_QSORT */
 
-    QStringList::ConstIterator page;
+    QStringList::const_iterator page;
     for (page = pages.begin(); page != pages.end(); ++page)
     {
 	// I look for the beginning of the man page name
@@ -1249,6 +1365,20 @@ void MANProtocol::showIndex(const QString& section)
     // sort and print
     qsort(indexlist, listlen, sizeof(struct man_index_t *), compare_man_index);
 
+    QChar firstchar, tmp;
+    QString indexLine="<div class=\"secidxshort\">\n";
+    if (indexlist[0]->manpage_len>0)
+    {
+	firstchar=QChar((indexlist[0]->manpage_begin)[0]).lower();
+
+	const QString appendixstr = QString(
+	    " [<a href=\"#%1\" accesskey=\"%2\">%3</a>]\n"
+	).arg(firstchar).arg(firstchar).arg(firstchar);
+	indexLine.append(appendixstr);
+    }
+    os << "<tr><td class=\"secidxnextletter\"" << " colspan=\"3\">\n  <a name=\"" 
+       << firstchar << "\">" << firstchar <<"</a>\n</td></tr>" << endl;
+
     for (int i=0; i<listlen; i++)
     {
 	struct man_index_t *manindex = indexlist[i];
@@ -1265,6 +1395,19 @@ void MANProtocol::showIndex(const QString& section)
 	{
 	    continue;
 	}
+	
+	tmp=QChar((manindex->manpage_begin)[0]).lower();
+	if (firstchar != tmp)
+	{
+	    firstchar = tmp;
+	    os << "<tr><td class=\"secidxnextletter\"" << " colspan=\"3\">\n  <a name=\"" 
+	       << firstchar << "\">" << firstchar << "</a>\n</td></tr>" << endl;
+
+    	    const QString appendixstr = QString(
+    		" [<a href=\"#%1\" accesskey=\"%2\">%3</a>]\n"
+	    ).arg(firstchar).arg(firstchar).arg(firstchar);
+	    indexLine.append(appendixstr);
+	}
 	os << "<tr><td><a href=\"man:"
 	   << manindex->manpath << "\">\n";
 
@@ -1275,6 +1418,7 @@ void MANProtocol::showIndex(const QString& section)
 	   << "</td></tr>"  << endl;
 	last_index = manindex;
     }
+    indexLine.append("</div>");
 
     for (int i=0; i<listlen; i++) {
 	::free(indexlist[i]->manpath);   // allocated by strdup
@@ -1319,14 +1463,16 @@ void MANProtocol::showIndex(const QString& section)
 #endif /* _USE_QSORT */
 #endif /* _USE_OLD_CODE */
 
-    os << "</table>" << endl;
+    os << "</table></div>" << endl;
+    
+    os << indexLine << endl;
 
     // print footer
     os << "</body></html>" << endl;
 
     infoMessage(QString::null);
     mimeType("text/html");
-    data(output.utf8());
+    data(array);
     finished();
 }
 
@@ -1354,7 +1500,7 @@ void MANProtocol::listDir(const KURL &url)
     QStringList::Iterator it = list.begin();
     QStringList::Iterator end = list.end();
 
-    for ( ; it != end; it++ ) {
+    for ( ; it != end; ++it ) {
         stripExtension( &(*it) );
 
         uds_entry[0].m_str = *it;
