@@ -40,6 +40,8 @@ Medium::Medium(const QString &id, const QString &name)
 	m_properties+= QString::null; /* ICON_NAME */
 
 	loadUserLabel();
+
+	m_halmounted = false;
 }
 
 Medium::Medium()
@@ -57,6 +59,8 @@ Medium::Medium()
 	m_properties+= QString::null; /* BASE_URL */
 	m_properties+= QString::null; /* MIME_TYPE */
 	m_properties+= QString::null; /* ICON_NAME */
+	
+	m_halmounted = false;
 }
 
 const Medium Medium::create(const QStringList &properties)
@@ -159,7 +163,7 @@ void Medium::loadUserLabel()
 bool Medium::mountableState(bool mounted)
 {
 	if ( m_properties[DEVICE_NODE].isEmpty()
-	  || m_properties[MOUNT_POINT].isEmpty() )
+	  || ( mounted && m_properties[MOUNT_POINT].isEmpty() ) )
 	{
 		return false;
 	}
@@ -204,14 +208,10 @@ bool Medium::needMounting() const
 
 KURL Medium::prettyBaseURL() const
 {
-	if ( isMountable() )
-	{
+        if ( !baseURL().isEmpty() )
+            return baseURL();
+
 		return KURL( mountPoint() );
-	}
-	else
-	{
-		return KURL( baseURL() );
-	}
 }
 
 QString Medium::prettyLabel() const
