@@ -322,6 +322,8 @@ void HALBackend::DeviceCondition(const char* udi, const char* condition)
 	    QPtrListIterator<Medium> it (medlist);
 	    for ( const Medium *current_medium = it.current(); current_medium; current_medium = ++it)
             {
+                if( current_medium->id().startsWith( "/org/kde" ))
+                    continue;
 		QString driveUdi = libhal_device_get_property_QString(m_halContext, current_medium->id().latin1(), "block.storage_device");
 		if (driveUdi == udi)
                 {
@@ -849,6 +851,13 @@ QStringList HALBackend::mountoptions(const QString &name)
         result << tmp;
     }
 
+	if ( valids.contains("locale") )
+	{
+		value = config.readBoolEntry( "locale", true );
+		tmp = QString( "locale=%1" ).arg( value ? "true" : "false" );
+		result << tmp;
+	}
+
     if (valids.contains("utf8"))
     {
         value = config.readBoolEntry("utf8", true);
@@ -922,7 +931,7 @@ bool HALBackend::setMountoptions(const QString &name, const QStringList &options
 
     QMap<QString,QString> valids = MediaManagerUtils::splitOptions(options);
 
-    const char *names[] = { "ro", "quiet", "atime", "uid", "utf8", "flush", "sync", 0 };
+    const char *names[] = { "ro", "quiet", "atime", "uid", "utf8", "flush", "sync", "locale", 0 };
     for (int index = 0; names[index]; ++index)
         if (valids.contains(names[index]))
             config.writeEntry(names[index], valids[names[index]] == "true");
@@ -942,6 +951,10 @@ bool HALBackend::setMountoptions(const QString &name, const QStringList &options
         config.writeEntry("automount", valids["automount"]);
     }
 
+	if (valids.contains("locale") ) {
+		config.writeEntry("locale", valids["locale"]);
+	}
+
     return true;
 }
 
@@ -1140,6 +1153,11 @@ QString HALBackend::mount(const Medium *medium)
         soptions << QString("uid=%1").arg(getuid());
     }
 
+    if (valids["locale"] == "true")
+	{
+		soptions << QString("locale=%1").arg( KGlobal::locale()->language() ); 
+	}
+
     if (valids["ro"] == "true")
         soptions << "ro";
 
