@@ -48,6 +48,11 @@ MediaNotifier::MediaNotifier(const QCString &name) : KDEDModule(name)
 
 MediaNotifier::~MediaNotifier()
 {
+	disconnectDCOPSignal( "kded", "mediamanager", "mediumAdded(QString, bool)",
+	                      "onMediumChange(QString, bool)" );
+	
+	disconnectDCOPSignal( "kded", "mediamanager", "mediumChanged(QString, bool)",
+	                      "onMediumChange(QString, bool)" );
 }
 
 void MediaNotifier::onMediumChange( const QString &name, bool allowNotification )
