@@ -1,6 +1,5 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: process.cpp,v 1.9 2002/09/16 00:08:26 fisher Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -61,6 +60,8 @@ MyPtyProcess::MyPtyProcess()
     m_bTerminal = false;
     m_bErase = false;
     m_pPTY = 0L;
+    m_Pid = -1;
+    m_Fd = -1;
 }
 
 
@@ -194,9 +195,10 @@ void MyPtyProcess::unreadLineFrom(QCString inbuf, QCString line, bool addnl)
 
 int MyPtyProcess::exec(QCString command, QCStringList args)
 {
-    kdDebug(PTYPROC) << "MyPtyProcess::exec()" << endl;
+  kdDebug(PTYPROC) << "MyPtyProcess::exec(): " << command << endl;// << ", args = " << args << endl;
+
     if (init() < 0)
-	return -1;
+        return -1;
 
     // Open the pty slave before forking. See SetupTTY()
     int slave = open(m_TTY, O_RDWR);
