@@ -24,7 +24,6 @@
 #include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <dcopclient.h>
-#include <dcopref.h>
 
 #include <qeventloop.h>
 
@@ -49,8 +48,6 @@ extern "C" {
 		KApplication app( false, false );
 		// We want to be anonymous even if we use DCOP
 		app.dcopClient()->attach();
-		DCOPRef ref( "kded", "kded" );
-		ref.call( "loadModule", "systemdirnotify" );
 
 		KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 		SystemProtocol slave( args->arg(0), args->arg(1), args->arg(2) );
