@@ -13,24 +13,26 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _KIO_MEDIA_H_
 #define _KIO_MEDIA_H_
 
-#include <kio/slavebase.h>
+#include <kio/forwardingslavebase.h>
 
 #include "systemimpl.h"
 
-class SystemProtocol : public KIO::SlaveBase
+class SystemProtocol : public KIO::ForwardingSlaveBase
 {
 public:
 	SystemProtocol(const QCString &protocol, const QCString &pool,
 	               const QCString &app);
 	virtual ~SystemProtocol();
-
+	
+	virtual bool rewriteURL(const KURL &url, KURL &newUrl);
+	
 	virtual void stat(const KURL &url);
 	virtual void listDir(const KURL &url);
 
