@@ -1,10 +1,15 @@
+#include <config.h>
 
 #include <sys/types.h>
+#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
+#endif
 #include <stdlib.h>
 #include <unistd.h>
 
 #include <qfile.h>
+
+#include <kglobal.h>
 #include <kurl.h>
 #include <kdebug.h>
 #include <kinstance.h>
@@ -12,6 +17,10 @@
 #include <kzip.h>
 #include <kar.h>
 #include <kmimemagic.h>
+#include <klocale.h>
+#include <kde_file.h>
+#include <kio/global.h>
+#include <kremoteencoding.h>
 
 #include <errno.h> // to be removed
 
@@ -51,7 +60,7 @@ ArchiveProtocol::~ArchiveProtocol()
     delete m_archiveFile;
 }
 
-bool ArchiveProtocol::checkNewFile( const KURL & url, QString & path )
+bool ArchiveProtocol::checkNewFile( const KURL & url, QString & path, KIO::Error& errorNum )
 {
     QString fullPath = url.path();
     kdDebug(7109) << "ArchiveProtocol::checkNewFile " << fullPath << endl;
@@ -61,8 +70,8 @@ bool ArchiveProtocol::checkNewFile( const KURL & url, QString & path )
     if ( m_archiveFile && m_archiveName == fullPath.left(m_archiveName.length()) )
     {
         // Has it changed ?
-        struct stat statbuf;
-        if ( ::stat( QFile::encodeName( m_archiveName ), &statbuf ) == 0 )
+        KDE_struct_stat statbuf;
+        if ( KDE_stat( QFile::encodeName( m_archiveName ), &statbuf ) == 0 )
         {
             if ( m_mtime == statbuf.st_mtime )
             {
@@ -92,12 +101,18 @@ bool ArchiveProtocol::checkNewFile( const KURL & url, QString & path )
         fullPath += '/';
 
     kdDebug(7109) << "the full path is " << fullPath << endl;
+    KDE_struct_stat statbuf;
+    statbuf.st_mode = 0; // be sure to clear the directory bit
     while ( (pos=fullPath.find( '/', pos+1 )) != -1 )
     {
         QString tryPath = fullPath.left( pos );
         kdDebug(7109) << fullPath << "  trying " << tryPath << endl;
-        struct stat statbuf;
-        if ( ::stat( QFile::encodeName(tryPath), &statbuf ) == 0 && !S_ISDIR(statbuf.st_mode) )
+        if ( KDE_stat( QFile::encodeName(tryPath), &statbuf ) == -1 )
+        {
+            // We are not in the file system anymore, either we have already enough data or we will never get any useful data anymore
+            break;
+        }
+        if ( !S_ISDIR(statbuf.st_mode) )
         {
             archiveFile = tryPath;
             m_mtime = statbuf.st_mtime;
@@ -118,6 +133,14 @@ bool ArchiveProtocol::checkNewFile( const KURL & url, QString & path )
     if ( archiveFile.isEmpty() )
     {
         kdDebug(7109) << "ArchiveProtocol::checkNewFile: not found" << endl;
+        if ( S_ISDIR(statbuf.st_mode) ) // Was the last stat about a directory?
+        {
+            // Too bad, it is a directory, not an archive.
+            kdDebug(7109) << "Path is a directory, not an archive." << endl;
+            errorNum = KIO::ERR_IS_DIRECTORY;
+        }
+        else
+            errorNum = KIO::ERR_DOES_NOT_EXIST;
         return false;
     }
 
@@ -133,6 +156,7 @@ bool ArchiveProtocol::checkNewFile( const KURL & url, QString & path )
         m_archiveFile = new KZip( archiveFile );
     } else {
         kdWarning(7109) << "Protocol " << url.protocol() << " not supported by this IOSlave" << endl;
+        errorNum = KIO::ERR_UNSUPPORTED_PROTOCOL;
         return false;
     }
 
@@ -141,6 +165,7 @@ bool ArchiveProtocol::checkNewFile( const KURL & url, QString & path )
         kdDebug(7109) << "Opening " << archiveFile << "failed." << endl;
         delete m_archiveFile;
         m_archiveFile = 0L;
+        errorNum = KIO::ERR_CANNOT_OPEN_FOR_READING;
         return false;
     }
 
@@ -154,7 +179,7 @@ void ArchiveProtocol::createUDSEntry( const KArchiveEntry * archiveEntry, UDSEnt
     UDSAtom atom;
     entry.clear();
     atom.m_uds = UDS_NAME;
-    atom.m_str = archiveEntry->name();
+    atom.m_str = remoteEncoding()->decode(archiveEntry->name().local8Bit());
     entry.append(atom);
 
     atom.m_uds = UDS_FILE_TYPE;
@@ -174,30 +199,39 @@ void ArchiveProtocol::createUDSEntry( const KArchiveEntry * archiveEntry, UDSEnt
     entry.append( atom );
 
     atom.m_uds = UDS_USER;
-    atom.m_str = archiveEntry->user();
+    atom.m_str = remoteEncoding()->decode(archiveEntry->user().local8Bit());
     entry.append( atom );
 
     atom.m_uds = UDS_GROUP;
-    atom.m_str = archiveEntry->group();
+    atom.m_str = remoteEncoding()->decode(archiveEntry->group().local8Bit());
     entry.append( atom );
 
     atom.m_uds = UDS_LINK_DEST;
-    atom.m_str = archiveEntry->symlink();
+    atom.m_str = remoteEncoding()->decode(archiveEntry->symlink().local8Bit());
     entry.append( atom );
 }
 
 void ArchiveProtocol::listDir( const KURL & url )
 {
-    kdDebug( 7109 ) << "ArchiveProtocol::listDir " << url.url() << endl;
+    kdDebug( 7109 ) << "ArchiveProtocol::listDir " << url << endl;
 
     QString path;
-    if ( !checkNewFile( url, path ) )
+    KIO::Error errorNum;
+    if ( !checkNewFile( url, path, errorNum ) )
     {
-        QCString _path( QFile::encodeName(url.path()));
-        kdDebug( 7109 ) << "Checking (stat) on " << _path << endl;
-        struct stat buff;
-        if ( ::stat( _path.data(), &buff ) == -1 || !S_ISDIR( buff.st_mode ) ) {
-            error( KIO::ERR_DOES_NOT_EXIST, url.prettyURL() );
+        if ( errorNum == KIO::ERR_CANNOT_OPEN_FOR_READING )
+        {
+            // If we cannot open, it might be a problem with the archive header (e.g. unsupported format)
+            // Therefore give a more specific error message
+            error( KIO::ERR_SLAVE_DEFINED,
+                   i18n( "Could not open the file, probably due to an unsupported file format.\n%1")
+                           .arg( url.prettyURL() ) );
+            return;
+        }
+        else if ( errorNum != ERR_IS_DIRECTORY )
+        {
+            // We have any other error
+            error( errorNum, url.prettyURL() );
             return;
         }
         // It's a real dir -> redirect
@@ -223,6 +257,8 @@ void ArchiveProtocol::listDir( const KURL & url )
         return;
     }
 
+    path = QString::fromLocal8Bit(remoteEncoding()->encode(path));
+
     kdDebug( 7109 ) << "checkNewFile done" << endl;
     const KArchiveDirectory* root = m_archiveFile->directory();
     const KArchiveDirectory* dir;
@@ -271,16 +307,24 @@ void ArchiveProtocol::stat( const KURL & url )
 {
     QString path;
     UDSEntry entry;
-    if ( !checkNewFile( url, path ) )
+    KIO::Error errorNum;
+    if ( !checkNewFile( url, path, errorNum ) )
     {
         // We may be looking at a real directory - this happens
         // when pressing up after being in the root of an archive
-        QCString _path( QFile::encodeName(url.path()));
-        kdDebug( 7109 ) << "ArchiveProtocol::stat (stat) on " << _path << endl;
-        struct stat buff;
-        if ( ::stat( _path.data(), &buff ) == -1 || !S_ISDIR( buff.st_mode ) ) {
-            kdDebug( 7109 ) << "isdir=" << S_ISDIR( buff.st_mode ) << "  errno=" << strerror(errno) << endl;
-            error( KIO::ERR_DOES_NOT_EXIST, url.path() );
+        if ( errorNum == KIO::ERR_CANNOT_OPEN_FOR_READING )
+        {
+            // If we cannot open, it might be a problem with the archive header (e.g. unsupported format)
+            // Therefore give a more specific error message
+            error( KIO::ERR_SLAVE_DEFINED,
+                   i18n( "Could not open the file, probably due to an unsupported file format.\n%1")
+                           .arg( url.prettyURL() ) );
+            return;
+        }
+        else if ( errorNum != ERR_IS_DIRECTORY )
+        {
+            // We have any other error
+            error( errorNum, url.prettyURL() );
             return;
         }
         // Real directory. Return just enough information for KRun to work
@@ -290,6 +334,14 @@ void ArchiveProtocol::stat( const KURL & url )
         entry.append( atom );
         kdDebug( 7109 ) << "ArchiveProtocol::stat returning name=" << url.fileName() << endl;
 
+        KDE_struct_stat buff;
+        if ( KDE_stat( QFile::encodeName( url.path() ), &buff ) == -1 )
+        {
+            // Should not happen, as the file was already stated by checkNewFile
+            error( KIO::ERR_COULD_NOT_STAT, url.prettyURL() );
+            return;
+        }
+
         atom.m_uds = KIO::UDS_FILE_TYPE;
         atom.m_long = buff.st_mode & S_IFMT;
         entry.append( atom );
@@ -311,6 +363,7 @@ void ArchiveProtocol::stat( const KURL & url )
         path = QString::fromLatin1( "/" );
         archiveEntry = root;
     } else {
+        path = QString::fromLocal8Bit(remoteEncoding()->encode(path));
         archiveEntry = root->entry( path );
     }
     if ( !archiveEntry )
@@ -327,15 +380,31 @@ void ArchiveProtocol::stat( const KURL & url )
 
 void ArchiveProtocol::get( const KURL & url )
 {
-    kdDebug( 7109 ) << "ArchiveProtocol::get" << url.url() << endl;
+    kdDebug( 7109 ) << "ArchiveProtocol::get " << url << endl;
 
     QString path;
-    if ( !checkNewFile( url, path ) )
+    KIO::Error errorNum;
+    if ( !checkNewFile( url, path, errorNum ) )
     {
-        error( KIO::ERR_DOES_NOT_EXIST, url.prettyURL() );
-        return;
+        if ( errorNum == KIO::ERR_CANNOT_OPEN_FOR_READING )
+        {
+            // If we cannot open, it might be a problem with the archive header (e.g. unsupported format)
+            // Therefore give a more specific error message
+            error( KIO::ERR_SLAVE_DEFINED,
+                   i18n( "Could not open the file, probably due to an unsupported file format.\n%1")
+                           .arg( url.prettyURL() ) );
+            return;
+        }
+        else
+        {
+            // We have any other error
+            error( errorNum, url.prettyURL() );
+            return;
+        }
     }
 
+    path = QString::fromLocal8Bit(remoteEncoding()->encode(path));
+
     const KArchiveDirectory* root = m_archiveFile->directory();
     const KArchiveEntry* archiveEntry = root->entry( path );
 
@@ -353,37 +422,113 @@ void ArchiveProtocol::get( const KURL & url )
     if ( !archiveEntry->symlink().isEmpty() )
     {
       kdDebug(7109) << "Redirection to " << archiveEntry->symlink() << endl;
-      KURL realURL( url, archiveEntry->symlink() );
-      kdDebug(7109) << "realURL= " << realURL.url() << endl;
+      KURL realURL;
+      if (archiveEntry->symlink().startsWith("/")) { // absolute path
+          realURL.setPath(archiveEntry->symlink() ); // goes out of tar:/, back into file:
+      } else {
+          realURL = KURL( url, archiveEntry->symlink() );
+      }
+      kdDebug(7109) << "realURL= " << realURL << endl;
       redirection( realURL );
       finished();
       return;
     }
 
-    totalSize( archiveFileEntry->size() );
+    //kdDebug(7109) << "Preparing to get the archive data" << endl;
+    
+    /*
+     * The easy way would be to get the data by calling archiveFileEntry->data()
+     * However this has drawbacks:
+     * - the complete file must be read into the memory
+     * - errors are skipped, resulting in an empty file
+     */
 
-    QByteArray completeData = archiveFileEntry->data();
-
-    KMimeMagicResult * result = KMimeMagic::self()->findBufferFileType( completeData, path );
-    kdDebug(7109) << "Emitting mimetype " << result->mimeType() << endl;
-    mimeType( result->mimeType() );
-
-    QByteArray partialData;
-    int offset = 0;
-    const int inc = 0x800000; // 8MB
-
-    while ( offset + inc < archiveFileEntry->size() ) {
-        partialData.setRawData( completeData.data() + offset, inc );
-        data( partialData );
-        partialData.resetRawData( completeData.data() + offset, inc );
-        processedSize( offset + inc );
-	offset += inc;
+    QIODevice* io = 0;
+    // Getting the device is hard, as archiveFileEntry->device() is not virtual!
+    if ( url.protocol() == "tar" )
+    {
+        io = archiveFileEntry->device();
+    }
+    else if ( url.protocol() == "ar" )
+    {
+        io = archiveFileEntry->device();
+    }
+    else if ( url.protocol() == "zip" )
+    {
+        io = ((KZipFileEntry*) archiveFileEntry)->device();
+    }
+    else
+    {
+        // Wrong protocol? Why was this not catched by checkNewFile?
+        kdWarning(7109) << "Protocol " << url.protocol() << " not supported by this IOSlave; " << k_funcinfo << endl;
+        error( KIO::ERR_UNSUPPORTED_PROTOCOL, url.protocol() );
+        return;
     }
 
-    partialData.setRawData( completeData.data() + offset, archiveFileEntry->size() - offset );
-    data( partialData );
-    partialData.resetRawData( completeData.data() + offset, archiveFileEntry->size() - offset );
-    processedSize( archiveFileEntry->size() );
+    if (!io)
+    {
+        error( KIO::ERR_SLAVE_DEFINED,
+            i18n( "The archive file could not be opened, perhaps because the format is unsupported.\n%1" )
+                    .arg( url.prettyURL() ) );
+        return;
+    }
+    
+    if ( !io->open( IO_ReadOnly ) )
+    {
+        error( KIO::ERR_CANNOT_OPEN_FOR_READING, url.prettyURL() );
+        return;
+    }
+    
+    totalSize( archiveFileEntry->size() );
+
+    // Size of a QIODevice read. It must be large enough so that the mime type check will not fail
+    const int maxSize = 0x100000; // 1MB
+    
+    int bufferSize = kMin( maxSize, archiveFileEntry->size() );
+    QByteArray buffer ( bufferSize );
+    if ( buffer.isEmpty() && bufferSize > 0 )
+    {
+        // Something went wrong
+        error( KIO::ERR_OUT_OF_MEMORY, url.prettyURL() );
+        return;
+    }
+
+    bool firstRead = true;
+
+    // How much file do we still have to process?
+    int fileSize = archiveFileEntry->size();
+    KIO::filesize_t processed = 0;
+
+    while ( !io->atEnd() && fileSize > 0 )
+    {
+        if ( !firstRead )
+        {
+            bufferSize = kMin( maxSize, fileSize );
+            buffer.resize( bufferSize, QGArray::SpeedOptim );
+        }
+        const Q_LONG read = io->readBlock( buffer.data(), buffer.size() ); // Avoid to use bufferSize here, in case something went wrong.
+        if ( read != bufferSize )
+        {
+            kdWarning(7109) << "Read " << read << " bytes but expected " << bufferSize << endl;
+            error( KIO::ERR_COULD_NOT_READ, url.prettyURL() );
+            return;
+        }
+        if ( firstRead )
+        {
+            // We use the magic one the first data read
+            // (As magic detection is about fixed positions, we can be sure that it is enough data.)
+            KMimeMagicResult * result = KMimeMagic::self()->findBufferFileType( buffer, path );
+            kdDebug(7109) << "Emitting mimetype " << result->mimeType() << endl;
+            mimeType( result->mimeType() );
+            firstRead = false;
+        }
+        data( buffer );
+        processed += read;
+        processedSize( processed );
+        fileSize -= bufferSize;
+    }
+    io->close();
+    delete io;
 
     data( QByteArray() );
 
@@ -475,3 +620,4 @@ debug("void TARProtocol::filterData");
 }
 */
 
+// kate: space-indent on; indent-width 4; replace-tabs on;
