@@ -14,12 +14,10 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
-// $Id: imagecreator.cpp,v 1.11 2003/10/31 08:40:09 coolo Exp $
-
 #include <assert.h>
 
 #include <qimage.h>
@@ -30,7 +28,7 @@
 
 extern "C"
 {
-    ThumbCreator *new_creator()
+    KDE_EXPORT ThumbCreator *new_creator()
     {
         KImageIO::registerFormats();
         return new ImageCreator;
