@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <qfile.h>
@@ -24,6 +24,7 @@
 
 #include <kstandarddirs.h>
 #include <kpixmapsplitter.h>
+#include <kmimetype.h>
 
 #include "textcreator.h"
 
@@ -50,6 +51,11 @@ TextCreator::~TextCreator()
 
 bool TextCreator::create(const QString &path, int width, int height, QImage &img)
 {
+    // Filter out unwanted mimetypes
+    KMimeType::Ptr mimeType = KMimeType::findByPath( path );
+    if ( mimeType->is( "text/rtf" ) )
+        return false;
+
     if ( !m_splitter )
     {
         m_splitter = new KPixmapSplitter;
