@@ -404,6 +404,8 @@ void ThumbnailProtocol::get(const KURL &url)
             shmdt((char*)shmaddr);
             return;
         }
+        if( img.depth() != 32 )           // KIO::PreviewJob and this code below completely
+            img = img.convertDepth( 32 ); // ignores colortable :-/, so make sure there is none
         stream << img.width() << img.height() << img.depth()
                << img.hasAlphaBuffer();
         memcpy(shmaddr, img.bits(), img.numBytes());
