@@ -13,12 +13,12 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef _THUMBNAIL_H_
-#define _THUMBNAIL_H_ "$Id: thumbnail.h,v 1.3 2001/07/27 22:45:50 malte Exp $"
+#define _THUMBNAIL_H_
 
 #include <qdict.h>
 
