@@ -72,7 +72,7 @@ public:
     bool del( int trashId, const QString& fileId );
 
     /// Empty trash, i.e. delete all trashed files
-    void emptyTrash();
+    bool emptyTrash();
 
     /// Return true if the trash is empty
     bool isEmpty() const;
@@ -123,7 +123,8 @@ private:
     void fileAdded();
     void fileRemoved();
 
-    bool testDir( const QString& name );
+    // Warning, returns error code, not a bool
+    int testDir( const QString& name ) const;
     void error( int e, const QString& s );
 
     bool readInfoFile( const QString& infoPath, TrashedFileInfo& info, int trashId );
@@ -137,12 +138,13 @@ private:
     QString trashDirectoryPath( int trashId ) const;
     QString topDirectoryPath( int trashId ) const;
 
-    bool synchronousDel( const QString& path, bool setLastErrorCode );
+    bool synchronousDel( const QString& path, bool setLastErrorCode, bool isDir );
 
     void scanTrashDirectories() const;
 
     int idForTrashDirectory( const QString& trashDir ) const;
     bool initTrashDirectory( const QCString& trashDir_c ) const;
+    bool checkTrashSubdirs( const QCString& trashDir_c ) const;
     QString trashForMountPoint( const QString& topdir, bool createIfNeeded ) const;
     static QString makeRelativePath( const QString& topdir, const QString& path );
 
