@@ -20,10 +20,11 @@
 #define __kebsearchline_h
 
 #include <klistviewsearchline.h>
-
+#include <qobject.h>
 
 class KEBSearchLine : public KListViewSearchLine
 {
+    Q_OBJECT
 public:
     KEBSearchLine(QWidget *parent = 0, KListView *listView = 0, const char *name = 0);
 
@@ -34,6 +35,10 @@ public:
     enum modes { EXACTLY, AND, OR } mmode;
     modes mode();
     void setMode(modes m);
+    virtual void updateSearch(const QString &s = QString::null);
+
+signals:
+    void searchUpdated();
 
 protected:
 
