@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef __listview_h
@@ -23,6 +23,8 @@
 #include <assert.h>
 
 #include <qlistview.h>
+#include <qmap.h>
+#include <qvaluevector.h>
 
 #include <klocale.h>
 #include <kbookmark.h>
@@ -32,6 +34,7 @@
 #include "toplevel.h"
 
 class QSplitter;
+class KListViewSearchLine;
 
 class KEBListViewItem : public QListViewItem
 {
@@ -54,14 +57,17 @@ public:
    void restoreStatus();
 
    void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int alignment);
+   void setSelected ( bool s );
 
    virtual void setOpen(bool);
 
    bool isEmptyFolderPadder() const { return m_emptyFolderPadder; }
-   KBookmark bookmark() const { return m_bookmark; }
+   const KBookmark bookmark() const { return m_bookmark; }
 
   typedef enum { GreyStyle, BoldStyle, GreyBoldStyle, DefaultStyle } PaintStyle;
 
+   static bool parentSelected(QListViewItem * item);
+
 private:
    const QString nsGet() const;
    void normalConstruct(const KBookmark &);
@@ -101,13 +107,10 @@ public:
    bool isFolderList() const { return m_folderList; }
 
    KEBListViewItem* rootItem() const;
-   QPtrList<KEBListViewItem>* itemList(); // TODO - make const!!!
 
 public slots:
    virtual void rename(QListViewItem *item, int c);
-   void slotSelectionChanged();
    void slotMoved();
-   void slotCurrentChanged(QListViewItem*);
    void slotContextMenu(KListView *, QListViewItem *, const QPoint &);
    void slotItemRenamed(QListViewItem *, const QString &, int);
    void slotDoubleClicked(QListViewItem *, const QPoint &, int);
@@ -130,23 +133,28 @@ class ListView : public QObject
 public:
    // init stuff
    void initListViews();
-   void setInitialAddress(QString address);
    void updateListViewSetup(bool readOnly);
    void connectSignals();
+   void setSearchLine(KListViewSearchLine * searchline) { m_searchline = searchline; };
 
    // selected item stuff
-   int numSelected() const;
-   KEBListViewItem* selectedItem() const;
-   QPtrList<KEBListViewItem>* selectedItems() const;
+   void selected(KEBListViewItem * item, bool s);
+   
+   void invalidate(const QString & address);
+   void invalidate(QListViewItem * item);
+   void fixUpCurrent(const QString & address);
+
+   KEBListViewItem * firstSelected() const;
+   QValueVector<KEBListViewItem *> selectedItemsMap() const;
+
+   QValueList<QString> selectedAddresses();
 
    // bookmark helpers
-   QValueList<KBookmark> itemsToBookmarks(QPtrList<KEBListViewItem>* items) const;
+   QValueList<KBookmark> itemsToBookmarks(const QValueVector<KEBListViewItem *> & items) const;
 
    // bookmark stuff
-   QValueList<KBookmark> getBookmarkSelection() const;
    QValueList<KBookmark> allBookmarks() const;
    QValueList<KBookmark> selectedBookmarksExpanded() const;
-   void selectedBookmarksExpandedHelper(KEBListViewItem * item, QValueList<KBookmark> & bookmarks) const;
 
    // address stuff
    KEBListViewItem* getItemAtAddress(const QString &address) const;
@@ -155,11 +163,9 @@ public:
    // gui stuff - DESIGN - all of it???
    SelcAbilities getSelectionAbilities() const;
 
-   void updateSelectedItems(); // DESIGN - rename?
    void updateListView();
-   void emitSlotSelectionChanged() { emit handleSelectionChanged(m_listView); }
    void setOpen(bool open); // DESIGN -rename to setAllOpenFlag
-   void setCurrent(KEBListViewItem *item);
+   void setCurrent(KEBListViewItem *item, bool select);
    void renameNextCell(bool dir);
 
    QWidget *widget() const { return m_listView; }
@@ -173,40 +179,39 @@ public:
 
    void handleMoved(KEBListView *);
    void handleDropped(KEBListView *, QDropEvent *, QListViewItem *, QListViewItem *);
-   void handleSelectionChanged(KEBListView *);
-   void handleCurrentChanged(KEBListView *, QListViewItem *);
    void handleContextMenu(KEBListView *, KListView *, QListViewItem *, const QPoint &);
    void handleDoubleClicked(KEBListView *, QListViewItem *, const QPoint &, int);
    void handleItemRenamed(KEBListView *, QListViewItem *, const QString &, int);
 
    static void startRename(int column, KEBListViewItem *item);
 
+   static void deselectAllChildren(KEBListViewItem *item);
+
    ~ListView();
 
 public slots:
    void slotBkInfoUpdateListViewItem();
 
 private:
-   void updateTree(bool updateSplitView = true);
+   void updateTree();
+   void selectedBookmarksExpandedHelper(KEBListViewItem * item, QValueList<KBookmark> & bookmarks) const;
    void fillWithGroup(KEBListView *, KBookmarkGroup, KEBListViewItem * = 0);
- 
+
    ListView();
-   static void deselectAllButParent(KEBListViewItem *item);
 
    KEBListView *m_listView;
-   KEBListView *m_folderListView;
+   KListViewSearchLine * m_searchline;
 
-   QString m_last_selection_address;
-   QString m_currentSelectedRootAddress;
-
-   bool m_splitView;
+//  Actually this is a std:set, the bool is ignored
+   QMap<KEBListViewItem *, bool> mSelectedItems;
+   bool m_needToFixUp;
 
    // statics
    static ListView *s_self;
-   static bool s_listview_is_dirty;
    static int s_myrenamecolumn;
    static KEBListViewItem *s_myrenameitem;
    static QStringList s_selected_addresses;
+   static QString s_current_address;
 };
 
 #endif
