@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include "konq_main.h"
@@ -22,6 +22,7 @@
 #include "konq_factory.h"
 #include "konq_mainwindow.h"
 #include "konq_view.h"
+#include "konq_settingsxt.h"
 #include "KonquerorIface.h"
 
 #include <ktempfile.h>
@@ -128,8 +129,7 @@ extern "C" KDE_EXPORT int kdemain( int argc, char **argv )
          {
              if (args->isSet("preload"))
              {
-                 KConfigGroupSaver group( app.config(), "Reusing" );
-                 if( app.config()->readNumEntry( "MaxPreloadCount", 1 ) > 0 )
+                 if( KonqSettings::maxPreloadCount() > 0 )
                  {
                      DCOPRef ref( "kded", "konqy_preloader" );
                      if( !ref.callExt( "registerPreloadedKonqy", DCOPRef::NoEventLoop, 5000,
