@@ -79,12 +79,11 @@ void KonqRun::foundMimeType( const QString & _type )
   m_req.args = m_args;
 
   bool tryEmbed = true;
+
   // One case where we shouldn't try to embed, is when the server asks us to save
-  // ####### only if content-disposition doesn't say inline
-#if 0
-  if ( !m_suggestedFilename.isEmpty() )
+  if ( serverSuggestsSave() )
      tryEmbed = false;
-#endif
+
   if ( KonqMainWindow::isMimeTypeAssociatedWithSelf( mimeType ) )
       m_req.forceAutoEmbed = true;
 
@@ -107,6 +106,8 @@ void KonqRun::foundMimeType( const QString & _type )
     if ( res == KParts::BrowserRun::Delayed )
       return;
     m_bFinished = ( res == KParts::BrowserRun::Handled );
+    if (!m_bFinished && !tryEmbed) // Open selected for a serverSuggestsSave() file
+        m_bFinished = m_pMainWindow->openView( mimeType, m_strURL, m_pView, m_req );
   }
 
   // make Konqueror think there was an error, in order to stop the spinning wheel
