@@ -1236,8 +1236,18 @@ void KonqView::disableScrolling()
 
 KonqViewIface * KonqView::dcopObject()
 {
-  if ( !m_dcopObject )
-      m_dcopObject = new KonqViewIface( this );
+  if ( !m_dcopObject ) {
+    QCString dcopName = name();
+    if ( dcopName.isEmpty() || dcopName == "unnamed" )
+      dcopName = viewName().utf8();
+    if ( dcopName.isEmpty() || dcopName == "unnamed" ) {
+      QVariant dcopProperty = part()->property( "dcopObjectId" );
+      if ( dcopProperty.type() == QVariant::CString )
+        dcopName = dcopProperty.toCString();
+    }
+    dcopName += "-view"; // to avoid having the same name as the part
+    m_dcopObject = new KonqViewIface( this, dcopName );
+  }
   return m_dcopObject;
 }
 
