@@ -1292,8 +1292,8 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
          QSize size = readConfigSize( cfg, m_pMainWindow );
          if ( size.isValid() )
              m_pMainWindow->resize( size );
-         else if( resetWindow )
-             m_pMainWindow->resize( 700, 480 ); // size from KonqMainWindow ctor
+         else  // no size in the profile; use last known size
+             m_pMainWindow->restoreWindowSize();
      }
   }
 
@@ -1395,6 +1395,8 @@ void KonqViewManager::slotActivePartChanged ( KParts::Part *newPart )
 
 void KonqViewManager::emitActivePartChanged()
 {
+    // prevent unnecessary multiple calls to slotPartActivated:
+    m_activePartChangedTimer->stop();
     m_pMainWindow->slotPartActivated( activePart() );
 }
 
