@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include "konq_listview.h"
@@ -124,7 +124,7 @@ void KonqListViewItem::updateContents()
                 setText(tmpColumn->displayInColumn,KIO::convertSize(m_fileitem->size())+" ");
             break;
          case KIO::UDS_ACCESS:
-            setText(tmpColumn->displayInColumn,makeAccessString(m_fileitem->permissions()));
+            setText(tmpColumn->displayInColumn,m_fileitem->permissionsString());	    
             break;
          case KIO::UDS_MODIFICATION_TIME:
          case KIO::UDS_ACCESS_TIME:
@@ -390,7 +390,6 @@ const char* KonqBaseListViewItem::makeAccessString( const mode_t mode)
    return buffer;
 }
 
-
 KonqBaseListViewItem::KonqBaseListViewItem(KonqBaseListViewWidget *_listViewWidget, KFileItem* _fileitem)
 :KListViewItem(_listViewWidget)
 ,sortChar(0)
