@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef __konq_treeviewitem_h__
@@ -37,7 +37,7 @@ public:
    * @param _parent the parent widget, the tree view
    * @param _fileitem the file item created by KDirLister
    */
-  KonqListViewDir( KonqTreeViewWidget *_parent, KFileItem* _fileitem );
+  KonqListViewDir( KonqTreeViewWidget *_parent, KFileItem *_fileitem );
 
   /**
    * Create an item representing a directory, inside a directory
@@ -45,9 +45,7 @@ public:
    * @param _parent the parent widget, a directory item in the tree view
    * @param _fileitem the file item created by KDirLister
    */
-  KonqListViewDir( KonqTreeViewWidget *_treeview, KonqListViewDir * _parent, KFileItem* _fileitem );
-
-  virtual ~KonqListViewDir();
+  KonqListViewDir( KonqTreeViewWidget *_treeview, KonqListViewDir *_parent, KFileItem *_fileitem );
 
   /**
    * Called when user opens the directory (inherited from QListViewItem).
@@ -68,11 +66,6 @@ public:
    */
   virtual void setComplete( bool _b ) { m_bComplete = _b; }
 
-  /**
-   * (inherited from QListViewItem)
-   *
-  virtual void setup();*/
-
   /**
    * URL of this directory
    * @param _trailing set to true for a trailing slash (see KURL)
