@@ -15,26 +15,29 @@
  *                                                                         *
  ***************************************************************************/
 #include "konqsidebar.h"
+#include "konqsidebariface_p.h"
 
 #include <konq_events.h>
 #include <kdebug.h>
 #include <qapplication.h>
+#include <kaccelmanager.h>
 
 KonqSidebar::KonqSidebar( QWidget *parentWidget, const char *widgetName,
                           QObject *parent, const char *name, bool universalMode )
-: KParts::ReadOnlyPart(parent, name)
+: KParts::ReadOnlyPart(parent, name),KonqSidebarIface()
 {
 	// we need an instance
 	setInstance( KonqSidebarFactory::instance() );
 	m_extension = 0;
 	// this should be your custom internal widget
-	m_widget = new Sidebar_Widget( parentWidget,this, widgetName ,universalMode);
+	m_widget = new Sidebar_Widget( parentWidget, this, widgetName ,universalMode, parentWidget->topLevelWidget()->property("currentProfile").toString() );
 	m_extension = new KonqSidebarBrowserExtension( this, m_widget,"KonqSidebar::BrowserExtension" );
 	connect(m_widget,SIGNAL(started(KIO::Job *)),
 		this, SIGNAL(started(KIO::Job*)));
 	connect(m_widget,SIGNAL(completed()),this,SIGNAL(completed()));
 	connect(m_extension, SIGNAL(addWebSideBar(const KURL&, const QString&)),
 		m_widget, SLOT(addWebSideBar(const KURL&, const QString&)));
+        KAcceleratorManager::setNoAccel(m_widget);
 	setWidget(m_widget);
 }
 
@@ -119,12 +122,6 @@ KInstance* KonqSidebarFactory::instance()
 	return s_instance;
 }
 
-extern "C"
-{
-	void* init_konq_sidebar()
-	{
-		return new KonqSidebarFactory;
-	}
-}
+K_EXPORT_COMPONENT_FACTORY( konq_sidebar, KonqSidebarFactory )
 
 #include "konqsidebar.moc"
