@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include <qclipboard.h>
@@ -34,6 +34,7 @@
 #include "bookmark_module.h"
 #include "bookmark_item.h"
 #include <konqbookmarkmanager.h>
+#include <kdebug.h>
 
 KonqSidebarBookmarkModule::KonqSidebarBookmarkModule( KonqSidebarTree * parentTree )
     : QObject( 0L ), KonqSidebarTreeModule( parentTree ),
@@ -72,6 +73,9 @@ KonqSidebarBookmarkModule::KonqSidebarBookmarkModule( KonqSidebarTree * parentTr
     (void) new KAction( i18n("Copy Link Address"), "editcopy", 0, this,
                         SLOT( slotCopyLocation() ), m_collection, "copy_location");
 
+    KStdAction::editBookmarks( KonqBookmarkManager::self(), SLOT( slotEditBookmarks() ),
+			       m_collection, "edit_bookmarks" );
+
     connect( KonqBookmarkManager::self(), SIGNAL(changed(const QString &, const QString &) ),
              SLOT( slotBookmarksChanged(const QString &) ) );
 }
@@ -90,40 +94,45 @@ void KonqSidebarBookmarkModule::addTopLevelItem( KonqSidebarTreeTopLevelItem * i
     m_ignoreOpenChange = false;
 }
 
+bool KonqSidebarBookmarkModule::handleTopLevelContextMenu( KonqSidebarTreeTopLevelItem *, const QPoint& ) 
+{
+    QPopupMenu *menu = new QPopupMenu;
+
+    if (tree()->tabSupport()) {
+	m_collection->action("folder_open_tabs")->plug(menu);
+	menu->insertSeparator();
+    }
+    m_collection->action("create_folder")->plug(menu);
+ 
+    menu->insertSeparator();
+    m_collection->action("edit_bookmarks")->plug(menu);
+
+    menu->exec( QCursor::pos() );
+    delete menu;
+
+    return true;
+}
+
 void KonqSidebarBookmarkModule::showPopupMenu()
 {
     KonqSidebarBookmarkItem *bi = dynamic_cast<KonqSidebarBookmarkItem*>( tree()->selectedItem() );
     if (!bi)
         return;
 
-    // see if the newTab() dcop function is available (i.e. the sidebar is embedded into konqueror)
-    bool tabSupport = false;
-    DCOPRef ref(kapp->dcopClient()->appId(), tree()->topLevelWidget()->name());
-    DCOPReply reply = ref.call("functions()");
-    if (reply.isValid()) {
-        QCStringList funcs;
-        reply.get(funcs, "QCStringList");
-        for (QCStringList::ConstIterator it = funcs.begin(); it != funcs.end(); ++it) {
-            if ((*it) == "void newTab(QString url)") {
-                tabSupport = true;
-                break;
-            }
-        }
-    }
-
+    bool tabSupported = tree()->tabSupport();
     QPopupMenu *menu = new QPopupMenu;
 
     if (bi->bookmark().isGroup()) {
-        if (tabSupport) {
+        if (tabSupported) {
             m_collection->action("folder_open_tabs")->plug(menu);
             menu->insertSeparator();
         }
         m_collection->action("create_folder")->plug(menu);
         m_collection->action("delete_folder")->plug(menu);
     } else {
-        if (tabSupport)
-            m_collection->action("open_tab")->plug(menu);
         m_collection->action("open_window")->plug(menu);
+        if (tabSupported)
+            m_collection->action("open_tab")->plug(menu);
         m_collection->action("copy_location")->plug(menu);
         menu->insertSeparator();
         m_collection->action("create_folder")->plug(menu);
@@ -168,7 +177,9 @@ void KonqSidebarBookmarkModule::slotMoved(QListViewItem *i, QListViewItem*, QLis
         if (error)
             parentGroup = KonqBookmarkManager::self()->root();
     } else {
-        // most probably the root...
+        // No parent! This means the user dropped it before the top level item
+        // And KListView has moved the item there, we need to correct it
+        tree()->moveItem(item, m_topLevelItem, 0L);
         parentGroup = KonqBookmarkManager::self()->root();
     }
 
@@ -227,14 +238,20 @@ void KonqSidebarBookmarkModule::slotDropped(KListView *, QDropEvent *e, QListVie
     if (after) {
         parentGroup = afterBookmark.parentGroup();
     } else if (parent) {
-        KonqSidebarBookmarkItem *p = dynamic_cast<KonqSidebarBookmarkItem*>(parent);
-        if (!p)
-            return;
-        KBookmark bm = p->bookmark();
-        if (bm.isGroup())
-            parentGroup = bm.toGroup();
-        else
-            return;
+        if(KonqSidebarBookmarkItem *p = dynamic_cast<KonqSidebarBookmarkItem*>(parent))
+        {
+            if (!p)
+                return;
+            KBookmark bm = p->bookmark();
+            if (bm.isGroup())
+                parentGroup = bm.toGroup();
+            else
+                return;
+        }
+        else if(parent == m_topLevelItem)
+        {
+            parentGroup = KonqBookmarkManager::self()->root();
+        }
     } else {
         // it's most probably the root...
         parentGroup = KonqBookmarkManager::self()->root();
@@ -255,17 +272,24 @@ void KonqSidebarBookmarkModule::slotDropped(KListView *, QDropEvent *e, QListVie
 void KonqSidebarBookmarkModule::slotCreateFolder()
 {
     KonqSidebarBookmarkItem *bi = dynamic_cast<KonqSidebarBookmarkItem*>( tree()->selectedItem() );
-    if (!bi)
-        return;
-
-    KBookmarkGroup parentGroup;
-    if (bi->bookmark().isGroup())
-        parentGroup = bi->bookmark().toGroup();
+    KBookmarkGroup parentGroup;    
+    if (bi)
+    {
+	if (bi->bookmark().isGroup())
+	    parentGroup = bi->bookmark().toGroup();
+	else
+	    parentGroup = bi->bookmark().parentGroup();
+    }
+    else if(tree()->selectedItem() == m_topLevelItem)
+    {
+	parentGroup = KonqBookmarkManager::self()->root();
+    }
     else
-        parentGroup = bi->bookmark().parentGroup();
+	return;
 
     KBookmark bookmark = parentGroup.createNewFolder(KonqBookmarkManager::self());
-    parentGroup.moveItem(bookmark, bi->bookmark());
+    if(bi && !(bi->bookmark().isGroup()))
+	parentGroup.moveItem(bookmark, bi->bookmark());
 
     KonqBookmarkManager::self()->emitChanged( parentGroup );
 }
@@ -281,8 +305,8 @@ void KonqSidebarBookmarkModule::slotDelete()
 
     if (KMessageBox::warningYesNo(
             tree(),
-            folder ? i18n("Are you sure you wish to remove this bookmark folder?")
-                    : i18n("Are you sure you wish to remove this bookmark?"),
+            folder ? i18n("Are you sure you wish to remove the bookmark folder\n\"%1\"?").arg(bookmark.text())
+                    : i18n("Are you sure you wish to remove the bookmark\n\"%1\"?").arg(bookmark.text()),
             folder ? i18n("Bookmark Folder Deletion")
                     : i18n("Bookmark Deletion"),
             KGuiItem( i18n("&Delete"), "editdelete"), KStdGuiItem::cancel())
@@ -324,7 +348,7 @@ void KonqSidebarBookmarkModule::slotProperties(KonqSidebarBookmarkItem *bi)
 
     KBookmark bookmark = bi->bookmark();
 
-    QString folder = bookmark.isGroup() ? QString::null : bookmark.url().url();
+    QString folder = bookmark.isGroup() ? QString::null : bookmark.url().pathOrURL();
     BookmarkEditDialog dlg( bookmark.fullText(), folder, 0, 0,
                             i18n("Bookmark Properties") );
     if ( dlg.exec() != KDialogBase::Accepted )
@@ -332,7 +356,10 @@ void KonqSidebarBookmarkModule::slotProperties(KonqSidebarBookmarkItem *bi)
 
     makeTextNodeMod(bookmark, "title", dlg.finalTitle());
     if ( !dlg.finalUrl().isNull() )
-        bookmark.internalElement().setAttribute("href", dlg.finalUrl());
+    {
+        KURL u = KURL::fromPathOrURL(dlg.finalUrl());
+        bookmark.internalElement().setAttribute("href", u.url(0, 106));
+    }
 
     KBookmarkGroup parentBookmark = bookmark.parentGroup();
     KonqBookmarkManager::self()->emitChanged( parentBookmark );
@@ -350,10 +377,15 @@ void KonqSidebarBookmarkModule::slotOpenNewWindow()
 void KonqSidebarBookmarkModule::slotOpenTab()
 {
     KonqSidebarBookmarkItem *bi = dynamic_cast<KonqSidebarBookmarkItem*>( tree()->selectedItem() );
-    if (!bi)
-        return;
-
-    KBookmark bookmark = bi->bookmark();
+    KBookmark bookmark;
+    if (bi)
+    {
+	bookmark = bi->bookmark();
+    }
+    else if(tree()->selectedItem() == m_topLevelItem)
+	bookmark = KonqBookmarkManager::self()->root();	
+    else
+	return;
 
     DCOPRef ref(kapp->dcopClient()->appId(), tree()->topLevelWidget()->name());
 
@@ -511,6 +543,7 @@ BookmarkEditDialog::BookmarkEditDialog(const QString& title, const QString& url,
         locationLabel->setBuddy(m_location);
         grid->addWidget(m_location, 1, 1);
     }
+    main->setMinimumSize( 300, 0 );
 }
 
 void BookmarkEditDialog::slotOk()
