@@ -1,16 +1,21 @@
-/* -------------------------------------------------------------------------- */
-/*                                                                            */
-/* [TEPty.h]                 Pseudo Terminal Device                           */
-/*                                                                            */
-/* -------------------------------------------------------------------------- */
-/*                                                                            */
-/* Copyright (c) 1997,1998 by Lars Doelle <lars.doelle@on-line.de>            */
-/*                                                                            */
-/* This file is part of Konsole - an X terminal for KDE                       */
-/*                                                                            */
-/* -------------------------------------------------------------------------- */
+/*
+    This file is part of Konsole, an X terminal.
+    Copyright (C) 1997,1998 by Lars Doelle <lars.doelle@on-line.de>
 
-/*! \file
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301  USA.
 */
 
 #ifndef TE_PTY_H
@@ -46,6 +51,7 @@ Q_OBJECT
     QString error() { return m_strError; }
     void setXonXoff(bool on);
     void setSize(int lines, int cols);
+    void setErase(char erase);
 
   public slots:
     void useUtf8(bool on);
@@ -71,12 +77,20 @@ Q_OBJECT
     */
     void buffer_empty();
 
+    // this will be emitted in the child process
+    // after forking (and, obviously, before exec())
+    void forkedChild();
+
   public:
 
     void send_byte(char s);
     void send_string(const char* s);
     bool buffer_full() { return m_bufferFull; }
 
+    // override from KProcess to allow the client of konsolePart
+    // to set up things after fork() but before exec()
+    virtual int commSetupDoneC();
+
   protected slots:
       void dataReceived(KProcess *, char *buf, int len);
   public slots:
