@@ -282,9 +282,12 @@ void TESession::notifySessionState(int state)
 
 void TESession::onContentSizeChange(int height, int width)
 {
-  //kdDebug(1211)<<"TESession::onContentSizeChange " << height << " " << width << endl;
-  em->onImageSizeChange( height/font_h, width/font_w );
-  sh->setSize( height/font_h, width/font_w );
+  // ensure that image is at least one line high by one column wide
+  const int columns = QMAX( width/font_w , 1 );
+  const int lines = QMAX( height/font_h , 1 );
+
+  em->onImageSizeChange( lines , columns );
+  sh->setSize( lines , columns );
 }
 
 void TESession::onFontMetricChange(int height, int width)
