@@ -52,16 +52,16 @@ KStylePage::KStylePage(QWidget *parent, const char *name ) : KStylePageDlg(paren
 	klv_styles->setAllColumnsShowFocus(true);
 
 	kde = new QListViewItem( klv_styles);
-	kde->setText( 0, QPixmap::defaultDepth() > 8 ? i18n( "Keramik" ) : i18n( "Light" ) );
+	kde->setText( 0, QPixmap::defaultDepth() > 8 ? i18n( "Plastik" ) : i18n( "Light" ) );
 	kde->setText( 1, i18n( "KDE default style" ) );
 
 	classic = new QListViewItem( klv_styles);
 	classic->setText( 0, i18n( "KDE Classic" ) );
 	classic->setText( 1, i18n( "Classic KDE style" ) );
 
-	plastik = new QListViewItem( klv_styles );
-	plastik->setText( 0, i18n( "Plastik" ) );
-	plastik->setText( 1, i18n( "A modern, yet simple style" ) );
+	keramik = new QListViewItem( klv_styles );
+	keramik->setText( 0, i18n( "Keramik" ) );
+	keramik->setText( 1, i18n( "The previous default style" ) );
 
 	cde = new QListViewItem( klv_styles);
 	cde->setText( 0, i18n( "Sunshine" ) );
@@ -80,7 +80,7 @@ KStylePage::KStylePage(QWidget *parent, const char *name ) : KStylePageDlg(paren
 
 	// Note: if the default is changed here it needs to be changed in kdebase/kwin/plugins.cpp
 	//       and kdebase/kwin/kcmkwin/kwindecoration/kwindecoration.cpp as well.
-	defaultKWinStyle = QPixmap::defaultDepth() > 8 ? "kwin_keramik" : "kwin_quartz";
+	defaultKWinStyle = QPixmap::defaultDepth() > 8 ? "kwin_plastik" : "kwin_quartz";
 	appliedStyle = NULL;
 
 	getAvailability();
@@ -125,11 +125,11 @@ void KStylePage::saveKWin(bool curSettings){
 			kdf = new KDesktopFile(kstd->findResource("data", "kwin/redmond.desktop"));
 		else if (platinum->isSelected() && kwin_system_exist)
 			kdf = new KDesktopFile(kstd->findResource("data", "kwin/system.desktop"));
-		else if (plastik->isSelected() && kwin_plastik_exist)
-			kdf = new KDesktopFile(kstd->findResource("data", "kwin/plastik.desktop"));
+		else if (keramik->isSelected() && kwin_keramik_exist)
+			kdf = new KDesktopFile(kstd->findResource("data", "kwin/keramik.desktop"));
 		else if (kde->isSelected()) {
-			if (kwin_keramik_exist && (QColor::numBitPlanes() > 8))
-				kdf = new KDesktopFile(kstd->findResource("data", "kwin/keramik.desktop"));
+			if (kwin_plastik_exist && (QColor::numBitPlanes() > 8))
+				kdf = new KDesktopFile(kstd->findResource("data", "kwin/plastik.desktop"));
 			else if (kwin_quartz_exist)
 				kdf = new KDesktopFile(kstd->findResource("data", "kwin/quartz.desktop"));
 		}
@@ -183,6 +183,7 @@ void KStylePage::saveColors(bool curSettings){
 	config->writeEntry("inactiveBlend", toSave->inactiveBlend, true, true);
 	config->writeEntry("activeTitleBtnBg", toSave->activeTitleBtnBg, true, true);
 	config->writeEntry("inactiveTitleBtnBg", toSave->inactiveTitleBtnBg, true, true);
+        config->writeEntry("alternateBackground", toSave->alternateBackground, true, true);
 
 	////////////////////////////////////////////////////
 	// KDE-1.x support
@@ -219,7 +220,7 @@ void KStylePage::saveColors(bool curSettings){
 void KStylePage::saveIcons(bool curSettings) {
 	QString theme = origIcons;
 	if (curSettings) {
-		if ( (kde->isSelected() || platinum->isSelected() || plastik->isSelected())
+		if ( (kde->isSelected() || platinum->isSelected() || keramik->isSelected())
 			&& icon_crystalsvg_exist)
 				theme = "crystalsvg";
 		else if ( (classic->isSelected() || cde->isSelected() || win->isSelected())
@@ -264,8 +265,8 @@ void KStylePage::changeCurrentStyle() {
 	else if (platinum->isSelected() && platinum_exist) {
 		currentStyle="Platinum";
 	}
-	else if (plastik->isSelected() && kde_plastik_exist) {
-		currentStyle="Plastik";
+	else if (keramik->isSelected() && kde_plastik_exist) {
+		currentStyle="Keramik";
 	}
 	else if (classic->isSelected()) {
 		// Use the highcolor style if the display supports it
@@ -277,9 +278,9 @@ void KStylePage::changeCurrentStyle() {
 		}
 	}
 	else if (kde->isSelected()) {
-		// Use the keramik style if the display supports it
-		if ( (QColor::numBitPlanes() > 8) && kde_keramik_exist ) {
-			currentStyle="Keramik";
+		// Use the plastik style if the display supports it
+		if ( (QColor::numBitPlanes() > 8) && kde_plastik_exist ) {
+			currentStyle="Plastik";
 		}
 		else if (kde_light_exist) {
 			currentStyle="Light, 3rd revision";
@@ -299,7 +300,7 @@ void KStylePage::changeCurrentStyle() {
 void KStylePage::presetStyle(const QString& style){
 	kdDebug() << "KStylePage::presetStyle(): "<< style << endl;
 	if(style=="KDE") {
-		if (kde_keramik_exist)
+		if (kde_plastik_exist)
 			klv_styles->setSelected(kde,true);
 		else if (kde_hc_exist || kde_def_exist)
 			klv_styles->setSelected(classic,true);
@@ -326,9 +327,9 @@ void KStylePage::getColors(colorSet *set, bool colorfile ){
 		KGlobal::dirs()->addResourceType("colors", KStandardDirs::kde_default("data")+"kdisplay/color-schemes");
 		// set the style
 		if (kde->isSelected()) {
-			set->bgMode="VerticalGradient";
-			set->usrCol1.setNamedColor ("#1E72A0");
-			set->usrCol2.setNamedColor ("#C0C0C0");
+			set->bgMode="Flat";
+                        set->usrCol1.setNamedColor("#003082");
+			set->usrCol2.setNamedColor("#6C8BB9");
 			set->colorFile="<default>";
 		}
 		else if(classic->isSelected()){
@@ -337,11 +338,11 @@ void KStylePage::getColors(colorSet *set, bool colorfile ){
 			set->usrCol2.setNamedColor ("#C0C0C0");
 			set->colorFile=locate("colors", "KDETwo.kcsrc");
 		}
-		else if(plastik->isSelected()){
+		else if(keramik->isSelected()){
 			set->bgMode="VerticalGradient";
-			set->usrCol1.setNamedColor("#2A569D");
-			set->usrCol2.setNamedColor("#6C8BB9");
-			set->colorFile=locate("colors","Plastik.kcsrc");
+			set->usrCol1.setNamedColor ("#1E72A0");
+			set->usrCol2.setNamedColor ("#C0C0C0");
+			set->colorFile=locate("colors","Keramik.kcsrc");
 		}
 		else if(cde->isSelected()){
 			set->bgMode="Flat";
@@ -371,8 +372,8 @@ void KStylePage::getColors(colorSet *set, bool colorfile ){
 		KConfig kdesktop("kdesktoprc");
 		kdesktop.setGroup("Desktop0");
 		// set Background (userSettings if available, else default)
-		set->bgMode=kdesktop.readEntry("BackgroundMode", "VerticalGradient");
-		QColor tmp1("#1E72A0");
+		set->bgMode=kdesktop.readEntry("BackgroundMode", "Flat");
+                QColor tmp1("#003082");
 		QColor tmp2("#C0C0C0");
 		set->usrCol1=kdesktop.readColorEntry("Color1", &tmp1);
 		set->usrCol2=kdesktop.readColorEntry("Color2", &tmp2);
@@ -388,8 +389,8 @@ void KStylePage::getColors(colorSet *set, bool colorfile ){
 	set->background=config->readColorEntry( "background", &widget );
 	set->windowForeground=config->readColorEntry( "windowForeground", &black );
 	set->windowBackground=config->readColorEntry( "windowBackground", &white );
-	set->selectForeground=config->readColorEntry( "selectForeground", &black );
-	set->selectBackground=config->readColorEntry( "selectBackground", &kde31Beige );
+	set->selectForeground=config->readColorEntry( "selectForeground", &white );
+	set->selectBackground=config->readColorEntry( "selectBackground", &kde34Blue );
 	set->buttonForeground=config->readColorEntry( "buttonForeground", &black );
 	set->buttonBackground=config->readColorEntry( "buttonBackground", &button );
 	set->linkColor=config->readColorEntry( "linkColor", &link );
@@ -398,13 +399,14 @@ void KStylePage::getColors(colorSet *set, bool colorfile ){
 	if(!colorfile)
 		config->setGroup( "WM" );
 	set->activeForeground=config->readColorEntry("activeForeground", &white);
-	set->inactiveForeground=config->readColorEntry("inactiveForeground", &white);
-	set->activeBackground=config->readColorEntry("activeBackground", &emerald2);
-	set->inactiveBackground=config->readColorEntry("inactiveBackground", &emerald1);
-	set->activeBlend=config->readColorEntry("activeBlend", &emerald2);
-	set->inactiveBlend=config->readColorEntry("inactiveBlend", &emerald1);
-	set->activeTitleBtnBg=config->readColorEntry("activeTitleBtnBg", &widget);
-	set->inactiveTitleBtnBg=config->readColorEntry("inactiveTitleBtnBg", &widget);
+        set->inactiveForeground=config->readColorEntry("inactiveForeground", &inactiveForeground);
+        set->activeBackground=config->readColorEntry("activeBackground", &activeBackground);
+        set->inactiveBackground=config->readColorEntry("inactiveBackground", &inactiveBackground);
+        set->activeBlend=config->readColorEntry("activeBlend", &activeBlend);
+        set->inactiveBlend=config->readColorEntry("inactiveBlend", &inactiveBackground);
+        set->activeTitleBtnBg=config->readColorEntry("activeTitleBtnBg", &activeTitleBtnBg);
+        set->inactiveTitleBtnBg=config->readColorEntry("inactiveTitleBtnBg", &inactiveTitleBtnBg);
+        set->alternateBackground=config->readColorEntry("alternateBackground", &alternateBackground);
         if ( deleteConfig)
             delete config;
 }
@@ -426,9 +428,9 @@ void KStylePage::getAvailability() {
 		else if (*it == "Light, 3rd revision") kde_light_exist = true;
 	}
 	// and disable the ListItems, if they are not.
-	if ( !(kde_keramik_exist || kde_light_exist) ) kde->setVisible(false);
+	if ( !(kde_plastik_exist || kde_light_exist) ) kde->setVisible(false);
 	if ( !(kde_hc_exist || kde_def_exist) ) classic->setVisible(false);
-	if (!kde_plastik_exist || QPixmap::defaultDepth() <= 8) plastik->setVisible(false);
+	if (!kde_keramik_exist || QPixmap::defaultDepth() <= 8) keramik->setVisible(false);
 	if (!cde_exist) cde->setVisible(false);
 	if (!win_exist) win->setVisible(false);
 	if (!platinum_exist) platinum->setVisible(false);
@@ -490,18 +492,23 @@ void KStylePage::getUserDefaults() {
 
 /** initialize KDE default color values */
 void KStylePage::initColors() {
-	widget.setRgb(238, 238, 230);
-	kde31Beige.setRgb(255,221,118);
-	emerald1.setRgb(143,159,180);
-	emerald2.setRgb(62,145,235);
-
+	widget.setRgb(239, 239, 239);
+	kde34Blue.setRgb(103,141,178);
+        inactiveBackground.setRgb(157,170,186);
+        activeBackground.setRgb(65,142,220);
+        inactiveForeground.setRgb(221,221,221);
+        activeBlend.setRgb(107,145,184);
+        activeTitleBtnBg.setRgb(127,158,200);
+        inactiveTitleBtnBg.setRgb(167,181,199);
+        alternateBackground.setRgb(237,244,249);
+        
 	if (QPixmap::defaultDepth() > 8)
-		button.setRgb(238, 234, 222);
+		button.setRgb(221, 223, 228);
 	else
 		button.setRgb(220, 220, 220);
 
-	link.setRgb(0, 0, 192);
-	visitedLink.setRgb(128, 0,128);
+	link.setRgb(0, 0, 238);
+	visitedLink.setRgb(82, 24, 139);
 }
 
 /** live-update the system */
