@@ -23,16 +23,16 @@
 // libkscreensaver interface
 extern "C"
 {
-    const char *kss_applicationName = "kblankscrn.kss";
-    const char *kss_description = I18N_NOOP( "KBlankScreen" );
-    const char *kss_version = "2.2.0";
+    KDE_EXPORT const char *kss_applicationName = "kblankscrn.kss";
+    KDE_EXPORT const char *kss_description = I18N_NOOP( "KBlankScreen" );
+    KDE_EXPORT const char *kss_version = "2.2.0";
 
-    KScreenSaver *kss_create( WId id )
+    KDE_EXPORT KScreenSaver* kss_create( WId id )
     {
         return new KBlankSaver( id );
     }
 
-    QDialog *kss_setup()
+    KDE_EXPORT QDialog* kss_setup()
     {
         return new KBlankSetup();
     }
@@ -42,51 +42,34 @@ extern "C"
 // dialog to setup screen saver parameters
 //
 KBlankSetup::KBlankSetup( QWidget *parent, const char *name )
-	: QDialog( parent, name, TRUE )
+	: KDialogBase( parent, name, true, i18n( "Setup Blank Screen Saver" ),
+		Ok|Cancel, Ok, true )
 {
 	readSettings();
 
-	QLabel *label;
-	QPushButton *button;
+	QFrame *main = makeMainWidget();
+	QGridLayout *grid = new QGridLayout(main, 4, 2, 0, spacingHint() );
 
-	setCaption( i18n("Setup Blank Screen Saver") );
+	QLabel *label = new QLabel( i18n("Color:"), main );
+	grid->addWidget(label, 0, 0);
 
-	QVBoxLayout *tl = new QVBoxLayout(this, 10);
-	QHBoxLayout *tl1 = new QHBoxLayout;
-	tl->addLayout(tl1);
-
-	QVBoxLayout *tl11 = new QVBoxLayout(5);
-	tl1->addLayout(tl11);
-
-	label = new QLabel( i18n("Color:"), this );
-	tl11->addWidget(label);
-
-	colorPush = new KColorButton( color, this );
+	KColorButton *colorPush = new KColorButton( color, main );
 	colorPush->setMinimumWidth(80);
 	connect( colorPush, SIGNAL( changed(const QColor &) ),
 		SLOT( slotColor(const QColor &) ) );
-	tl11->addWidget(colorPush);
-	tl11->addStretch(1);
+	grid->addWidget(colorPush, 1, 0);
 
-	preview = new QWidget( this );
-	preview->setFixedSize( 220, 170 );
+	preview = new QWidget( main );
+	preview->setFixedSize( 220, 165 );
 	preview->setBackgroundColor( black );
 	preview->show();    // otherwise saver does not get correct size
 	saver = new KBlankSaver( preview->winId() );
-	tl1->addWidget(preview);
+	grid->addMultiCellWidget(preview, 0, 2, 1, 1);
 
-	KButtonBox *bbox = new KButtonBox(this);	
-	bbox->addStretch(1);
+	grid->setRowStretch( 2, 10 );
+	grid->setRowStretch( 3, 20 );
 
-	button = bbox->addButton( i18n("&OK"));
-	connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
-
-	button = bbox->addButton(i18n("&Cancel"));
-	connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
-	bbox->layout();
-	tl->addWidget(bbox);
-
-	tl->freeze();
+	setMinimumSize( sizeHint() );
 }
 
 // read settings from config file
@@ -105,13 +88,11 @@ void KBlankSetup::slotColor( const QColor &col )
 }
 
 // Ok pressed - save settings and exit
-void KBlankSetup::slotOkPressed()
+void KBlankSetup::slotOk()
 {
 	KConfig *config = KGlobal::config();
 	config->setGroup( "Settings" );
-
 	config->writeEntry( "Color", color );
-
 	config->sync();
 
 	accept();
@@ -123,7 +104,6 @@ void KBlankSetup::slotOkPressed()
 KBlankSaver::KBlankSaver( WId id ) : KScreenSaver( id )
 {
 	readSettings();
-
 	blank();
 }
 
