@@ -248,17 +248,22 @@ void SplashInstaller::readThemesList()
 //-----------------------------------------------------------------------------
 void SplashInstaller::defaults()
 {
-  mThemesList->setCurrentItem(findTheme("Default"));
-  emit changed( true );
+   load( true );
 }
 
 void SplashInstaller::load()
+{
+   load( false );
+}
+
+void SplashInstaller::load( bool useDefaults )
 {
   KConfig cnf("ksplashrc");
+  cnf.setReadDefaults( useDefaults );
   cnf.setGroup("KSplash");
   QString curTheme = cnf.readEntry("Theme","Default");
   mThemesList->setCurrentItem(findTheme(curTheme));
-  emit changed( false );
+  emit changed( useDefaults );
 }
 
 //-----------------------------------------------------------------------------
@@ -330,10 +335,10 @@ void SplashInstaller::slotSetTheme(int id)
         path = mThemesList->text2path[path];
     enabled = false;
     KURL url;
+    QString themeName;
     if (!path.isEmpty())
     {
       // Make sure the correct plugin is installed.
-      QString themeName;
       int i = path.findRev('/');
       if (i >= 0)
         themeName = path.mid(i+1);
@@ -356,22 +361,22 @@ void SplashInstaller::slotSetTheme(int id)
         // Get theme information.
         infoTxt = "<qt>";
         if ( cnf.hasKey( "Name" ) )
-          infoTxt += QString( i18n( "<b>Name:</b> %1<br>" ) ).arg( cnf.readEntry( "Name", i18n( "Unknown" ) ) );
+          infoTxt += i18n( "<b>Name:</b> %1<br>" ).arg( cnf.readEntry( "Name", i18n( "Unknown" ) ) );
         if ( cnf.hasKey( "Description" ) )
-          infoTxt += QString( i18n( "<b>Description:</b> %1<br>" ) ).arg( cnf.readEntry( "Description", i18n( "Unknown" ) ) );
+          infoTxt += i18n( "<b>Description:</b> %1<br>" ).arg( cnf.readEntry( "Description", i18n( "Unknown" ) ) );
         if ( cnf.hasKey( "Version" ) )
-          infoTxt += QString( i18n( "<b>Version:</b> %1<br>" ) ).arg( cnf.readEntry( "Version", i18n( "Unknown" ) ) );
+          infoTxt += i18n( "<b>Version:</b> %1<br>" ).arg( cnf.readEntry( "Version", i18n( "Unknown" ) ) );
         if ( cnf.hasKey( "Author" ) )
-          infoTxt += QString( i18n( "<b>Author:</b> %1<br>" ) ).arg( cnf.readEntry( "Author", i18n( "Unknown" ) ) );
+          infoTxt += i18n( "<b>Author:</b> %1<br>" ).arg( cnf.readEntry( "Author", i18n( "Unknown" ) ) );
         if ( cnf.hasKey( "Homepage" ) )
-          infoTxt += QString( i18n( "<b>Homepage:</b> %1<br>" ) ).arg( cnf.readEntry( "Homepage", i18n( "Unknown" ) ) );
+          infoTxt += i18n( "<b>Homepage:</b> %1<br>" ).arg( cnf.readEntry( "Homepage", i18n( "Unknown" ) ) );
         infoTxt += "</qt>";
 
         QString pluginName( cnf.readEntry( "Engine", "Default" ) ); // Perhaps no default is better?
         if ((KTrader::self()->query("KSplash/Plugin", QString("[X-KSplash-PluginName] == '%1'").arg(pluginName))).isEmpty())
         {
           enabled = false;
-          error = QString(i18n("This theme requires the plugin %1 which is not installed.")).arg(pluginName);
+          error = i18n("This theme requires the plugin %1 which is not installed.").arg(pluginName);
         }
         else
           enabled = true; // Hooray, there is at least one plugin which can handle this theme.
@@ -381,7 +386,7 @@ void SplashInstaller::slotSetTheme(int id)
         error = i18n("Could not load theme configuration file.");
       }
     }
-    mBtnTest->setEnabled(enabled);
+    mBtnTest->setEnabled(enabled && themeName != "None" );
     mText->setText(infoTxt);
     if (!enabled)
     {
@@ -458,6 +463,17 @@ void SplashInstaller::slotTest()
   if (r >= 0)
     themeName = themeName.mid(r+1);
 
+  // special handling for none and simple splashscreens
+  if( themeName == "None" )
+    return;
+  if( themeName == "Simple" )
+  {
+    KProcess proc;
+    proc << "ksplashsimple" << "--test";
+    if (!proc.start(KProcess::Block))
+      KMessageBox::error(this,i18n("Unable to start ksplashsimple."));
+    return;
+  }
   KProcess proc;
   proc << "ksplash" << "--test" << "--theme" << themeName;
   if (!proc.start(KProcess::Block))
