@@ -71,7 +71,7 @@ CfgRedmond::CfgRedmond( QWidget *p, KConfig *c )
   _preview->setUserColor( c->readColorEntry( "Username Text Color", &defaultWhiteColor ) );
   _preview->setStatusColor( c->readColorEntry( "Action Text Color", &defaultDarkColor ) );
 
-  _preview->setIcon( c->readEntry( "User Icon", "go" ) );
+  _preview->setIcon( c->readEntry( "User Icon", "kmenu" ) );
 
   QLabel *lbl = new QLabel( vbox );
   lbl->setText( i18n("(Sorry, but I haven't finished writing this one yet...)") );
@@ -126,7 +126,7 @@ void ThemeRedmond::_initUi()
     bgimg = mTheme->locateThemeData( "Background.png" );
 
   if( mPixmap.isNull() )
-    mPixmap = DesktopIcon( "go", 48 );
+    mPixmap = DesktopIcon( "kmenu", 48 );
 
   QPixmap pix( bgimg );
 
@@ -323,7 +323,7 @@ void ThemeRedmond::_readSettings()
 
   // Overall appearance
   mBackgroundImage = cfg->readEntry( "Background Image", QString::null );
-  mIcon = cfg->readEntry( "User Icon", "go" );
+  mIcon = cfg->readEntry( "User Icon", "kmenu" );
   mWelcomeText = cfg->readEntry( "Welcome Text", i18n("Welcome") );
   mUsernameText = cfg->readEntry( "Username Text", QString::null );
 
