@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 	KSysGuard is currently maintained by Chris Schlaeger <cs@kde.org>.
 	Please do not commit any changes without consulting me first. Thanks!
@@ -37,13 +37,12 @@
 #include "MultiMeterSettings.h"
 
 MultiMeter::MultiMeter(QWidget* parent, const char* name,
-				   const QString& title, double, double, bool nf)
-	: KSGRD::SensorDisplay(parent, name, title)
+				   const QString& title, double, double, bool nf, bool isApplet)
+	: KSGRD::SensorDisplay(parent, name, title, nf, isApplet)
 {
 	setShowUnit( true );
 	lowerLimit = upperLimit = 0;
 	lowerLimitActive = upperLimitActive = false;
-	setNoFrame( nf );
 
 	normalDigitColor = KSGRD::Style->firstForegroundColor();
 	alarmDigitColor = KSGRD::Style->alarmColor();
@@ -64,7 +63,7 @@ MultiMeter::MultiMeter(QWidget* parent, const char* name,
 
 	setPlotterWidget(lcd);
 
-	setMinimumSize(16, 16);
+	setMinimumSize(5, 5);
 	setModified(false);
 }
 
@@ -105,7 +104,10 @@ MultiMeter::answerReceived(int id, const QString& answer)
 		int digits = (int) log10(val) + 1;
 
 		if (noFrame())
-			lcd->setNumDigits(2);
+			if (digits > 4)
+				lcd->setNumDigits(4);
+			else
+				lcd->setNumDigits(digits);	    
 		else
 		{
 			if (digits > 5)
@@ -132,7 +134,7 @@ void
 MultiMeter::resizeEvent(QResizeEvent*)
 {
 	if (noFrame())
-		lcd->setGeometry(0, 0, width() - 1, height() - 1);
+		lcd->setGeometry(0, 0, width(), height());
 	else
 		frame()->setGeometry(0, 0, width(), height());
 }
