@@ -120,7 +120,11 @@ ProcessList::ProcessList(QWidget *parent, const char* name)
 
 	if (aliases.isEmpty())
 	{
+#ifdef Q_OS_LINUX
 		aliases.insert("init", new QString("penguin"));
+#else
+		aliases.insert("init", new QString("system"));
+#endif
 		/* kernel stuff */
 		aliases.insert("bdflush", new QString("kernel"));
 		aliases.insert("dhcpcd", new QString("kernel"));
@@ -235,10 +239,6 @@ ProcessList::ProcessList(QWidget *parent, const char* name)
 	// Elements in the process list may only live in this list.
 	pl.setAutoDelete(true);
 
-	// load the icons we display with the processes
-	icons = new KIconLoader();
-	Q_CHECK_PTR(icons);
-
 	setItemMargin(2);
 	setAllColumnsShowFocus(true);
 	setTreeStepSize(17);
@@ -262,9 +262,6 @@ ProcessList::ProcessList(QWidget *parent, const char* name)
 
 ProcessList::~ProcessList()
 {
-	// remove icon list from memory
-	delete icons;
-
 	delete(headerPM);
 }
 
@@ -611,11 +608,11 @@ ProcessList::addProcess(KSGRD::SensorPSLine* p, ProcessLVI* pli)
 	QPixmap pix;
 	if (!iconCache[name])
 	{
-		pix = icons->loadIcon(name, KIcon::Small,
+		pix = KGlobal::iconLoader()->loadIcon(name, KIcon::Small,
 							  KIcon::SizeSmall, KIcon::DefaultState,
 							  0L, true);
 		if (pix.isNull() || !pix.mask())
-			pix = icons->loadIcon("unknownapp", KIcon::User,
+			pix = KGlobal::iconLoader()->loadIcon("unknownapp", KIcon::User,
 								  KIcon::SizeSmall);
 
 		if (pix.width() != 16 || pix.height() != 16)
@@ -659,7 +656,7 @@ ProcessList::addProcess(KSGRD::SensorPSLine* p, ProcessLVI* pli)
 		else if ( mColumnTypes[col] == "f" )
       pli->setText( col, KGlobal::locale()->formatNumber( (*p)[col].toFloat() ) );
     else if ( mColumnTypes[col] == "D" )
-      pli->setText( col, KGlobal::locale()->formatNumber( (*p)[col].toDouble(), 0 ) );
+      pli->setText( col, KGlobal::locale()->formatNumber( (*p)[col].toInt(), 0 ) );
     else
 			pli->setText(col, (*p)[col]);
 	}
@@ -676,7 +673,7 @@ ProcessList::updateMetaInfo(void)
 	// iterate through all items of the listview
 	for ( ; it.current(); ++it )
 	{
-		if (it.current()->isSelected())
+		if (it.current()->isSelected() && it.current()->isVisible())
 			selectedPIds.append(it.current()->text(1).toInt());
 		if (treeViewEnabled && !it.current()->isOpen())
 			closedSubTrees.append(it.current()->text(1).toInt());
@@ -849,14 +846,12 @@ ProcessList::handleRMBPressed(QListViewItem* lvi, const QPoint& p, int col)
 		break;
 	case 300:
 		{
-		ReniceDlg *reniceDlg = new ReniceDlg(this, "reniceDlg", currentNiceValue, currentPId);
-		Q_CHECK_PTR( reniceDlg );
+		ReniceDlg reniceDlg(this, "reniceDlg", currentNiceValue, currentPId);
 
 		int reniceVal;
-		if ((reniceVal = reniceDlg->exec()) != 40) {
-			delete reniceDlg;
+		if ((reniceVal = reniceDlg.exec()) != 40) {
 			emit reniceProcess(selectedPIds, reniceVal);
-    }
+		}
 		}
 		break;
 	default:
@@ -908,7 +903,7 @@ ProcessList::selectAllItems(bool select)
 {
 	selectedPIds.clear();
 
-	QListViewItemIterator it(this);
+	QListViewItemIterator it(this, QListViewItemIterator::Visible);
 
 	// iterate through all items of the listview
 	for ( ; it.current(); ++it )
@@ -923,7 +918,7 @@ ProcessList::selectAllItems(bool select)
 void
 ProcessList::selectAllChilds(int pid, bool select)
 {
-	QListViewItemIterator it(this);
+	QListViewItemIterator it(this, QListViewItemIterator::Visible );
 
 	// iterate through all items of the listview
 	for ( ; it.current(); ++it )
