@@ -23,6 +23,7 @@
 */
 
 #include <klocale.h>
+#include <knuminput.h>
 
 #include "ReniceDlg.moc"
 
@@ -31,10 +32,8 @@ ReniceDlg::ReniceDlg(QWidget* parent, const char* name, int currentPPrio,
 	: KDialogBase( parent, name, true, i18n("Renice Process"),
                        KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
 {
-	value = currentPPrio;
-
-         QWidget *page = new QWidget( this );
-         setMainWidget(page);
+	QWidget *page = new QWidget( this );
+	setMainWidget(page);
 	vLay = new QVBoxLayout(page, 20, -1, "ReniceLayout");
 
 	QString msg;
@@ -51,34 +50,14 @@ ReniceDlg::ReniceDlg(QWidget* parent, const char* name, int currentPPrio,
 	 * Create a slider with an LCD display to the right using a horizontal
 	 * layout. The slider and the LCD are kept in sync through signals
 	 */
-	sldLay = new QHBoxLayout();
-	vLay->addLayout(sldLay);
-
-	slider = new QSlider(-20, 19, 1, 0, QSlider::Horizontal, page, "prio" );
-	slider->setMaximumSize(210, 25);
-	slider->setMinimumSize(210, 25);
-	slider->setTickmarks((QSlider::TickSetting) 2);
-	slider->setFocusPolicy(QWidget::TabFocus);
-	slider->setFixedHeight(slider->sizeHint().height());
-	slider->setValue(value);
-	sldLay->addWidget(slider);
-	sldLay->addSpacing(10);
-
-	lcd = new QLCDNumber(3, page, "lcd");
-	lcd->setMaximumSize(55, 23);
-	lcd->setMinimumSize(55, 23);
-	lcd->display(value);
-	QObject::connect(slider, SIGNAL(valueChanged(int)), lcd,
-					 SLOT(display(int)));
-	QObject::connect(slider, SIGNAL(valueChanged(int)),
-					 SLOT(setPriorityValue(int)));
-	sldLay->addWidget(lcd);
-	vLay->activate();
+	input = new KIntNumInput(currentPPrio, page, 10);
+	input->setRange(-20, 19);
+	vLay->addWidget(input);
 }
 
 void ReniceDlg::slotOk()
 {
-    done(value);
+    done(input->value());
 }
 
 void ReniceDlg::slotCancel()
