@@ -28,15 +28,12 @@
 #include <qpixmap.h>
 
 #include <kdebug.h>
+#include <kglobal.h>
+
 #include <ksgrd/StyleEngine.h>
 
 #include "SignalPlotter.h"
 
-static inline int min( int a, int b )
-{
-  return ( a < b ? a : b );
-}
-
 SignalPlotter::SignalPlotter( QWidget *parent, const char *name )
   : QWidget( parent, name )
 {
@@ -367,7 +364,7 @@ void SignalPlotter::updateDataBuffers()
                                          mHorizontalScale ) + 2.5 );
 
   // overlap between the old and the new buffers.
-  int overlap = min( mSamples, newSampleNum );
+  int overlap = kMin( mSamples, newSampleNum );
 
   for ( uint i = 0; i < mBeamData.count(); ++i ) {
     double* nd = new double[ newSampleNum ];
