@@ -35,6 +35,7 @@
 
 #include "WorkSheet.h"
 #include "WorkSheetSettings.h"
+#include "ProcessController.h"
 
 #include "Workspace.h"
 
@@ -341,7 +342,7 @@ void Workspace::deleteWorkSheet( const QString &fileName )
     }
 }
 
-bool Workspace::restoreWorkSheet( const QString &fileName, const QString &newName )
+WorkSheet *Workspace::restoreWorkSheet( const QString &fileName, const QString &newName )
 {
   /* We might want to save the worksheet under a different name later. This
    * name can be specified by newName. If newName is empty we use the
@@ -365,7 +366,7 @@ bool Workspace::restoreWorkSheet( const QString &fileName, const QString &newNam
 
   if ( !sheet->load( fileName ) ) {
     delete sheet;
-    return false;
+    return NULL;
   }
   
   mSheetList.append( sheet );
@@ -377,7 +378,7 @@ bool Workspace::restoreWorkSheet( const QString &fileName, const QString &newNam
   if ( !newName.isEmpty() )
     sheet->setFileName( newName );
 
-  return true;
+  return sheet;
 }
 
 void Workspace::cut()
@@ -443,10 +444,20 @@ void Workspace::showProcesses()
   kstd->addResourceType( "data", "share/apps/ksysguard" );
 
   QString file = kstd->findResource( "data", "ProcessTable.sgrd" );
-  if ( !file.isEmpty() )
-    restoreWorkSheet( file );
-  else
+  if ( file.isEmpty() ) {
     KMessageBox::error( this, i18n( "Cannot find file ProcessTable.sgrd." ) );
+    return;
+  }
+  WorkSheet *processSheet = restoreWorkSheet( file );
+  if(!processSheet) return;
+
+  //Set the focus of the search line.  This is nasty I know, but I don't know how better to do this :(
+  KSGRD::SensorDisplay *processSensor = processSheet->display( 0,0 );
+  if(!processSensor || !processSensor->isA("ProcessController")) return;
+  ProcessController *controller = dynamic_cast<ProcessController *>(processSensor);
+  if(!controller) return;
+  controller->setSearchFocus();
+
 }
 
 #include "Workspace.moc"
