@@ -14,9 +14,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: netdev.c,v 1.2 2003/03/07 22:08:25 waba Exp $
 */
 
 #include <sys/types.h>
