@@ -17,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -40,7 +40,9 @@
 #include <unistd.h>
 #include <errno.h>
 #include <../version.h>
-
+#ifdef HAVE_DNSSD
+#include <dns_sd.h>
+#endif
 #include "modules.h"
 
 #include "ksysguardd.h"
@@ -60,6 +62,10 @@ static unsigned char BindToAllInterfaces = 0;
 static int CurrentSocket;
 static const char *LockFile = "/var/run/ksysguardd.pid";
 static const char *ConfigFile = KSYSGUARDDRCFILE;
+#ifdef HAVE_DNSSD
+static int ServiceSocket = -1;
+static DNSServiceRef Ref;
+#endif
 
 void signalHandler( int sig );
 void makeDaemon( void );
@@ -67,6 +73,10 @@ void resetClientList( void );
 int addClient( int client );
 int delClient( int client );
 int createServerSocket( void );
+#ifdef HAVE_DNSSD
+void publish_callback (DNSServiceRef, DNSServiceFlags, DNSServiceErrorType errorCode, const char *name,
+		       const char*, const char*, void *context);
+#endif
 
 /**
   This variable is set to 1 if a module requests that the daemon should
@@ -173,7 +183,9 @@ void signalHandler( int sig )
   switch ( sig ) {
     case SIGQUIT:
     case SIGTERM:
-      /* Not really anything to do here at the moment. */
+#ifdef HAVE_DNSSD
+    if ( ServiceSocket != -1 ) DNSServiceRefDeallocate(Ref);
+#endif      
       exit( 0 );
       break;
   }
@@ -195,20 +207,25 @@ static void dropPrivileges( void )
 {
   struct passwd *pwd;
 
-  if ( ( pwd = getpwnam( "nobody" ) ) != NULL )
-    setuid( pwd->pw_uid );
-	else {
+  if ( ( pwd = getpwnam( "nobody" ) ) != NULL ) {
+    if ( !setgid(pwd->pw_gid) )
+      setuid(pwd->pw_uid);
+    if (!geteuid() && getuid() != pwd->pw_uid)
+      _exit(1);
+  }
+  else {
     log_error( "User 'nobody' does not exist." );
     /**
       We exit here to avoid becoming vulnerable just because
       user nobody does not exist.
      */
-    exit( 1 );
+    _exit(1);
   }
 }
 
 void makeDaemon( void )
 {
+  int fd = -1;
   switch ( fork() ) {
     case -1:
       log_error( "fork() failed" );
@@ -218,10 +235,18 @@ void makeDaemon( void )
       chdir( "/" );
       umask( 0 );
       if ( createLockFile() < 0 )
-        exit( 1 );
+        _exit( 1 );
 
       dropPrivileges();
       installSignalHandler();
+      
+      fd = open("/dev/null", O_RDWR, 0); 
+      if (fd != -1) {
+          dup2(fd, STDIN_FILENO);
+          dup2(fd, STDOUT_FILENO);
+          dup2(fd, STDERR_FILENO);
+          close (fd);
+      }
       break;
     default:
       exit( 0 );
@@ -314,6 +339,15 @@ int delClient( int client )
   return -1;
 }
 
+#ifdef HAVE_DNSSD
+void publish_callback (DNSServiceRef ref, DNSServiceFlags f, DNSServiceErrorType errorCode, const char *name,
+		       const char* type, const char* domain, void *context)
+{
+	if (errorCode != kDNSServiceErr_NoError) log_error("Publishing DNS-SD service failed with error %i",errorCode);
+}
+#endif
+
+
 int createServerSocket()
 {
   int i = 1;
@@ -361,6 +395,13 @@ int createServerSocket()
     return -1;
   }
 
+#ifdef HAVE_DNSSD
+  if ( BindToAllInterfaces ) 
+    if (DNSServiceRegister(&Ref, 0, 0, 0, "_ksysguard._tcp", RegisterDomain ? 
+    RegisterDomain : "local.",NULL, htons(SocketPort), 0, 0, publish_callback, 0) == kDNSServiceErr_NoError)
+      ServiceSocket = DNSServiceRefSockFD(Ref);
+#endif
+
   return newSocket;
 }
 
@@ -375,6 +416,12 @@ static int setupSelect( fd_set* fds )
   if ( RunAsDaemon ) {
     int i;
     FD_SET( ServerSocket, fds );
+#ifdef HAVE_DNSSD
+    if ( ServiceSocket != -1 ) {
+        FD_SET( ServiceSocket, fds );
+	if ( highestFD < ServiceSocket) highestFD = ServiceSocket;
+    }
+#endif	
 
     for ( i = 0; i < MAX_CLIENTS; i++ ) {
       if ( ClientList[ i ].socket != -1 ) {
@@ -443,6 +490,10 @@ static void handleSocketTraffic( int socketNo, const fd_set* fds )
         addClient( clientsocket );
     }
 
+#ifdef HAVE_DNSSD
+    if ( ServiceSocket != -1 && FD_ISSET( ServiceSocket, fds )) DNSServiceProcessResult(Ref);
+#endif
+
     for ( i = 0; i < MAX_CLIENTS; i++ ) {
       if ( ClientList[ i ].socket != -1 ) {
         CurrentSocket = ClientList[ i ].socket;
