@@ -49,8 +49,18 @@ BRIDGE_HELPER( void, maximize, MaximizeMode m, m, )
 BRIDGE_HELPER( void, minimize,,, )
 BRIDGE_HELPER( void, showContextHelp,,, )
 BRIDGE_HELPER( void, setDesktop, int desktop, desktop, )
-BRIDGE_HELPER( void, setKeepAbove, bool set, set, )
-BRIDGE_HELPER( void, setKeepBelow, bool set, set, )
+
+void Bridge::setKeepAbove( bool set )
+    {
+    if( c->keepAbove() != set )
+        c->workspace()->performWindowOperation( c, KeepAboveOp );
+    }
+
+void Bridge::setKeepBelow( bool set )
+    {
+    if( c->keepBelow() != set )
+        c->workspace()->performWindowOperation( c, KeepBelowOp );
+    }
 
 NET::WindowType Bridge::windowType( unsigned long supported_types ) const
     {
@@ -113,6 +123,11 @@ void Bridge::titlebarDblClickOperation()
     c->workspace()->performWindowOperation( c, options->operationTitlebarDblClick());
     }
 
+void Bridge::titlebarMouseWheelOperation( int delta )
+    {
+    c->performMouseCommand( options->operationTitlebarMouseWheel( delta ), QCursor::pos());
+    }
+
 void Bridge::setShade( bool set )
     {
     c->setShade( set ? ShadeNormal : ShadeNone );
