@@ -674,7 +674,7 @@ void KAdvancedConfig::load( void )
     setShadeHover(config->readBoolEntry(KWIN_SHADEHOVER, false));
     setShadeHoverInterval(config->readNumEntry(KWIN_SHADEHOVER_INTERVAL, 250));
 
-    setElectricBorders(config->readBoolEntry(KWM_ELECTRIC_BORDER, false));
+    setElectricBorders(config->readNumEntry(KWM_ELECTRIC_BORDER, 0));
     setElectricBorderDelay(config->readNumEntry(KWM_ELECTRIC_BORDER_DELAY, 150));
 
 //    setFocusStealing( config->readNumEntry(KWIN_FOCUS_STEALING, 2 ));
