@@ -13,7 +13,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "ruleswidget.h"
@@ -31,6 +31,7 @@
 #include <assert.h>
 #include <kmessagebox.h>
 #include <qtabwidget.h>
+#include <qtimer.h>
 
 #include "../../rules.h"
 
@@ -61,13 +62,21 @@ RulesWidget::RulesWidget( QWidget* parent, const char* name )
               " after the window is created. No further changes will be affected.</li>"
               "<li><em>Remember:</em> The value of the window property will be remembered and every time"
               " time the window is created, the last remembered value will be applied.</li>"
-              "<li><em>Force:</em> The window property will be always forced to the given value.</li></ul>" );
+              "<li><em>Force:</em> The window property will be always forced to the given value.</li>"
+              "<li><em>Apply Now:</em> The window property will be set to the given value immediately"
+              " and will not be affected later (this action will be deleted afterwards).</li>"
+              "<li><em>Force temporarily:</em> The window property will be forced to the given value"
+              " until it is hidden (this action will be deleted after the window is hidden).</li>"
+              "</ul>" );
     QString forceRuleDesc =
         i18n( "Specify how the window property should be affected:<ul>"
               "<li><em>Do Not Affect:</em> The window property will not be affected and therefore"
               " the default handling for it will be used. Specifying this will block more generic"
               " window settings from taking effect.</li>"
-              "<li><em>Force:</em> The window property will be always forced to the given value.</li></ul>" );
+              "<li><em>Force:</em> The window property will be always forced to the given value.</li>"
+              "<li><em>Force temporarily:</em> The window property will be forced to the given value"
+              " until it is hidden (this action will be deleted after the window is hidden).</li>"
+              "</ul>" );
     // window tabs have enable signals done in designer
     // geometry tab
     SETUP( position, set );
@@ -98,6 +107,7 @@ RulesWidget::RulesWidget( QWidget* parent, const char* name )
     SETUP( minsize, force );
     SETUP( maxsize, force );
     SETUP( strictgeometry, force );
+    SETUP( disableglobalshortcuts, force );
     KWinModule module;
     int i;
     for( i = 1;
@@ -149,6 +159,7 @@ UPDATE_ENABLE_SLOT( ignoreposition )
 UPDATE_ENABLE_SLOT( minsize )
 UPDATE_ENABLE_SLOT( maxsize )
 UPDATE_ENABLE_SLOT( strictgeometry )
+UPDATE_ENABLE_SLOT( disableglobalshortcuts )
 
 #undef UPDATE_ENABLE_SLOT
 
@@ -159,6 +170,8 @@ static const int set_rule_to_combo[] =
     3, // Force
     1, // Apply
     2, // Remember
+    4, // ApplyNow
+    5  // ForceTemporarily
     };
 
 static const Rules::SetRule combo_to_set_rule[] =
@@ -166,20 +179,27 @@ static const Rules::SetRule combo_to_set_rule[] =
     ( Rules::SetRule )Rules::DontAffect,
     ( Rules::SetRule )Rules::Apply,
     ( Rules::SetRule )Rules::Remember,
-    ( Rules::SetRule )Rules::Force
+    ( Rules::SetRule )Rules::Force,
+    ( Rules::SetRule )Rules::ApplyNow,
+    ( Rules::SetRule )Rules::ForceTemporarily
     };
 
 static const int force_rule_to_combo[] =
     {
     0, // Unused
     0, // Don't Affect
-    1 // Force
+    1, // Force
+    0, // Apply
+    0, // Remember
+    0, // ApplyNow
+    2  // ForceTemporarily
     };
 
 static const Rules::ForceRule combo_to_force_rule[] =
     {
     ( Rules::ForceRule )Rules::DontAffect,
-    ( Rules::ForceRule )Rules::Force
+    ( Rules::ForceRule )Rules::Force,
+    ( Rules::ForceRule )Rules::ForceTemporarily
     };
 
 static QString positionToStr( const QPoint& p )
@@ -248,13 +268,15 @@ static int placementToCombo( Placement::Policy placement )
         {
         1, // NoPlacement
         0, // Default
-        5, // Random
+        0, // Unknown
+        6, // Random
         2, // Smart
-        3, // Cascade
-        4, // Centered
-        6, // ZeroCornered
-        7, // UnderMouse
-        8 // OnMainWindow
+        4, // Cascade
+        5, // Centered
+        7, // ZeroCornered
+        8, // UnderMouse
+        9, // OnMainWindow
+        3  // Maximizing
         };
     return conv[ placement ];
     }
@@ -266,12 +288,14 @@ static Placement::Policy comboToPlacement( int val )
         Placement::Default,
         Placement::NoPlacement,
         Placement::Smart,
+        Placement::Maximizing,
         Placement::Cascade,
         Placement::Centered,
         Placement::Random,
         Placement::ZeroCornered,
         Placement::UnderMouse,
         Placement::OnMainWindow
+        // no Placement::Unknown
         };
     return conv[ val ];
     }
@@ -405,6 +429,7 @@ void RulesWidget::setRules( Rules* rules )
     LINEEDIT_FORCE_RULE( minsize, sizeToStr );
     LINEEDIT_FORCE_RULE( maxsize, sizeToStr );
     CHECKBOX_FORCE_RULE( strictgeometry, );
+    CHECKBOX_FORCE_RULE( disableglobalshortcuts, );
     }
 
 #undef GENERIC_RULE
@@ -494,6 +519,7 @@ Rules* RulesWidget::rules() const
     LINEEDIT_FORCE_RULE( minsize, strToSize );
     LINEEDIT_FORCE_RULE( maxsize, strToSize );
     CHECKBOX_FORCE_RULE( strictgeometry, );
+    CHECKBOX_FORCE_RULE( disableglobalshortcuts, );
     return rules;
     }
 
@@ -610,6 +636,7 @@ void RulesWidget::prefillUnusedValues( const KWin::WindowInfo& info )
     LINEEDIT_PREFILL( minsize, sizeToStr, info.frameGeometry().size() );
     LINEEDIT_PREFILL( maxsize, sizeToStr, info.frameGeometry().size() );
     //CHECKBOX_PREFILL( strictgeometry, );
+    //CHECKBOX_PREFILL( disableglobalshortcuts, );
     }
 
 #undef GENERIC_PREFILL
@@ -668,16 +695,31 @@ RulesDialog::RulesDialog( QWidget* parent, const char* name )
 
 // window is set only for Alt+F3/Window-specific settings, because the dialog
 // is then related to one specific window
-Rules* RulesDialog::edit( Rules* r, WId window )
+Rules* RulesDialog::edit( Rules* r, WId window, bool show_hints )
     {
     rules = r;
     widget->setRules( rules );
     if( window != 0 )
         widget->prepareWindowSpecific( window );
+    if( show_hints )
+        QTimer::singleShot( 0, this, SLOT( displayHints()));
     exec();
     return rules;
     }
 
+void RulesDialog::displayHints()
+    {
+    QString str = "<qt><p>";
+    str += i18n( "This configuration dialog allows altering settings only for the selected window"
+                 " or application. Find the setting you want to affect, enable the setting using the checkbox,"
+                 " select in what way the setting should be affected and to which value." );
+#if 0 // maybe later
+    str += "</p><p>" + i18n( "Consult the documentation for more details." );
+#endif
+    str += "</p></qt>";
+    KMessageBox::information( this, str, QString::null, "displayhints" );
+    }
+
 void RulesDialog::accept()
     {
     if( !widget->finalCheck())
