@@ -12,9 +12,15 @@ License. See the file "COPYING" for the exact licensing terms.
 #ifndef KWIN_NOTIFICATIONS_H
 #define KWIN_NOTIFICATIONS_H
 
+#include <stdlib.h>
+#include <qstring.h>
+#include <qvaluelist.h>
+
 namespace KWinInternal
 {
 
+class Client;
+
 class Notify
     {
     public:
@@ -39,10 +45,23 @@ class Notify
             MoveEnd,
             ResizeStart,
             ResizeEnd,
+            DemandAttentionCurrent,
+            DemandAttentionOther,
             DesktopChange = 100
             };
 
-        static void raise( Event );
+        static bool raise( Event, const QString& message = QString::null, Client* c = NULL );
+        static bool makeDemandAttention( Event );
+        static void sendPendingEvents();
+    private:
+        static QString eventToName( Event );
+        struct EventData
+            {
+            QString event;
+            QString message;
+            long window;
+            };
+        static QValueList< EventData > pending_events;
     };
 
 } // namespace
