@@ -82,21 +82,12 @@ unsigned long Options::updateSettings()
         focusStealingPreventionLevel = 0;
 
     KConfig *gc = new KConfig("kdeglobals", false, false);
-    bool isVirtual = KApplication::desktop()->isVirtualDesktop();
     gc->setGroup("Windows");
-    xineramaEnabled = gc->readBoolEntry ("XineramaEnabled", isVirtual ) &&
-                      isVirtual;
-    if (xineramaEnabled) 
-        {
-        xineramaPlacementEnabled = gc->readBoolEntry ("XineramaPlacementEnabled", true);
-        xineramaMovementEnabled = gc->readBoolEntry ("XineramaMovementEnabled", true);
-        xineramaMaximizeEnabled = gc->readBoolEntry ("XineramaMaximizeEnabled", true);
-        xineramaFullscreenEnabled = gc->readBoolEntry ("XineramaFullscreenEnabled", true);
-        }
-    else 
-        {
-        xineramaPlacementEnabled = xineramaMovementEnabled = xineramaMaximizeEnabled = xineramaFullscreenEnabled = false;
-        }
+    xineramaEnabled = gc->readBoolEntry ("XineramaEnabled", true );
+    xineramaPlacementEnabled = gc->readBoolEntry ("XineramaPlacementEnabled", true);
+    xineramaMovementEnabled = gc->readBoolEntry ("XineramaMovementEnabled", true);
+    xineramaMaximizeEnabled = gc->readBoolEntry ("XineramaMaximizeEnabled", true);
+    xineramaFullscreenEnabled = gc->readBoolEntry ("XineramaFullscreenEnabled", true);
     delete gc;
 
     placement = Placement::policyFromString( config->readEntry("Placement"), true );
