@@ -117,7 +117,9 @@ static int limit0to4( int i ) { return QMAX( 0, QMIN( 4, i )); }
 
 void Rules::readFromCfg( KConfig& cfg )
     {
-    description = cfg.readEntry( "description" );
+    description = cfg.readEntry( "Description" );
+    if( description.isEmpty()) // capitalized first, lowercase for backwards compatibility
+        description = cfg.readEntry( "description" );
     READ_MATCH_STRING( wmclass, .lower().latin1() );
     wmclasscomplete = cfg.readBoolEntry( "wmclasscomplete" );
     READ_MATCH_STRING( windowrole, .lower().latin1() );
@@ -216,7 +218,7 @@ void Rules::readFromCfg( KConfig& cfg )
 
 void Rules::write( KConfig& cfg ) const
     {
-    cfg.writeEntry( "description", description );
+    cfg.writeEntry( "Description", description );
     // always write wmclass
     WRITE_MATCH_STRING( wmclass, (const char*), true );
     cfg.writeEntry( "wmclasscomplete", wmclasscomplete );
@@ -863,6 +865,8 @@ void Client::updateWindowRules()
     {
     if( !isManaged()) // not fully setup yet
         return;
+    if( workspace()->rulesUpdatesDisabled())
+        return;
     client_rules.update( this );
     }
 
@@ -1058,6 +1062,16 @@ void Workspace::rulesUpdated()
     rulesUpdatedTimer.start( 1000, true );
     }
 
+void Workspace::disableRulesUpdates( bool disable )
+    {
+    rules_updates_disabled = disable;
+    if( !disable )
+        for( ClientList::ConstIterator it = clients.begin();
+             it != clients.end();
+             ++it )
+            (*it)->updateWindowRules();
+    }
+
 #endif
 
 } // namespace
