@@ -306,11 +306,21 @@ NET::WindowType Workspace::txtToWindowType( const char* txt )
 // but Qt doesn't have API for saying when session saved finished (either
 // successfully, or was cancelled). Therefore, create another connection
 // to session manager, that will provide this information.
-static void save_yourself( SmcConn conn_P, SmPointer ptr, int, Bool, int, Bool )
+// Similarly the remember feature of window-specific settings should be disabled
+// during KDE shutdown when windows may move e.g. because of Kicker going away
+// (struts changing). When session saving starts, it can be cancelled, in which
+// case the shutdown_cancelled callback is invoked, or it's a checkpoint that
+// is immediatelly followed by save_complete, or finally it's a shutdown that
+// is immediatelly followed by die callback. So getting save_yourself with shutdown
+// set disables window-specific settings remembering, getting shutdown_cancelled
+// re-enables, otherwise KWin will go away after die.
+static void save_yourself( SmcConn conn_P, SmPointer ptr, int, Bool shutdown, int, Bool )
     {
     SessionSaveDoneHelper* session = reinterpret_cast< SessionSaveDoneHelper* >( ptr );
     if( conn_P != session->connection())
         return;
+    if( shutdown )
+        Workspace::self()->disableRulesUpdates( true );
     SmcSaveYourselfDone( conn_P, True );
     }
 
@@ -336,6 +346,7 @@ static void shutdown_cancelled( SmcConn conn_P, SmPointer ptr )
     SessionSaveDoneHelper* session = reinterpret_cast< SessionSaveDoneHelper* >( ptr );
     if( conn_P != session->connection())
         return;
+    Workspace::self()->disableRulesUpdates( false ); // re-enable
     // no need to differentiate between successful finish and cancel
     session->saveDone();
     }
