@@ -290,6 +290,7 @@ void Workspace::init()
         NET::WM2ExtendedStrut |
         NET::WM2KDETemporaryRules |
         NET::WM2ShowingDesktop |
+        NET::WM2DesktopLayout |
         0
         ,
         NET::ActionMove |
@@ -310,6 +311,7 @@ void Workspace::init()
         protocols, 5, qt_xscreen() );
 
     loadDesktopSettings();
+    updateDesktopLayout();
     // extra NETRootInfo instance in Client mode is needed to get the values of the properties
     NETRootInfo client_info( qt_xdisplay(), NET::ActiveWindow | NET::CurrentDesktop );
     int initial_desktop;
@@ -1521,25 +1523,33 @@ void Workspace::sendClientToDesktop( Client* c, int desk, bool dont_activate )
     updateClientArea();
     }
 
-void Workspace::setDesktopLayout(int o, int x, int y)
+void Workspace::setDesktopLayout( int, int, int )
+    { // DCOP-only, unused
+    }
+
+void Workspace::updateDesktopLayout()
     {
-    layoutOrientation = (Qt::Orientation) o;
-    layoutX = x;
-    layoutY = y;
+    // rootInfo->desktopLayoutCorner(); // I don't find this worth bothering, feel free to
+    layoutOrientation = ( rootInfo->desktopLayoutOrientation() == NET::OrientationHorizontal
+        ? Qt::Horizontal : Qt::Vertical );
+    layoutX = rootInfo->desktopLayoutColumnsRows().width();
+    layoutY = rootInfo->desktopLayoutColumnsRows().height();
+    if( layoutX == 0 && layoutY == 0 ) // not given, set default layout
+        layoutY = 2;
     }
 
 void Workspace::calcDesktopLayout(int &x, int &y) const
     {
-    x = layoutX;
+    x = layoutX; // <= 0 means compute it from the other and total number of desktops
     y = layoutY;
-    if ((x == -1) && (y > 0))
+    if((x <= 0) && (y > 0))
        x = (numberOfDesktops()+y-1) / y;
-    else if ((y == -1) && (x > 0))
+    else if((y <=0) && (x > 0))
        y = (numberOfDesktops()+x-1) / x;
 
-    if (x == -1)
+    if(x <=0)
        x = 1;
-    if (y == -1)
+    if (y <= 0)
        y = 1;
     }
 
@@ -1598,6 +1608,7 @@ bool Workspace::removeSystemTrayWin( WId w, bool check )
             }
         }
     systemTrayWins.remove( w );
+    XRemoveFromSaveSet (qt_xdisplay (), w);
     propagateSystemTrayWins();
     return TRUE;
     }
