@@ -463,7 +463,7 @@ void KFileIVI::updatePixmapSize()
 
     KonqIconViewWidget* view = static_cast<KonqIconViewWidget*>( iconView() );
 
-    if ( view->canPreview( item() ) ) {
+    if ( view && view->canPreview( item() ) ) {
         int previewSize = view->previewIconSize( size );
         setPixmapSize( QSize( previewSize, previewSize ) );
     }
