@@ -91,7 +91,7 @@ void KonqOperations::del( QWidget * parent, int method, const KURL::List & selec
   }
 
   KonqOperations * op = new KonqOperations( parent );
-  int confirmation = DEFAULT_CONFIRMATION;
+    ConfirmationType confirmation = DEFAULT_CONFIRMATION;
   op->_del( method, selectedURLs, confirmation );
 }
 
@@ -174,7 +174,7 @@ void KonqOperations::copy( QWidget * parent, int method, const KURL::List & sele
      (void) new KonqCommandRecorder( method==MOVE?KonqCommand::MOVE:KonqCommand::LINK, selectedURLs, destUrl, job );
 }
 
-void KonqOperations::_del( int method, const KURL::List & _selectedURLs, int confirmation )
+void KonqOperations::_del( int method, const KURL::List & _selectedURLs, ConfirmationType confirmation )
 {
     KURL::List selectedURLs;
     for (KURL::List::ConstIterator it = _selectedURLs.begin(); it != _selectedURLs.end(); ++it)
@@ -185,44 +185,44 @@ void KonqOperations::_del( int method, const KURL::List & _selectedURLs, int con
         return;
     }
 
-  m_method = method;
-  if ( confirmation == SKIP_CONFIRMATION || askDeleteConfirmation( selectedURLs, confirmation ) )
-  {
-    //m_srcURLs = selectedURLs;
-    KIO::Job *job;
-    switch( method )
+    if ( askDeleteConfirmation( selectedURLs, method, confirmation, parentWidget() ) )
     {
-      case TRASH:
-      {
-        job = KIO::trash( selectedURLs );
-        (void) new KonqCommandRecorder( KonqCommand::TRASH, selectedURLs, "trash:/", job );
-         break;
-      }
-      case EMPTYTRASH:
-      {
-        // Same as in ktrash --empty
-        QByteArray packedArgs;
-        QDataStream stream( packedArgs, IO_WriteOnly );
-        stream << (int)1;
-        job = KIO::special( "trash:/", packedArgs );
-        KNotifyClient::event(0, "Trash: emptied");
-        break;
-      }
-      case DEL:
-        job = KIO::del( selectedURLs );
-        break;
-      case SHRED:
-        job = KIO::del( selectedURLs, true );
-        break;
-      default:
-        kdWarning() << "Unknown operation: " << method << endl;
+        //m_srcURLs = selectedURLs;
+        KIO::Job *job;
+        m_method = method;
+        switch( method )
+        {
+        case TRASH:
+        {
+            job = KIO::trash( selectedURLs );
+            (void) new KonqCommandRecorder( KonqCommand::TRASH, selectedURLs, "trash:/", job );
+            break;
+        }
+        case EMPTYTRASH:
+        {
+            // Same as in ktrash --empty
+            QByteArray packedArgs;
+            QDataStream stream( packedArgs, IO_WriteOnly );
+            stream << (int)1;
+            job = KIO::special( "trash:/", packedArgs );
+            KNotifyClient::event(0, "Trash: emptied");
+            break;
+        }
+        case DEL:
+            job = KIO::del( selectedURLs );
+            break;
+        case SHRED:
+            job = KIO::del( selectedURLs, true );
+            break;
+        default:
+            kdWarning() << "Unknown operation: " << method << endl;
+            delete this;
+            return;
+        }
+        connect( job, SIGNAL( result( KIO::Job * ) ),
+                 SLOT( slotResult( KIO::Job * ) ) );
+    } else
         delete this;
-        return;
-    }
-    connect( job, SIGNAL( result( KIO::Job * ) ),
-             SLOT( slotResult( KIO::Job * ) ) );
-  } else
-    delete this;
 }
 
 void KonqOperations::_restoreTrashedItems( const KURL::List& urls )
@@ -233,16 +233,18 @@ void KonqOperations::_restoreTrashedItems( const KURL::List& urls )
              SLOT( slotResult( KIO::Job * ) ) );
 }
 
-bool KonqOperations::askDeleteConfirmation( const KURL::List & selectedURLs, int confirmation )
+bool KonqOperations::askDeleteConfirmation( const KURL::List & selectedURLs, int method, ConfirmationType confirmation, QWidget* widget )
 {
+    if ( confirmation == SKIP_CONFIRMATION )
+        return true;
     QString keyName;
     bool ask = ( confirmation == FORCE_CONFIRMATION );
     if ( !ask )
     {
         KConfig config("konquerorrc", true, false);
         config.setGroup( "Trash" );
-        keyName = ( m_method == DEL ? "ConfirmDelete" : m_method == SHRED ? "ConfirmShred" : "ConfirmTrash" );
-        bool defaultValue = ( m_method == DEL ? DEFAULT_CONFIRMDELETE : m_method == SHRED ? DEFAULT_CONFIRMSHRED : DEFAULT_CONFIRMTRASH );
+        keyName = ( method == DEL ? "ConfirmDelete" : method == SHRED ? "ConfirmShred" : "ConfirmTrash" );
+        bool defaultValue = ( method == DEL ? DEFAULT_CONFIRMDELETE : method == SHRED ? DEFAULT_CONFIRMSHRED : DEFAULT_CONFIRMTRASH );
         ask = config.readBoolEntry( keyName, defaultValue );
     }
     if ( ask )
@@ -260,10 +262,10 @@ bool KonqOperations::askDeleteConfirmation( const KURL::List & selectedURLs, int
       }
 
       int result;
-      switch(m_method)
+      switch(method)
       {
       case DEL:
-          result = KMessageBox::warningContinueCancelList( 0,
+          result = KMessageBox::warningContinueCancelList( widget,
              	i18n( "Do you really want to delete this item?", "Do you really want to delete these %n items?", prettyList.count()),
              	prettyList,
 		i18n( "Delete Files" ),
@@ -272,7 +274,7 @@ bool KonqOperations::askDeleteConfirmation( const KURL::List & selectedURLs, int
 	 break;
 
       case SHRED:
-          result = KMessageBox::warningContinueCancelList( 0,
+          result = KMessageBox::warningContinueCancelList( widget,
                 i18n( "Do you really want to shred this item?", "Do you really want to shred these %n items?", prettyList.count()),
                 prettyList,
                 i18n( "Shred Files" ),
@@ -282,7 +284,7 @@ bool KonqOperations::askDeleteConfirmation( const KURL::List & selectedURLs, int
 
       case MOVE:
       default:
-          result = KMessageBox::warningContinueCancelList( 0,
+          result = KMessageBox::warningContinueCancelList( widget,
                 i18n( "Do you really want to move this item to the trash?", "Do you really want to move these %n items to the trash?", prettyList.count()),
                 prettyList,
 		i18n( "Move to Trash" ),
@@ -517,7 +519,7 @@ void KonqOperations::doFileCopy()
         }
 
         m_method = TRASH;
-        if ( askDeleteConfirmation( mlst, DEFAULT_CONFIRMATION ) )
+        if ( askDeleteConfirmation( mlst, TRASH, DEFAULT_CONFIRMATION, parentWidget() ) )
             action = QDropEvent::Move;
         else
         {
@@ -807,4 +809,9 @@ void KonqMultiRestoreJob::slotResult( KIO::Job *job )
     slotStart();
 }
 
+QWidget* KonqOperations::parentWidget() const
+{
+    return static_cast<QWidget *>( parent() );
+}
+
 #include "konq_operations.moc"
