@@ -343,7 +343,8 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
     bool isDirectory    = S_ISDIR(mode);
     bool bTrashIncluded = false;
     bool mediaFiles     = false;
-    bool isLocal        = m_lstItems.first()->isLocalFile()
+    bool isReallyLocal = m_lstItems.first()->isLocalFile();
+    bool isLocal        = isReallyLocal
                        || m_lstItems.first()->url().protocol()=="media"
                        || m_lstItems.first()->url().protocol()=="system";
     bool isTrashLink     = false;
@@ -386,6 +387,8 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
         if ( mimeTypeList.findIndex( (*it)->mimetype() ) == -1 )
             mimeTypeList << (*it)->mimetype();
 
+        if ( isReallyLocal && !url.isLocalFile() )
+            isReallyLocal = false;
         if ( isLocal && !url.isLocalFile() && url.protocol() != "media" && url.protocol() != "system" )
             isLocal = false;
 
@@ -431,7 +434,6 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
             sDeleting = false;
         }
     }
-    const bool isSingleLocal = m_lstItems.count() == 1 && isLocal;
 
     m_info.m_Reading = sReading;
     m_info.m_Writing = sWriting;
@@ -575,6 +577,9 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
     if ( isCurrentTrash )
     {
         act = new KAction( i18n( "&Empty Trash Bin" ), "emptytrash", 0, this, SLOT( slotPopupEmptyTrashBin() ), &m_ownActions, "empytrash" );
+        KSimpleConfig trashConfig( "trashrc", true );
+        trashConfig.setGroup( "Status" );
+        act->setEnabled( !trashConfig.readBoolEntry( "Empty", true ) );
         addAction( act );
     }
     addGroup( "editactions" );
@@ -615,15 +620,20 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
 
     //////////////////////////////////////////////////////
 
+    const bool isSingleLocal = m_lstItems.count() == 1 && isLocal;
     PopupServices s;
     KURL urlForServiceMenu( m_lstItems.first()->url() );
+    if (isLocal && !isReallyLocal) { // media or system
+        bool dummy;
+        urlForServiceMenu = m_lstItems.first()->mostLocalURL(dummy);
+    }
 
     // 1 - Look for builtin and user-defined services
     if ( m_sMimeType == "application/x-desktop" && isSingleLocal ) // .desktop file
     {
         // get builtin services, like mount/unmount
-        s.builtin = KDEDesktopMimeType::builtinServices( m_lstItems.first()->url() );
-        const QString path = m_lstItems.first()->url().path();
+        s.builtin = KDEDesktopMimeType::builtinServices( urlForServiceMenu );
+        const QString path = urlForServiceMenu.path();
         KSimpleConfig cfg( path, true );
         cfg.setDesktopGroup();
         const QString priority = cfg.readEntry("X-KDE-Priority");
@@ -634,7 +644,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
            // of the .desktop file instead of the .desktop file itself?
         }
         ServiceList* list = s.selectList( priority, submenuName );
-        (*list) = KDEDesktopMimeType::userDefinedServices( path, cfg, url.isLocalFile() );
+        (*list) = KDEDesktopMimeType::userDefinedServices( path, cfg, urlForServiceMenu.isLocalFile() );
     }
 
     if ( sReading )
@@ -645,7 +655,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
         // first check the .directory if this is a directory
         if (isDirectory && isSingleLocal)
         {
-            QString dotDirectoryFile = m_lstItems.first()->url().path(1).append(".directory");
+            QString dotDirectoryFile = urlForServiceMenu.path(1).append(".directory");
             KSimpleConfig cfg( dotDirectoryFile, true );
             cfg.setDesktopGroup();
 
@@ -851,8 +861,24 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
                 KTrader::OfferList::ConstIterator it = offers.begin();
                 for( ; it != offers.end(); it++ )
                 {
-                    if ((*it)->noDisplay())
-                        continue;
+                    KService::Ptr service = (*it);
+
+                    // Skip OnlyShowIn=Foo and NotShowIn=KDE entries,
+                    // but still offer NoDisplay=true entries, that's the
+                    // whole point of such desktop files. This is why we don't
+                    // use service->noDisplay() here.
+                    const QString onlyShowIn = service->property("OnlyShowIn", QVariant::String).toString();
+                    if ( !onlyShowIn.isEmpty() ) {
+                        const QStringList aList = QStringList::split(';', onlyShowIn);
+                        if (!aList.contains("KDE"))
+                            continue;
+                    }
+                    const QString notShowIn = service->property("NotShowIn", QVariant::String).toString();
+                    if ( !notShowIn.isEmpty() ) {
+                        const QStringList aList = QStringList::split(';', notShowIn);
+                        if (aList.contains("KDE"))
+                            continue;
+                    }
 
                     QCString nam;
                     nam.setNum( id );
@@ -1136,6 +1162,7 @@ void KonqPopupMenu::addPlugins()
                                                             (*iterator)->name().latin1() );
         if ( !plugin )
             continue;
+        // This make the kuick plugin insert its stuff above "Properties"
         QString pluginClientName = QString::fromLatin1( "Plugin%1" ).arg( pluginCount );
         addMerge( pluginClientName );
         plugin->domDocument().documentElement().setAttribute( "name", pluginClientName );
