@@ -22,6 +22,7 @@
 #undef Always
 
 #include <kio/uiserver_stub.h>
+#include "konq_operations.h"
 
 #include <assert.h>
 
@@ -271,21 +272,39 @@ QString KonqUndoManager::undoText() const
 void KonqUndoManager::undo()
 {
   KonqCommand cmd = d->m_commands.top();
-  broadcastPop();
-  broadcastLock();
-
   assert( cmd.m_valid );
 
   d->m_current = cmd;
+
+  QValueList<KonqBasicOperation>& opStack = d->m_current.m_opStack;
+
+  // Let's first ask for confirmation if we need to delete any file (#99898)
+  KURL::List fileCleanupStack;
+  QValueList<KonqBasicOperation>::Iterator it = opStack.begin();
+  for ( ; it != opStack.end() ; ++it ) {
+      if ( !(*it).m_directory && !(*it).m_link && d->m_current.m_type == KonqCommand::COPY ) {
+          fileCleanupStack.append( (*it).m_dst );
+      }
+  }
+  if ( !fileCleanupStack.isEmpty() ) {
+      // Because undo can happen with an accidental Ctrl-Z, we want to always confirm.
+      if ( !KonqOperations::askDeleteConfirmation( fileCleanupStack, KonqOperations::DEL,
+                                                   KonqOperations::FORCE_CONFIRMATION,
+                                                   0 /* TODO parent */ ) )
+          return;
+  }
+
   d->m_dirCleanupStack.clear();
   d->m_dirStack.clear();
   d->m_dirsToUpdate.clear();
 
   d->m_undoState = MOVINGFILES;
-  kdDebug(1203) << "KonqUndoManager::undo MOVINGFILES" << endl;
 
-  QValueList<KonqBasicOperation>::Iterator it = d->m_current.m_opStack.begin();
-  QValueList<KonqBasicOperation>::Iterator end = d->m_current.m_opStack.end();
+  broadcastPop();
+  broadcastLock();
+
+  it = opStack.begin();
+  QValueList<KonqBasicOperation>::Iterator end = opStack.end();
   while ( it != end )
   {
     if ( (*it).m_directory && !(*it).m_renamed )
