@@ -37,7 +37,7 @@ k_dcop:
   virtual ASYNC requestURL(QString url, QString target) = 0;
   virtual ASYNC postURL(QString url, QString target, QByteArray data, QString mime) = 0;
   virtual ASYNC statusMessage( QString msg ) = 0;
-  virtual ASYNC evalJavaScript( int id, QString script ) = 0;
+  virtual ASYNC evalJavaScript( Q_INT32 id, QString script ) = 0;
 
 };
 
