@@ -56,8 +56,6 @@ const int XKeyRelease = KeyRelease;
 
 Boolean qmotif_event_dispatcher( XEvent *event );
 
-static void handle_xquerykeymap( Display* dpy, XEvent* event );
-
 class QXtEventLoopPrivate
 {
 public:
@@ -72,7 +70,7 @@ public:
 
     QIntDict<QSocketNotifier> socknotDict;
     bool activate_timers;
-    int timerid;
+    XtIntervalId timerid;
 
     // arguments for Xt display initialization
     const char* applicationClass;
@@ -110,7 +108,7 @@ XEvent* QXtEventLoop::lastEvent()
 
 QXtEventLoopPrivate::QXtEventLoopPrivate()
     : appContext(NULL), ownContext(NULL),
-      activate_timers(FALSE), timerid(-1)
+      activate_timers(FALSE), timerid(0)
 {
 }
 
@@ -153,7 +151,6 @@ void QXtEventLoopPrivate::unhook()
 extern bool qt_try_modal( QWidget *, XEvent * ); // defined in qapplication_x11.cpp
 Boolean qmotif_event_dispatcher( XEvent *event )
 {
-    handle_xquerykeymap( qt_xdisplay(), event );
     QApplication::sendPostedEvents();
 
     QWidgetIntDict *mapper = &static_d->mapper;
@@ -416,7 +413,7 @@ void QXtEventLoop::unregisterSocketNotifier( QSocketNotifier *notifier )
 void qmotif_timeout_handler( XtPointer, XtIntervalId * )
 {
     static_d->activate_timers = TRUE;
-    static_d->timerid = -1;
+    static_d->timerid = 0;
 }
 
 /*! \reimp
@@ -429,10 +426,10 @@ bool QXtEventLoop::processEvents( ProcessEventsFlags flags )
 
     // make sure we fire off Qt's timers
     int ttw = timeToWait();
-    if ( d->timerid != -1 ) {
+    if ( d->timerid != 0 ) {
 	XtRemoveTimeOut( d->timerid );
     }
-    d->timerid = -1;
+    d->timerid = 0;
     if ( ttw != -1 ) {
 	d->timerid =
 	    XtAppAddTimeOut( d->appContext, ttw,
@@ -469,29 +466,6 @@ bool QXtEventLoop::processEvents( ProcessEventsFlags flags )
     return ( (flags & WaitForMore) || ( pendingmask != 0 ) || nevents > 0 );
 }
 
-#include <dlfcn.h>
-
-static char xquerykeymap_data[ 32 ];
-static int (*real_xquerykeymap)( Display*, char[32] ) = NULL;
-
-static void handle_xquerykeymap( Display* dpy, XEvent* event )
-{
-    if( real_xquerykeymap == NULL )
-        real_xquerykeymap = (int (*)( Display*, char[32] )) dlsym( RTLD_NEXT, "XQueryKeymap" );
-    if( event->type == XFocusIn || event->type == XKeyPress || event->type == XKeyRelease )
-        real_xquerykeymap( dpy, xquerykeymap_data );
-    if( event->type == XFocusOut )
-        memset( xquerykeymap_data, 0, 32 );
-}
-
-extern "C" KDE_EXPORT
-int XQueryKeymap( Display* , char k[32] )
-{
-    memcpy( k, xquerykeymap_data, 32 );
-    return 1;
-}
-
-
 #include "qxteventloop.moc"
 
 #endif
